/***************************************************************************
 *   Copyright (C) 2008 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "bipartitemincost.h"

BipartiteMinCost::BipartiteMinCost(IntVec _a, IntVec _b, IntMatrix _c)
{
	m = _a.size();
	n = _b.size();
	a = _a;
	b = _b;
	c = _c;
}

BipartiteMinCost::BipartiteMinCost(const char* inFile)
{
	int _m, _n;
	IntVec _a, _b;
	IntMatrix _c;
	int tempInt;	
	string temp;

	try{
		ifstream in;
		in.exceptions (ios::failbit | ios::badbit);
		in.open(inFile);
		//read _m
		if ( !(in >> temp) )
			outError (ERR_READ_MISSING_DATA, inFile);
		_m = convert_int (temp.c_str());

		//read _n
		if ( !(in >> temp) )
			outError (ERR_READ_MISSING_DATA, inFile);
		_n = convert_int (temp.c_str());

		//read amount of instances for each pattern on the left hand side
		for ( int i = 0; i < _m; i++)
		{
			if ( !(in >> temp) )
				outError (ERR_READ_MISSING_DATA, inFile);
			tempInt = convert_int (temp.c_str());
			_a.push_back(tempInt);
		}

		//read amount of instances for each pattern on the right hand side
		for ( int i = 0; i < _n; i++)
		{
			if ( !(in >> temp) )
				outError (ERR_READ_MISSING_DATA, inFile);
			tempInt = convert_int (temp.c_str());
			_b.push_back(tempInt);
		}

		//read the cost matrix
		for (int i = 0; i < _m; i++)
		{
			IntVec currentRow;
			for (int j = 0; j < _n; j++)
			{
				if ( !(in >> temp) )
					outError (ERR_READ_MISSING_DATA, inFile);
				tempInt = convert_int (temp.c_str());
				currentRow.push_back(tempInt);
			}
			_c.push_back(currentRow);
		}
		in.clear();
		in.exceptions (ios::failbit | ios::badbit);
		in.close();
		
	}catch (ios::failure){
		outError(ERR_READ_INPUT, inFile);
	}

	m = _m; n = _n;
	a = _a; b = _b;
	c = _c;
}

BipartiteMinCost::~BipartiteMinCost()
{
	a.clear();
	b.clear();
	for (int i = 0; i < c.size(); i++)
	{
		c[i].clear();
	}
}

void BipartiteMinCost::firstInit()
{
	maxN = max(m,n);
	initIntMatrix(d, m, n, 0);
	dx = IntVec(m, 0);
	dy = IntVec(n, 0);
	arg = IntVec(maxN, 0);
	delta = IntVec(maxN, 0);
	deltaX = IntVec(maxN, 0);
	deltaY = IntVec(maxN, 0);
	queue = IntVec(maxN, -1);

	//these two vectors will be updated in the init() step
	fx = IntVec(m, 0);
	fy = IntVec(n, 0);

	//these two vectors are used in init BFS and need to be reset there
	traceX = IntVec(m, -1);
	traceY = IntVec(n, -1);
}

/*!
    \fn BipartiteMinCost::init()
 */
void BipartiteMinCost::init()
{	    
    for (int i = 0; i < m; i++)
    {
        fx[i] = maxC;	
    	for (int j = 0; j < n; j++)
    		if (fx[i] > c[i][j]) fx[i] = c[i][j];
  	}  		
  	for (int j = 0; j < n; j++)
	{
	    fy[j] = maxC;
	    for (int i = 0; i < m; i++)
	    	if (fy[j] > c[i][j] - fx[i]) fy[j] = c[i][j] - fx[i];
 	}
}

void BipartiteMinCost::initBFS()
{
	resetIntVector(traceX, -1);
	resetIntVector(traceY, -1);
	
	front = 0; rear = 0;
    queue[0] = start;
    traceX[start] = -2;
    deltaX[start] = a[start] - dx[start];
    for (int j = 0; j < n; j++)
    {
        delta[j] = c[start][j] - fx[start] - fy[j];
        arg[j] = start;
    }
    finish = -1;
}
/*!
    \fn BipartiteMinCost::findAugmentingPath()
 */
void BipartiteMinCost::findAugmentingPath()
{
	while (front <= rear)
    {
        int x = queue[front++];
        for (int y = 0; y < n; y++)
        	if (traceY[y] == -1)
        	{
        	    int w = c[x][y] - fx[x] - fy[y];
        	    if (w == 0)
        	    {
        	        traceY[y] = x;
        	        deltaY[y] = deltaX[x];
        	        if (dy[y] < b[y])
        	        {
        	            finish = y;
        	            deltaY[y] = min(deltaY[y], b[y] - dy[y]);
        	            return;
                 	}
                 	for (int xx = 0; xx < m; xx++)
                 		if (traceX[xx] == -1 && c[xx][y] == fx[xx] + fy[y] && d[xx][y])
                 		{
                 		    traceX[xx] = y;
                 		    deltaX[xx] = min(deltaY[y], d[xx][y]);
                 		    queue[++rear] = xx;
                   		}
             	}
             	if (delta[y] > w)
             	{
             	    delta[y] = w;
             	    arg[y] = x;
              	}
         	}
    }
}


/*!
    \fn BipartiteMinCost::subX_addY()
 */
void BipartiteMinCost::subX_addY()
{
	int incValue = maxC;
    for (int y = 0; y < n; y++)
    	if (traceY[y] == -1)
    		incValue = min(incValue, delta[y]);
	for (int i = 0; i < m; i++)
		if (traceX[i] != -1) fx[i] += incValue;
	for (int j = 0; j < n; j++)
		if (traceY[j] != -1) fy[j] -= incValue;
		else delta[j] -= incValue;
	for (int j = 0; j < n; j++)
		if (delta[j] == 0 && traceY[j] == -1)
		{
		    int i = arg[j];
		    traceY[j] = i;
		    deltaY[j] = deltaX[i];
		    if (dy[j] < b[j])
		    {
		        finish = j;
		        deltaY[j] = min(deltaY[j], b[j] - dy[j]);
		        return;
      		}
      		for (int ii = 0; ii < m; ii++)
  				if (traceX[ii] == -1 && c[ii][j] == fx[ii] + fy[j] && d[ii][j])
  				{
  				    traceX[ii] = j;
  				    deltaX[ii] = min(deltaY[j], d[ii][j]);
  				    queue[++rear]= ii;
      			}
  		}
}


/*!
    \fn BipartiteMinCost::enlarge()
 */
void BipartiteMinCost::enlarge()
{
    int incValue = deltaY[finish];
    dy[finish] += incValue;
    int x;
    while (true)
    {
        x = traceY[finish];
        d[x][finish] += incValue;
        finish = traceX[x];
        if (finish == -2) break;
        d[x][finish] -= incValue;
    }
    dx[x] += incValue;
}
void BipartiteMinCost::solve()
{
	firstInit();
	init();
	for (int i = 0; i < m; i++)
    	while (a[i] > dx[i])
    	{
    	    start = i;
    	    initBFS();
    	    do
    	    {
    	        findAugmentingPath();
    	        if (finish == -1) subX_addY();
         	}
         	while (finish ==  -1);
         	enlarge();
     	}

	//compute total cost
	int cost = 0;
	for (int i = 0; i < m; i++)
		for (int j = 0; j < n; j ++)
			cost += d[i][j] * c[i][j];
	totalCost = cost;
}
