/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef INTERVALSET_H
#define INTERVALSET_H

#include<set>
#include "intinterval.h"
#include "utility.h"

/**
a set of intervals of consecutive integer numbers.
IMPORTANT NOTE::Those intervals are disjoint or only overlap at the end or the begining.

	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/

namespace std {
	/**
		Define less than relationship of two integer interval, used for set template
	*/
	template<>
	struct less<IntInterval*> {
		/**
			@return true if *p1->begin < *p2->begin numerically
			@param p1 first integer interval
			@param p2 second integer interval
		*/
		bool operator()(const IntInterval *p1, const IntInterval *p2) const 
		{			
			return (p1->getBegin() < p2->getBegin());	
		}
	};
} // namespace std

class IntervalSet : set <IntInterval*, std::less<IntInterval*> > {
friend class PatternSet;
public:
	/**
		empty constructor
	*/
    IntervalSet();
	/**
		constructor from a vector of integers. First, this vector must be sort in ascending order. Intevals of consecutive numbers should be detected.
		@param aIntVec the vector of integer numbers.
	*/
	IntervalSet(const IntVec aIntVec);
	
	/**
		constructor from a set of integers sorted in ascending order.
		Intervals of consecutives numbers should be detected.
		@param aIntSet the set of (sorted) integers.
	*/
	IntervalSet (const IntSet aIntSet);

	/**
		initialize from a set of integers sorted in ascending order.
		Intervals of consecutive numbers should be detected.
		@param aIntSet the set of (sorted) integers
	*/
	void init( const IntSet aIntSet);

	/**
		find the interval ends by a given number.
		@param aInt the given integer
		@RETURN pointer to the IntInterval ends by the given number.
		NULL if not found.
	*/
	IntInterval* findEnd(const int aInt);

	/**
		find the interval starts by given number.
		@param aInt the given integer
		@RETURN pointer to the IntInterval starts by the given number.
		NULL if not found.
	*/
	IntInterval* findBegin(const int aInt);

	/**
		add an interval to this set of intervals.
		Need to find for an interval in this set that can connects to the given interval.
		If found, just extend the found interval than examining its neighbors.
		If not found, add anyway if added = true, otherwise not add.
		@param anInterval pointer to the interval should be added
		@param amount maximum number should be added
		@param added indicate whether or not add if not find an interval that can connect to the given one
		@param atBegin indicate that adding at the end (in case not found a match && added = true);
	*/
	void addAnInterval (IntInterval *anInterval, int &amount, bool atEnd = false, bool added = false);

	/**
		add a vector of intervals to this set of intervals. Total amount of numbers added not exceed a given number (amount)
		@param interVec a vector of intervals
		@param amount maximum amount of numbers should be added
	*/
	void addIntervalVec (IntervalVec &interVec, int &amount, bool added = false);

	/**
		add a vector of integers to this set of intervals. Total amount of numbers added not exceed a given number (amount)
		@param intVec a vector of integers
		@param amount maximum amount of numbers should be added
	*/
	void addIntVec (const IntVec intVec, int &amount, bool added = false);
	
	/**
		given a query interval, compute its distance to the closest interval(s) in this set
		@param anInterval the query interval
		@param pos (OUT) 0 if the begin of anInterval is closer, otherwise, 1 (the end of anInterval is closer).
		@RETURN the distance 
	*/
	int lessDistanceTo(const IntInterval *anInterval, bool &pos);

	/**
		print this set of intervals to an output stream
		@param out the output stream
	*/
	void printIntervalSet(ostream &out) const;

	/**
		To print the set fully		
	*/
// 	void printIntervalSetFull(ostream &out) const;
	void removeAll();

    ~IntervalSet(); 
};

#endif

