/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef NODE_H
#define NODE_H

/**
describes a node on a tree

	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/
#include <vector>
#include <string>
#include <iostream>
#include <fstream>
#include <stdio.h>
#include <stdlib.h>

using namespace std;
#include "utility.h"

/**
	predeclaration of class Node
*/
class Node;



/**
	a Neighbor a node in the tree
*/
class Neighbor {
public:

	/**
		the other end of the branch
	*/
	Node *node;

	/**
		id of this branches, used to output amount of each type of muations on each branch
	*/
	int brId;

	/**
		branch length
	*/
	double length;

	/**
		number of mutations on this branch which favors long internal branches (short external branches)
	*/
	double minMutCost;
	/**
		number of mutations on this branch which favors short internal branches (long external branches)
	*/
	double maxMutCost;

	/**
		amount of each type of mutations on this branch which favors long internal branches (short external branches)
	*/
	IntVec minMutTypeAmount;

	/**
		amount of each type of mutations on this branch which favors short internal branches (long external branches)
	*/
	IntVec maxMutTypeAmount;

	
	/**
		construction of Neighbor class with a node and length
		@param anode the other end of the branch
		@param alength length of branch
	*/
	Neighbor(Node *anode, double alength) {
		brId = -1;
		node = anode;
		length = alength;
		minMutCost = maxMutCost=0;
		minMutTypeAmount = IntVec(StateNum, 0);
		maxMutTypeAmount = IntVec(StateNum, 0);
	}

	Neighbor(Node *anode){
		brId = -1;
		node = anode;
		length = -1;
		minMutCost = maxMutCost = 0;
		minMutTypeAmount = IntVec(StateNum, 0);
		maxMutTypeAmount = IntVec(StateNum, 0);
	}

	Neighbor(int aBrId, Node *anode, double alength) {
		brId = aBrId;
		node = anode;
		length = alength;
		minMutCost = maxMutCost=0;
		minMutTypeAmount = IntVec(StateNum, 0);
		maxMutTypeAmount = IntVec(StateNum, 0);
	}

	Neighbor(int aBrId, Node *anode){
		brId = aBrId;
		node = anode;
		length = -1;
		minMutCost = maxMutCost = 0;
		minMutTypeAmount = IntVec(StateNum, 0);
		maxMutTypeAmount = IntVec(StateNum, 0);
	}

	/**
		destructor
	*/
	virtual ~Neighbor() {}
};

/*
	some macros to transverse neighbors of a node
*/
#define FOR_NEIGHBOR(mynode, mydad, it) \
	for (it = (mynode)->neighbors.begin(); it != (mynode)->neighbors.end(); it++) \
		if ((*it)->node != (mydad))

#define FOR_NEIGHBOR_IT(mynode, mydad, it) \
	for (NeighborVec::iterator it = (mynode)->neighbors.begin(); it != (mynode)->neighbors.end(); it++) \
		if ((*it)->node != (mydad))

#define FOR_NEIGHBOR_DECLARE(mynode, mydad, it) \
	NeighborVec::iterator it; \
	for (it = (mynode)->neighbors.begin(); it != (mynode)->neighbors.end(); it++) \
		if ((*it)->node != (mydad))

/*--------------------------------------------------*/
/*--------------------------------------------------*/
/**
	Vector containing a list of Neighbors
*/
typedef vector<Neighbor*> NeighborVec;

/**
	A node on the tree
	@author Nguyen Thi Minh Anh, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/
class Node{
/**------------METHODS-----------------*/
public:

	/**
		default constructor
	*/
    Node();//{id=-1; seqID=-1; fitchScore=0;};

	/**
		constructor 
		@param aid id of this node
	*/
	Node(int aid);

	/**
		constructor 
		@param aid id of this node
		@param aname name of this node
	*/
	Node(int aid, int aname);

	/**
		constructor 
		@param aid id of this node
		@param aname name of this node
	*/
	Node(int aid, const char *aname);

	/**
		destructor 
	*/
	virtual ~Node();
	
	/**
		@return true of this is a leaf
	*/
	bool isLeaf();

	/**
		replace a neighbor node by a newnode
		@param node old neighbor node
		@param newnode new neighbor node
		@param newlen new length applied for the corresponding branch
	*/
	void replaceNeighbor(Node* node, Node *newnode, double newlen);

/**------------ATTRIBUTES---------------*/
public:
	/**
		id of this node on the tree
	*/
    int id;
	/**
		name of this node
	*/
	string name;
	/**
		list of neighbors. 1 for leaves, 3 for internal node and 2 for the root in case of binary tree
	*/
	NeighborVec neighbors;
	/**
		id of the corresponding sequence if this node is a leaf. Otherwise, -1.
	*/
	int seqID;
	/**
		set of characters at this node, it is digitalized for fast computation.
		It is equivalent to the preliminary nodal set in Fitch algorithm
	*/
    int fitchSet;
	/**
		set of characters at this node, it is digitalized for fast computation.
		It is equivalent to the final nodal set in Fitch algorithm
	*/
    int finalFitchSet;
	/**
		fitch score at each node 0 or 1.
		0 means the fitch sets at its children have intersection != empty.
		otherwise 1.
		To obtain the Fitch score for the whole tree we need to add the scores at all the node.
	*/
    int fitchScore;
	/**
		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM: (DELTRAN) MINimum number of total of mutations (COST) on all EXternal BRanches in the substree rooted at this node if the state at this node is in turn 1, 2, 4, 8.
		This vector is of size 4. its element, e.g. the third element, is -1 if the possible character state at this node does not include 4.
	*/
	IntVec minExBrCost;
	/**
		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM: (ACCTRAN) MAXimum number of total of mutations (COST) on all EXternal BRanches in the substree rooted at this node if the state at this node is in turn 1, 2, 4, 8.
		This vector is of size 4. its element, e.g. the third element, is -1 if the possible character state at this node does not include 4.
	*/
	IntVec maxExBrCost;
	/**
		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM: possible character SET at this node if the character state at its ancestor is in turn 1, 2, 4, 8.
		This vector is also of size 4. its element, e.g. the third element, is 0 if 4 is not in the possible character set of this node's ancestor.
	*/
	IntVec charSet;
	/**
		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM: all possible character SET at this node
	*/
	int allCharSet;	
};

#endif

