/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "pattern.h"

Pattern::Pattern()
{
	code = string();
	ntaxa = 0;
	logll = 0;
	obsNum = 0;
	exAmount = 0;
	exDiff = 0;
	mutStep = -1;
	positions = IntVec();
}

Pattern::Pattern(const string &astring, bool encoded, int amutStep, double alogll, int aobsNum)
{	
	int	strlength = astring.length();
 	code = string();
	ntaxa = strlength;	
	logll = alogll;
	obsNum = aobsNum;
	exAmount = 0;
	exDiff = 0;
	mutStep = amutStep;
	positions = IntVec();
	if (encoded){
		for (int i = 0; i < strlength; i++)
			code.push_back(astring[i]);
	}
	else 
	{
		char c;
		for (int i = 0; i < strlength; i++)
		{
			c = '-';
			switch ( toupper(astring[i]) ){
				case 'A': c = '0'; break;
				case 'C': c = '1'; break;
				case 'G': c = '2'; break;
				case 'T': c = '3'; break;
				case 'U': c = '3'; break;
				default: break;
			}
			if ( c == '-')
				outError("There are non {ACGT/U} in pattern: ",astring.c_str());
			else
				code.push_back(c);
		}
	}	
}

Pattern::Pattern(const Pattern &pt)
{	
	ntaxa = pt.getNTaxa();
	logll = pt.getLogll();
	obsNum = pt.getObsNum();
	exDiff = pt.getExDiff();
	exAmount = pt.getExAmount();
	positions = pt.getPositions();
	mutStep = pt.getMutStep();
	code = string();
	for (string::const_iterator it = pt.code.begin(); it != pt.code.end(); it++)
	{
		code.push_back(*it);
	}	
}

Pattern& Pattern::operator= (const Pattern &apat)
{
	code = apat.code;
	ntaxa = apat.getNTaxa();
	logll = apat.getLogll();
	obsNum = apat.getObsNum();
	exDiff = apat.getExDiff();
	exAmount = apat.getExAmount();
	mutStep = apat.getMutStep();
	positions = apat.getPositions();
}

string Pattern::convert2Str() const
{
 	/*int len = code.size();
	cout << "len: " << len << ", ntaxa: " << ntaxa << endl;
   	assert(ntaxa == len);*/
	string patStr = string();
	int index;
	for (int i = 0; i < ntaxa; i++)
	{		
		index = (int)(code[i]-'0');		
		patStr.push_back(Nucleotides[index]);
	}	
	return patStr;
}

Pattern* Pattern::mutated(const Split *split, int mut) const
{
	assert(getNTaxa() == split->getNTaxa());
	int nuIndex, muIndex; //nucleotide index and mutation type index
	string mutStr;	
	int i=0;	
	for (Split::const_iterator bvi = split->begin(); bvi != split->end(); i++, bvi++)
	{
		nuIndex = (int)(code[i] - '0');
		if ((*bvi) == true)
		{
			muIndex = mut;	
		}
		else
			muIndex = 0;
		mutStr.push_back(MutatedChar[nuIndex][muIndex]);
	}
	Pattern *retPat = new Pattern(mutStr,true);
	return retPat;
}

/*void Pattern::updateMutStep (Tree *atree)
{
	int mutStep = atree->mutScore(this, true);
	(*this).setMutStep(mutStep);
}*/

IntVec Pattern::distanceTo(const Pattern& apat)
{
	assert((*this).getNTaxa() == apat.getNTaxa());
	int index1, index2;
	IntVec retVec;
	for (int i = 0; i < ntaxa; i++)
	{
		index1 = (int)(code[i] - '0');
		index2 = (int)(apat.code[i] - '0');
		retVec.push_back(K3stMatrix[index1][index2]);
	}
	return retVec;
}

bool Pattern::operator==(const Pattern &apat) const
{
	if ((*this).getNTaxa() != apat.getNTaxa()) return false;
	return (code == apat.code);
}

void Pattern::setLogll(const double alogll)
{
	(*this).logll = alogll;
}

void Pattern::setObsNum(const int aobsNum)
{
	(*this).obsNum = aobsNum;
}

void Pattern::setMutStep(const int aMutStep)
{
	(*this).mutStep = aMutStep;
}

void Pattern::addPosition (const int apos, bool incObsNum)
{
	(*this).positions.push_back(apos);
	if (incObsNum)
		(*this).obsNum++;
}

void Pattern::updateExAmount (const int seqLen, const double lowerP, const double kappa)
{	
	double prob = exp(getLogll());
	if (prob < lowerP)
		exAmount = 0;
	else
	{
//   		exAmount = max(1,(int)floor(prob*seqLen + 0.5));
 		exAmount = max(1, (int)floor ((prob+kappa*sqrt(prob*(1-prob)/seqLen))*seqLen));
	}
}
	
void Pattern::updateExDiff (const int seqLen, const double kappa)
{
	double prob = exp(getLogll());
	double diff = kappa*sqrt(prob*(1-prob)/seqLen);
	double upperB = prob+diff;
	double lowerB;
	if (prob < diff)
		lowerB = 0;
	else 
		lowerB = prob-diff;
	int diff1 = obsNum - (int)ceil(lowerB * seqLen); 
	if (diff1 < 0)
		exDiff = diff1;
	int diff2 = obsNum - (int)floor(upperB*seqLen);
	if (diff2 > 0)
		exDiff = diff2;	
}

void Pattern::printInfo (ostream& out) const
{	
	IntVec pos = (*this).getPositions();
	string pat = (*this).convert2Str();
 	if (positions.size() > 0)
 	{
		out << pat << "\t" << obsNum << "\t" << logll << "\t" << mutStep << "\t" << exDiff << endl;		
 	}
 	else
 	{
//  		out << pat << "\t" << obsNum << "\t" << logll << "\t" << mutStep << "\t" << exAmount << endl;
		out << pat << "\t" << obsNum << "\t" << logll << "\t" << mutStep << "\t" << getNumExchange() << endl;
 	}		
}

void Pattern::printInfoMoreLess (ostream& out) const
{		
	string pat = (*this).convert2Str();
	out.precision(10);
 	if (getExDiff() > 0)
 	{
		out << pat << "\t" << obsNum << "\t" << logll << "\t" << mutStep << "\t" << getExDiff() << endl;		
 	}
 	else //if (getExAmount() > 0)
 	{
//  		out << pat << "\t" << obsNum << "\t" << logll << "\t" << mutStep << "\t" << getExAmount() << endl;
		out << pat << "\t" << obsNum << "\t" << logll << "\t" << mutStep << "\t" << getNumExchange() << endl;
 	}	
}

void Pattern::printPositions (ostream &out) const
{
	IntVec pos = (*this).getPositions();
	string pat = (*this).convert2Str();
	if (!pos.empty())
	{
		out << pat << "\t" << obsNum << "\t" << logll << "\t" << exDiff;
		for (IntVec::iterator it = pos.begin(); it != pos.end(); it++)
		{
			out << "\t" << (*it);
		}
		out << endl;
	}
}

