/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PATTERN_H
#define PATTERN_H

#include <string>
#include "utility.h"
#include "split.h"


/**
	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/
class Pattern
{
public:
	/**
		default (empty) constructor
	*/	
    Pattern();

	/**
		construction from a string of nucleotide characters, the log likelihood and the number of observed occurence
		@param astring a string of nucleotide characters
		@param alogll the log likelihood, default is 0
		@param aobsNum the number of occurence, default is 0
		@param encoded if the patterns is already encoded, A=0, C=1, G=2, T=3
	*/
	Pattern(const string &astring, bool encoded = true, int amutStep = -1, double alogll = 0, int aobsNum = 0);

	/**
		copy constructor
		@param pt pattern to be copied from
	*/
	Pattern(const Pattern &pt);

	/**
		assignment
		@param apat a pattern
	*/
	Pattern &operator= (const Pattern &apat);

	/**
		get the number of taxa in this pattern
	*/
	int getNTaxa() const{
		return ntaxa;
	};

	/**
		convert this pattern to a string
	*/
	string convert2Str() const;

	/**
		mutate this pattern according to a split and a mutation type
		@param split a split defining where the mutation happens
		@param mut mutation type (0, 1, 2 or 3)
		@param rePat (OUT) the returned pattern
	*/
	Pattern* mutated(const Split *split, int mut) const;

	/**
		compute and update mutation step of this pattern on a given tree
		@param atree the tree
	*/
//  	void updateMutStep (Tree *atree);

	/**
		Compute the distance to another pattern based on K3stMatrix.
		@param apattern the other pattern.
		@RETURN  vector of integers representing the series of mutation types
	*/
	IntVec distanceTo(const Pattern &apattern);

	/**
		set loglikelihood for this pattern
		@param alogll the log likelihood value set to the pattern
	*/
	void setLogll(const double alogll);

	/**
		get the logll of this pattern
	*/
	inline double getLogll()const{
		return logll;
	};

	/**
		set number of observed occurence for this pattern
		@param aobsNum  the number of observed occurence to set
	*/
	void setObsNum(const int aobsNum);

	/**
		get number of observed occurence
	*/
	inline int getObsNum()const{
		return obsNum;
	};
	
	/**
		set step mutation
		@param aMutStep the mutation step
	*/
	void setMutStep(const int aMutStep);
	
	/**
		get step mutation
	*/
	inline int getMutStep() const{
		return mutStep;
	};	
	
	/**
		compare two pattern, just the string itself
		@param apat the other pattern
		@param RETURN TRUE if equal, FALSE otherwise
	*/
	bool operator==(const Pattern &apat) const;	

	/**
		given sequence length, compute expected amount for this pattern. logll must be given, too.
		This one is used for generated patterns to put into D-
		@param seqLen sequence's length
		@param lowerP from Gold confidence interval, a pattern would be observed if its likelihood is greater than lowerP
		@param kappa is the square root of the (1-2alpha/length) quantile of the used distribution
	*/
	void updateExAmount (const int seqLen, const double lowerP, const double kappa);
	
	/**
		given sequence length, compute the amount that this pattern is over/under represented (i.e. update exDiff)
		This one is used for patterns in the alignment.
		@param seqLen sequence's length		
		exDiff is positive: pattern is over represented.
		exDiff is 0: the pattern is in the confidence region.
		exDiff is negative: pattern is under represented
	*/
	void updateExDiff (const int seqLen, const double kappa);

	/**
		get number of units to be exchanged for "less" patterns
		"less" = generated patterns and observed patterns whose number of occurence does not exceed the upper bound of its confidence interval
	*/
	inline int getNumExchange() const
	{
		return exAmount - obsNum;
	}
	
	/**
		get the amount of this pattern being over/under represented. Used for observed patterns.
	*/
	inline int getExDiff() const
	{
		return exDiff;
	}
	
	/**
		get the expected number of occurence. Used for generated patterns.
	*/
	inline int getExAmount() const
	{
		return exAmount;
	}

	/**
		get the pattern itself and encoded.
	*/
	inline string getCode() const
	{
		return code;
	}

	/**
		return the integer vector storing positions at which this pattern appears in the alignment.
		@RETURN integer vector.
	*/
	inline IntVec getPositions() const{
		return positions;
	};

	/**
		add a position at which the pattern appear in the alignment.
		@param apos the position
		@param incObsNum TRUE ==> increase obsNum by 1. Default is FALSE = NOT increase obsNum
		This method will change the attribute: positions and increase obsNum by 1 if incObsNum == TRUE.
	*/
	void addPosition (const int apos, bool incObsNum = false);

	/**
		print the pattern. This is used when printing over/under-represented patterns in the alignment.
		@param out output stream
	*/
	void printInfo (ostream& out) const;

	void printInfoMoreLess(ostream& out) const;

	/**
		print info and position of this pattern.
		NOTE pattern itself "\t" obsNum "\t" exDiff, then obsNum numbers corresponding to positions vector element
		@param out output stream
	*/
	void printPositions (ostream &out) const;

    ~Pattern(){		
// 		cout << "pattern is deleted!" << endl;
};

public:
	/**
		the pattern itself with:
		A,C,G,T is 0, 1, 2, 3
	*/
	string code;
	/**
		number of taxa in this pattern. Should be equal to pat.length()
	*/
	int ntaxa;
	/**
		log likelihood of this pattern
	*/
	double logll;
	/**
		number of occurence in the alignment
	*/
	int obsNum;
	
	/**
		Integer vector to store the positions of this pattern in the alignment. If this is a generated pattern, the vector is empty.
	*/
	IntVec positions;
	/**
		number of times this pattern is over/under represented.
		positive if over, negative if under, zero otherwise
		This only makes sense for observed patterns.
	*/
	int exDiff;
	/**
		expected amount of this pattern. This only makes sense for generated patterns.
	*/
	int exAmount;

	/**
		mutation step from a constant patterns
	*/
	int mutStep;
};

/**
	compare two patterns w.r.t logll
	This is used to sort a vector of pattern in decreasing order of their logll.
	@param a the first pattern
	@param b the second pattern
	@RETURN TRUE if logll of the first greater than logll of the second pattern. Otherwise, return FALSE
*/
inline bool logllCmp (const Pattern *a, const Pattern *b)
{
	return (a->getLogll() > b->getLogll());
}
inline bool logllCmpLess (const Pattern *a, const Pattern *b)
{
	return (a->getLogll() < b->getLogll());
}
inline bool obsNumCmp(const Pattern *a, const Pattern *b)
{
	return (a->getObsNum() > b->getObsNum());
}
/**
	defined data type
*/
typedef vector< Pattern*> PatVec;

#endif
