/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "patternset.h"

PatternSet::PatternSet(const char *file):set<Pattern*, std::less<Pattern*> >()
{
	readPatternSet(file);
}

PatternSet::PatternSet(const StringVec sequences, const char *inFile):set<Pattern*, std::less<Pattern*> >()
{
	readPatternSet(sequences, inFile);
}

void PatternSet::readPatternSet(const StringVec sequences, const char *inFile)
{
	cout << "\nConstructing pattern set from a set of sequences and a file containing site's likelihood (" << inFile << ")..." << endl;
	DoubleVec sitelh;
	readSitelh(inFile, sitelh);
	int seqNum = sequences.size();
	int seqLen;
	if (seqNum > 0)
		seqLen = sequences[0].size();
	if (seqLen != sitelh.size())
		outError("sequence's length and number of site's likelihood are not consistent, ", inFile);
	for (int siteIndex = 0; siteIndex < seqLen; siteIndex++)
	{
		string currentPat = string();
		for (int seqIndex = 0; seqIndex < seqNum; seqIndex++)
			currentPat.push_back(sequences[seqIndex][siteIndex]);		
		//if the pattern is gap-free, take it into account
		if (strcspn(currentPat.c_str(), UGAP) == strlen(currentPat.c_str()))
		{			
			Pattern *apat = new Pattern(currentPat, false, -1, sitelh[siteIndex]);
			apat->addPosition(siteIndex, true);
			PatternSet::iterator foundId = (*this).find(apat);
			if (foundId != (*this).end())
			{				
				(*foundId)->addPosition(siteIndex, true);				
			}
			else
			{
				(*this).insert(apat);
			}
		}
	}
}

void PatternSet::readPatternSet(const char *inFile)
{
	cout << "\nReading iqpnni-pattern containing file: " << inFile << "...." << endl;
    ifstream in;
	try{
		in.exceptions (ios::failbit | ios::badbit);
		in.open(inFile);
		readPatternSet(in);
		in.clear();
		in.exceptions (ios::failbit | ios::badbit);
		in.close();
	} catch (ios::failure){
		outError(ERR_READ_INPUT, inFile);
	}
	cout << "Finish reading file!" << endl;	
}
	
void PatternSet::readPatternSet (ifstream &inFile)
{		
	string currentPattern, currentObservedStr, currentLogLLStr;
	int currentObserved;
	double currentLogLL;
    try{
		while (!inFile.eof())
		{
			//reading each line of the file
			//remove the badbit
			inFile.exceptions (ios::badbit);
			if ( !(inFile >> currentPattern >> currentObservedStr >> currentLogLLStr) ) break;
			//set the failbit again
			inFile.exceptions (ios::failbit | ios::badbit);

			//if the pattern is gap-free, take it into account
			if (strcspn(currentPattern.c_str(), UGAP) == strlen(currentPattern.c_str()))
			{
				currentObserved = convert_int(currentObservedStr.c_str());
				currentLogLL = convert_double(currentLogLLStr.c_str());

				Pattern *currentPat = new Pattern(currentPattern, false, -1, currentLogLL, currentObserved);
				(*this).addPattern(currentPat);
			}
		}
	} catch(bad_alloc){
			outError(ERR_NO_MEMORY);
	} catch (const char *str){
			outError(str);
	} catch (char *str){
			outError(str);
	} catch (string str){
			outError(str);
	} catch (ios::failure){
			outError(ERR_READ_INPUT);
	} catch (...){
			outError(ERR_READ_ANY);
	}
}

PatternSet::PatternSet(const StringVec &patterns)
{
	int len = patterns.size();
	for (int i = 0; i < len; i++)
	{
		Pattern *pat = new Pattern(patterns[i], false);
		(*this).addPattern(pat);
	}
}

void PatternSet::print2Align(StringVec taxaList, ostream &out) const
{
	int patNum = (*this).getPatNum();
// 	cout << "print2Align, number of pattern: " << patNum << endl;
	if (patNum == 0)
	{
		cout << "Error: attempting to print an empty PatternSet to an alignment file!" << endl;
	}
	else
	{
		const_iterator b_it = begin();
		int taxonNum = (*b_it)->getNTaxa();
	// 	cout << "print2Align, the first pattern: " << (*b_it)->code << endl;
	// 	cout << "print2Align, taxonNum: " << taxonNum << endl;
		assert(taxonNum == taxaList.size());		
		out << taxonNum << " " << patNum << endl;
		StringVec patterns;
		string currentPat;
		for (const_iterator it = begin(); it != end(); it++)
		{
			currentPat = (*it)->convert2Str();
			patterns.push_back(currentPat);
		}
		for (int taxonId = 0; taxonId < taxonNum; taxonId++)
		{
			int curNameSize = taxaList[taxonId].size();
			if (curNameSize >= 10)
				out << taxaList[taxonId] << " ";
			else
			{
				out << taxaList[taxonId] << " ";
				int space = 10 - curNameSize;
				for (int i = 0; i < space; i++)
					out << " ";
			}
			for (int siteId = 0; siteId < patNum; siteId++)
				out << patterns[siteId][taxonId];
			out << endl;
		}
	}
// 	cout << "Finish printing PatternSet!" << endl;
}

void PatternSet::print2Align(StringVec taxaList, const char *fileName) const
{
	try {
		ofstream out;
		out.exceptions(ios::failbit | ios::badbit);
		out.open(fileName);
		print2Align(taxaList,out);
		out.close();
		cout << "PatternSet was printed as an alignment to " << fileName << endl;
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT, fileName);
	}
}

void PatternSet::printPatternSet(ostream &out) const
{
	out << "Pattern\tNo.observed\tLogll\tmutStep\tNo.exchange" << endl;
	for (const_iterator it = begin(); it != end(); it++)
	{
		(*it)->printInfo(out);
	}
}

void PatternSet::printPatternSetMoreLess(ostream &out) const
{
	out << "Pattern\tNo.observed\tLogll\tmutStep\tNo.exchange" << endl;
	for (const_iterator it = begin(); it != end(); it++)
	{
		(*it)->printInfoMoreLess(out);
	}
}

void PatternSet::printAllPositions(ostream &out) const
{
	//out << "Pattern\tNo.observed\tLogll\tmutStep\tNo.exchange\tPositions" << endl;
	out << "Pattern\tNo.observed\tLogll\tNo.exchange\tPositions" << endl;
	for (const_iterator it = begin(); it != end(); it++)
	{
		(*it)->printPositions(out);
	}
}

/*void PatternSet::printOverInterval(ostream &outDeter, ostream &outFull, bool all) const
{	
	
	overInterSet.printIntervalSet(out);
}*/

void PatternSet::getOverInterval(IntervalSet &deterPos, IntervalSet &fullPos)
{
	cout << endl << "Determine positions being exchanged ..." << endl;	
	IntSet determinedPos;
	PatternSet unclearPosPatterns;
	for (const_iterator it = begin(); it != end(); it++)
	{
		int curExDiff = (*it)->getExDiff();
		if (curExDiff > 0)
		{
			if (curExDiff == (*it)->getObsNum()) //over positions are clearly determined
			{
				IntVec curPositions = (*it)->getPositions();
				for (IntVec::iterator posIt = curPositions.begin(); posIt != curPositions.end(); posIt++)
				{
					determinedPos.insert((*posIt));
				}
			}
			else
				unclearPosPatterns.addPattern((*it));
		}				
	}
	IntervalSet overInterSet(determinedPos);
	deterPos = IntervalSet(determinedPos);	
	
	/*ofstream determinedOut("determinedOver.txt", ios::out);
	overInterSet.printIntervalSet(determinedOut);
	determinedOut.close();*/
	if (unclearPosPatterns.empty())
	{
		fullPos = deterPos;
		return;
	}
	PatVec unclearVec = unclearPosPatterns.convert2Vector();
	std::sort(unclearVec.begin(), unclearVec.end(), obsNumCmp);
	
	//start adding unclear positions of the patterns

	//step1: get all exDiff to a vector
	IntVec exDiffVec;
	IntervalVecVec posVecVec;
	for (PatVec::iterator vIt = unclearVec.begin(); vIt != unclearVec.end(); vIt++)
	{
		exDiffVec.push_back((*vIt)->getExDiff());
		//get set of integer interval its positions spread
		IntervalSet curPosSet((*vIt)->getPositions());
		int curSize = curPosSet.size();
		//convert the set to vector of integer intervals
		IntervalVec curPosVec(curSize);	
		std::copy(curPosSet.begin(), curPosSet.end(),curPosVec.begin());
		//sort vector of integer intervals in descending order w.r.t the amount
		std::sort(curPosVec.begin(), curPosVec.end(), amountCmp);
		//put this sorted vector into posVecVec
		posVecVec.push_back(curPosVec);		
	}
	//keep going through all patterns until (1) their over positions are fully added
	//                                      (2) no strick added more
	bool finish = false;
	bool furtherImprove = true;
	int size = exDiffVec.size();
	int index = 0;
	while (!finish && furtherImprove) //okie
	{		
		int totalAdded = 0;
		finish = true;
		furtherImprove = false;
		for (int i = 0; i < size; i++)
		{
			if (exDiffVec[i] > 0)
			{
				int curExDiff = exDiffVec[i];
				overInterSet.addIntervalVec(posVecVec[i], curExDiff, false);				
				totalAdded += (exDiffVec[i] - curExDiff);
				exDiffVec[i] = curExDiff;
				if (curExDiff > 0) 
					finish = false;
			}								
		}
		if (totalAdded > 0)
			furtherImprove = true;
// 		cout << "Index: " << index << ", finish: " << (int)finish << ", furtherImprove: " << (int)furtherImprove << endl;
		index++;	
	}
	if (!finish)
	{		
		for (int i = 0; i < size; i++)
		{
			if (exDiffVec[i] > 0)
			{
				int curExDiff = exDiffVec[i];
				//NEED TO CHANGE THIS FUNCTION: Adding the intervals with least distance first --- ACTUALLY DONT NEED.
				overInterSet.addIntervalVec(posVecVec[i], curExDiff, true);
				exDiffVec[i] = curExDiff;
				if (curExDiff > 0) 
					cout << "Error in adding over positions!" << endl;
			}							
		}
	}

	fullPos = IntervalSet(overInterSet);

	/*	int testTotal = 0;
	for (IntervalSet::iterator it = overInterSet.begin(); it != overInterSet.end(); it++)
	{	
		testTotal += (*it)->getAmount();
		if ((*it)->getAmount() >= 2)
			out << (*it)->getBegin() << "-" << (*it)->getEnd() << endl;
		else
			out << (*it)->getBegin() << endl;
	}
	cout << "Total amount of patterns being over presented: " << testTotal << endl;*/
	cout << "Finish determining positions being exchanged!" << endl;
}

void PatternSet::printOverPositions(ostream &out) const
{
	cout << "\nPrinting positions of over-represented patterns ...." << endl;
	set<int,std::less<int> > allPositions;
	int total = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		if ((*it)->getExDiff()>0)
		{
			total++;
			IntVec curPositions = (*it)->getPositions();
			for (IntVec::iterator posIt = curPositions.begin(); posIt != curPositions.end(); posIt++)
			{				
				int currentpos = (*posIt);
				allPositions.insert(currentpos);
			}
		}
	}
		
	cout << "Number of over-represented patterns: " << total << ", total amount: " << allPositions.size() << endl;	
	for (set<int, std::less<int> > :: iterator setIt = allPositions.begin(); setIt != allPositions.end(); setIt++)
	{ 		
		out << (*setIt) << endl;
	}	
}

PatternSet& PatternSet::operator+= (const PatternSet &apatSet)
{
// 	cout << "BEGIN: PatternSet::operator+=" << endl;
	if (apatSet.empty())
		return (*this);

	if (!(*this).empty())
	{
		iterator it = begin();
		const_iterator ait = apatSet.begin();
		assert((*it)->getNTaxa() == (*ait)->getNTaxa());
	}

	for (PatternSet::const_iterator ait = apatSet.begin(); ait != apatSet.end(); ait++)
	{
		(*this).addPattern((*ait));
	}
	return (*this);
// 	cout << "END: PatternSet::operator+=" << endl;
}

void PatternSet::addPattern(Pattern *apat)
{
//      cout << "\npattern in addPattern: " << apat->convert2Str() << endl;
//      cout << "BEGIN: PatternSet::addPattern" << endl;
	Pattern *pat = new Pattern(*apat);
	if (empty())
	{
		(*this).insert(pat);
	}
	else
	{
		iterator it = begin();
		assert((*it)->getNTaxa() == pat->getNTaxa());
		(*this).insert(pat);
	}
//      cout << "END: PatternSet::addPattern" << endl;
}

void PatternSet::updateLogll (const char* inFile)
{
/*	cout << "\nReading file containing site's loglikelihood: " << inFile << "...." << endl;
    ifstream in;
	try{
		in.exceptions (ios::failbit | ios::badbit);
		in.open(inFile);
		updateLogll(in);
		in.clear();
		in.exceptions (ios::failbit | ios::badbit);
		in.close();
	} catch (ios::failure){
		outError(ERR_READ_INPUT, inFile);
	}
	cout << "Finish reading site's loglikelihood!" << endl;	*/
	DoubleVec sitelh;
	readSitelh(inFile,sitelh);
	updateLogll(sitelh);
}

/*void PatternSet::updateLogll(ifstream &inFile)
{
	string currentLogLLStr;
	double currentLogLL;
	PatternSet::iterator it = begin();
	try{
		//ignore the first line and then the first string of the second line (name of the tree)
		inFile.ignore(MAX_NUM_SPACE,'\n');
		inFile >> currentLogLLStr;		
		while (!inFile.eof())
		{
			//reading each line of the file
			//remove the badbit
			inFile.exceptions (ios::badbit);
			if ( !(inFile >> currentLogLLStr) ) break;
			//set the failbit again
			inFile.exceptions (ios::failbit | ios::badbit);

			//if the pattern is gap-free, take it into account
			if (it != end())
			{				
				currentLogLL = convert_double(currentLogLLStr.c_str());
				(*it)->setLogll(currentLogLL);
			}
			else
				outError("Number of patterns in PatternSet is less than number of log likelihood entries in .slh file");
			it++;
		}
	} catch(bad_alloc){
			outError(ERR_NO_MEMORY);
	} catch (const char *str){
			outError(str);
	} catch (char *str){
			outError(str);
	} catch (string str){
			outError(str);
	} catch (ios::failure){
			outError(ERR_READ_INPUT);
	} catch (...){
			outError(ERR_READ_ANY);
	}
}*/

void PatternSet::updateLogll (const DoubleVec slhVec)
{
	int vecSize = slhVec.size();
	assert(vecSize == (*this).getPatNum());
	int index = 0;
	for (iterator it = begin(); it != end(); it++, index++)
	{
		(*it)->setLogll(slhVec[index]);
	}
}
	
bool PatternSet::checkObsNum() const
{
	for(const_iterator it = begin(); it != end(); it++)
	{
		if ((*it)->getObsNum() != (*it)->positions.size())
			return false;
	}
	return true;
}

void PatternSet::updatePositions(StringVec sequences, bool incObsNum)
{
	if (sequences.empty()) return;

	int seqNum = sequences.size();
	iterator it = begin();
	assert(seqNum == (*it)->getNTaxa());
	int seqLen = (int) sequences[0].length();
	for (int siteIndex = 0; siteIndex < seqLen; siteIndex++)
	{
		string currentPat = string();
		for (int seqIndex = 0; seqIndex < seqNum; seqIndex++)
			currentPat.push_back(sequences[seqIndex][siteIndex]);		
		//if the pattern is gap-free, take it into account
		if (strcspn(currentPat.c_str(), UGAP) == strlen(currentPat.c_str()))
		{			
			Pattern *apat = new Pattern(currentPat,false);
			PatternSet::iterator foundId = (*this).find(apat);
			if (foundId != (*this).end())
			{				
				(*foundId)->addPosition(siteIndex, incObsNum);				
			}			
		}
	}
}

int PatternSet::getObsAmount() const
{
	int ret = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		ret += (*it)->getObsNum();
	}
	return ret;
}

void PatternSet::removeAll()
{
/*	if (!empty())
	{		
		for (reverse_iterator it = rbegin(); it != rend(); it++)
		{
			if ((*it) != NULL)
			{
				//cout << "Pattern " << i << " is not NULL!" << endl;
 				delete (*it);
// 				(*it).~Pattern();
//  				(*it) = NULL;
			}
		}
		clear();
	}
	else
	{
		cout << "removeAll(): PatternSet is empty!" << endl;
	}
	cout << "finish removeAll in PatternSet!" << endl;*/
}

void PatternSet::updateExDiff(int df)
{
// 	cout << "df: " << df << endl;
	int seqLen = getObsAmount();
// 	cout << "seqLen: " << seqLen << endl;
//  	double kappa = QnormTable[seqLen-1];
	double kappa;
	if (df > 0) // degree of freedom is provided
	{
		kappa = sqrt(invchisquaredistribution(df, alpha/(2*seqLen))); // use Chi-square distr.
	}
	else kappa = invnormaldistribution(1-alpha/(2*seqLen)); // df is not provided, use normal distr.
// 	cout << "updateExDiff, df: " << df << ", seqLen: " << seqLen << ", kappa: " << kappa << endl; 	
// 	double kappa = 1.959964;
	for (iterator it = begin(); it != end(); it++)
	{
		(*it)->updateExDiff(seqLen,kappa);
	}
}

void PatternSet::updateExAmount(const int seqLen, const double overMaxll, int df)
{
//  	cout << "df: " << df << ", seqLen: " << seqLen << endl;
//   	double old_kappa = QnormTable[seqLen-1]; // old version: used QnormTable
	double kappa;
	if (df > 0) // degree of freedom is provided
	{
		kappa = sqrt(invchisquaredistribution(df, alpha/(2*seqLen))); // use Chi-square distr.
	}
	else kappa = invnormaldistribution(1-alpha/(2*seqLen)); // df is not provided, use normal distr.
// 	cout << "old_kappa (normal): " << old_kappa << ", new kappa: " << kappa << endl;
// 	double kappa = 1.959964;
	//from Wald confidence interval, a pattern would be observed if its likelihood is greater than the following value
	double lowerP = 2/( (2+pow(kappa,2))*seqLen + kappa*sqrt(seqLen)*sqrt((4+pow(kappa,2))*seqLen -4) );

	double overMaxP = exp(overMaxll);
	
//  	cout << "lowerP: " << lowerP << ", overMaxP: " << overMaxP << endl;
	if (lowerP < overMaxP && overMaxP != 1)
		lowerP = overMaxP;
	
	for (iterator it = begin(); it != end(); it++)
	{
		(*it)->updateExAmount(seqLen,lowerP,kappa);
	}
}

double PatternSet::computeSumLogll() const
{
	double sumLogll = 0;
	double factor = 1;
	for (const_iterator it = begin(); it != end(); it++)
	{
		if ((*it)->getExDiff() > 0)
			factor = (*it)->getExDiff();
		/*else if ((*it)->getExAmount() > 0)
			factor = (*it)->getExAmount();*/
		else
			factor = (*it)->getNumExchange(); //exAmount - obsNum
		sumLogll += factor * (*it)->getLogll();
	}
}
	
void PatternSet::getMorePatterns(PatternSet &moreSet) const
{
	for (const_iterator it = begin(); it != end(); it++)
	{
		if ((*it)->getExDiff() > 0)
			moreSet.addPattern((*it));
	}
}

void PatternSet::getLessPatterns(PatternSet &lessSet) const
{
	for (const_iterator it = begin(); it != end(); it++)
	{
// 		if ((*it)->getExDiff() < 0 && (*it)->getExAmount() >0)
// 			outError("Internal error: exDiff < 0 && exAmount > 0 in pattern: ", (*it)->convert2Str());
		if ((*it)->getExDiff() < 0 || (*it)->getNumExchange() > 0)
			lessSet.addPattern((*it));
	}
}
	
int PatternSet::getTotalExAmount() const
{
	int ret = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		ret += (*it)->getExAmount();
	}
	return ret;
}

int PatternSet::getTotalExchangeAmount() const
{
	int ret = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		ret += (*it)->getNumExchange();
	}
	return ret;	
}

void PatternSet::getMoreAmount(IntVec &moreAmounts, int &moreNum, int &totalMoreNum) const
{
	IntVec _moreAmounts;
	int _moreNum = 0;
	int _totalMoreNum = 0;	
	for (const_iterator it = begin(); it != end(); it++)
	{
		int curExDiff = (*it)->getExDiff();
		if ( curExDiff > 0 )
		{
			_moreNum++;
			_totalMoreNum += curExDiff;
			_moreAmounts.push_back(curExDiff);
		}
	}
	//return
	moreAmounts = _moreAmounts;
	moreNum = _moreNum;
	totalMoreNum = _totalMoreNum;
}
		
void PatternSet::getLessAmount(IntVec &lessAmounts, int &lessNum, int &totalLessNum) const
{
	IntVec _lessAmounts;
	int _lessNum = 0;
	int _totalLessNum = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		int curExDiff = (*it)->getExDiff();
		if (curExDiff < 0)
			{
				_lessNum++;
				_totalLessNum -= curExDiff;
				_lessAmounts.push_back(-curExDiff);
			}
	}
	//return
	lessAmounts = _lessAmounts;
	lessNum = _lessNum;
	totalLessNum = _totalLessNum;
}

void PatternSet::getExchangeAmount(IntVec &exchangeAmounts, int &exchangeNum, int &totalExchangeNum) const
{
	IntVec _lessAmounts;
	int _lessNum = 0;
	int _totalLessNum = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		int curNumExchange = (*it)->getNumExchange();
		if (curNumExchange > 0)
		{
			_lessNum++;
			_totalLessNum += curNumExchange;
			_lessAmounts.push_back(curNumExchange);
		}
	}
	//return
	exchangeAmounts = _lessAmounts;
	exchangeNum = _lessNum;
	totalExchangeNum = _totalLessNum;
}

/*void PatternSet::updateMutStep(Tree *atree)
{
	for (iterator it =  begin(); it != end(); it++)
	{
		(*it)->updateMutStep(atree);
	}
}*/

IntVec PatternSet::getMutStepVec() const
{
	IntVec ret;
	int max=-1;
	for (const_iterator it = begin(); it != end(); it++)
	{
		if (max < (*it)->getMutStep()) 
			max = (*it)->getMutStep();
	}
	ret = IntVec(max+1,0);
	for (const_iterator it = begin(); it != end(); it++)
	{
		ret[(*it)->getMutStep()+1]++;
	}
}

double PatternSet::getMaxll() const
{	
	//derive the maximal log likelihood (overMaxll) of over represented patterns
	const_iterator beginIt = begin();
	//initialize overMaxll
	double overMaxll = 0;
	for (const_iterator it = begin(); it != end(); it++)
	{
		if ((*it)->getObsNum() == 1)
		{
			if (overMaxll == 0)
				overMaxll = (*it)->getLogll();
			else
				if (overMaxll < (*it)->getLogll())
					overMaxll = (*it)->getLogll();
		}		
	}
	return overMaxll;
}

PatVec PatternSet::convert2Vector()
{
	PatVec patVec(size());
	std::copy(begin(),end(),patVec.begin());	
	return patVec;
}

PatternSet::~PatternSet()
{
//      cout << "Start delete pattern set!" << endl;
//         removeAll();
//      cout << "Finish delete pattern set!" << endl;
}


