/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PATTERNSET_H
#define PATTERNSET_H

#include <set>
#include "utility.h"
#include "pattern.h"
#include "intinterval.h"
#include "intervalset.h"
#include "normaldistr.h"
#include "chisquaredistr.h"

namespace std {
	/**
		Define less than relationship of two patterns, used for set template
	*/
	template<>
	struct less<Pattern*> {
		/**
			@return true if *p1 < *p2 alphabetically
			@param p1 first split
			@param p2 second split
		*/
		bool operator()(const Pattern *p1, const Pattern *p2) const 
		{
			assert(p1->getNTaxa() == p2->getNTaxa());
			return (p1->getCode() < p2->getCode());	
		}
	};
} // namespace std

/**
Defining a set of pattern, use template <set>

	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/
class PatternSet: set <Pattern*, std::less<Pattern*> >
{
public:
	friend class Split;
    friend class SplitSet;
	friend class Process;	
    PatternSet(): set<Pattern*, std::less<Pattern*> >(){};

	/**
		construction from a list of sequences and a file containing corresponding site's likelihood
		@param sequences a vector of strings corresponding to a set of sequences
		@param sitelhFile a file contains site's likelihood
	*/
	PatternSet(const StringVec sequences, const char *inFile);

	/**
		add patternSet from a list of sequences and a file containing corresponding site's likelihood
		@param sequences a vector of strings corresponding to a set of sequences
		@param sitelhFile a file contains site's likelihood
	*/
	void readPatternSet(const StringVec sequences, const char *inFile);

	/**
		construction from a file in format of .iqpnni.patlh
		obsNum and loglikelihood will be updated.
		@param file input file, in format of .iqpnni.patlh
	*/
	PatternSet(const char *file);

	/**
		add patternSet from a file in format of .iqpnni.patlh
		obsNum and loglikelihood will be updated.
		@param file input file, in format of .iqpnni.patlh
	*/
	void readPatternSet(const char *file);
	
	/**
		used for construction from a file in format of .iqpnni.patlh
		set of patterns, obsNum and loglikelihood will be updated.
		@param in input stream in format of .iqpnni.patlh
	*/
	void readPatternSet (ifstream &in);

	/**
		construction from a vector of patterns.
	*/	
	PatternSet(const StringVec &patterns);

	/**
		print this set of patterns to an out stream as an alignment under sequential PHYLIP format.
		@param taxaList taxon's name list
		@param out output stream
	*/
	void print2Align(StringVec taxaList, ostream &out) const;

	/**
		print this set of patterns to a file as an alignment under sequential PHYLIP format.
		@param taxaList taxon's name list
		@param fileName name of output file
	*/
	void print2Align(StringVec taxaList, const char *fileName) const;

	/**
		print pattern set
		@param out output stream
	*/
	void printPatternSet(ostream &out) const;
	
	/**
		print pattern set in the format:
		Pattern	\t No.Observed \t mutStep \t Logll \t No.exchange
		@param out output stream
	*/
	void printPatternSetMoreLess(ostream &out) const;

	/**
		print all positions of each pattern in this pattern set
		NOTE: file will contain number of patterns lines.
		Each line begin by the pattern, then obsNum, then exDiff, then obsNum numbers corresponding to all positions of this pattern in the alignment.
		@param out output stream
	*/
	void printAllPositions(ostream &out) const;

	/**
		print all positions of all over-represented patterns in increasing order.
		The number of positions printed may be more than the total amount of positions should be replaced.
		@param out output stream
	*/
	void printOverPositions(ostream &out) const;

	/**
		print over represented positions in consecutive intervals. This will highlight misfit position in the alignment.
		NOTE: number of positions printed equals total amount of over positions.
		@param out output stream to report determined positions
		@param outFull output stream to report all positions which should be replaced
	*/
//  	void printOverInterval(ostream &outDeter, ostream &outFull, bool all = false) const;

	/**
		add a pattern to this set
		@param apat a pattern to be add		
	*/
	void addPattern(Pattern *apat);
	
	/**
		add all pattern from another set to this set
		@param apatSet a pattern set
	*/
	PatternSet &operator+= (const PatternSet &apatSet);

	/**
		update logll from file. This file is the output of tree-puzzle for site-likelihood.
		Format [name of tree, e.g. Tr_1] site-likelihood ==> all in one line
		@param slhFile file contains site log-likelihood
	*/
	void updateLogll (const char* slhFile);

	/**
		update logll from an input stream. This stream is in format similar to the file containing site-log likelihood from tree puzzle.
		Format [name of tree, e.g. Tr_1] site-likelihood ==> all in one line
		@param slhIn stream contains site log-likelihood
	*/
// 	void updateLogll(ifstream &slhIn);

	/**
		update logll from a double vector containing corresponding log likelihood
		@param slhVec double vector contains corresponding log-likelihood for this set of patterns.
	*/
	void updateLogll (const DoubleVec slhVec);

	/**
		check to see whether obsNum equals to number of occurence of each patterns in the alignment. Check obsNum == positions.size() ?
	*/
	bool checkObsNum() const;

	/**
		given a vector of sequences. Update positions of each pattern in the PatternSet in this vector of sequences. This is used for patterns from the alignment.
		@param sequences vector of sequences.
		@param incObsNum determine whether or not increase obsNum by 1 for each pattern. Default is FALSE, NOT increase.
	*/
	void updatePositions(StringVec sequences, bool incObsNum = false);

	/**
		compute amount of over/under represented patterns. This is used for patterns from the alignment only.
	*/
	void updateExDiff(int df = 0);

	/**
		compute and update mutation step from a tree for all patterns in this set
		@param atree the given tree		
	*/
//  	void updateMutStep(Tree *atree);	

	/**
		compute expected number of occurence for generated patterns. We need loglikelihood of the patterns and sequence's length
		@param seqLen length of (gap-free) alignment sequence.
		@param overMaxll maximal log likelihood of over represented pattern. A generated pattern can be added to D- if its log likelihood > max(overMaxll,min(upperBound of confident iterval))
	*/
	void updateExAmount(const int seqLen, const double overMaxll, int df=0);
	
	/**
		to copy over-represented patterns (in the alignment) to an other set after exDiff have been updated.
		@param moreSet (OUT) the returned set
	*/
	void getMorePatterns(PatternSet &moreSet) const;

	/**
		to copy under-represented patterns (in the alignment) to an other set after exDiff have been updated.
		@param lessSet (OUT) the returned set
	*/
	void getLessPatterns(PatternSet &lessSet) const;
	
	/**
		sum up all expected number of occurence (of generated patterns). Should be used after exAmount(s) are updated.
	*/
	int getTotalExAmount() const;

	/**
		to extract amount of a pattern being over represented.
		@param moreAmounts (OUT) the vector containing amount of patterns being over represented.
		@param moreNum (OUT) number of over represented patterns.
		@param totalMoreNum (OUT) total amount of over represented patterns. 
	*/
	void getMoreAmount(IntVec &moreAmounts, int &moreNum, int &totalMoreNum) const;
	
	/**
		to extract amount of a pattern being under represented (this pattern can be an observed one or a generated one).
		@param lessAmounts (OUT) the vector containing amount of patterns being under represented.
		@param lessNum (OUT) number of under represented patterns.
		@param totalLessNum (OUT) total amount of under represented patterns. 
	*/
	void getLessAmount(IntVec &lessAmounts, int &lessNum, int &totalLessNum) const;

	/**
		to extract amount of pattern (in the confidence interval and its obsNum still less than upperbound). Those patterns will be used to replace over-represent patterns
		@param exchangeAmounts (OUT) the vector containing amount of units can be exchanged
		@param exchangeNum (OUT) number of patterns can be exchanged
		@param totalExchangeNum (OUT) total amount of units that can be exchanged
	*/
	void getExchangeAmount(IntVec &exchangeAmounts, int &exchangeNum, int &totalExchangeNum) const;

	/**
		return sum of log likelihood of all patterns in the set
	*/
	double computeSumLogll() const;

	/**
		extract mutation step for this patternSet
		output is formatted as followings:
		IntVec[0]: #patterns with mutStep -1, undefined
		IntVec[1]: #patterns with mutStep 0, constant patterns
		...
		IntVec[i]: #patterns with mutStep i-1
	*/
	IntVec getMutStepVec() const;
	
	/**
		to determined which positions in the alignment should be replace
		@param deterPos (OUT) the positions of patterns having expectation = 0
		@param fullPos (OUT) deterPos + positions that should be replaced of patterns having obsNum > expectation > 0
	*/
	void getOverInterval(IntervalSet &deterPos, IntervalSet &fullPos);

	/**
		return number of patterns in this set
	*/
	inline int getPatNum() const
	{
		return (*this).size();
	}

	/**
		return total amount of obsNum, this is equal to (gap-free) sequence length in the alignment.
	*/
	int getObsAmount() const;

	/**
		get sum of (exAmount - obsNum)
	*/
	int getTotalExchangeAmount() const;

	/**
		return the maximal log likelihood of the patterns which should not be seen in the alignment
	*/
	double getMaxll() const;

	/**
		convert this set to vector
	*/
	PatVec convert2Vector();

	/**
		remove all pattern in the set
	*/
	void removeAll();

    ~PatternSet();

};

#endif
