/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "process.h"

Process::Process(Params _params)
{
	moreNum = 0;
	lessNum = 0;
	alignLessNum = 0;
	totalMoreNum = 0;
	totalLessNum = 0;
	totalAlignLessNum = 0;
	actualCost = -1;

	df = 0;
	enoughPat = false;
		
	lessPatterns = PatternSet();
	lessAmounts = IntVec();
	mutScoreMatrix = IntMatrix();

	init(_params);
}

Process::~Process()
{
/*	delete align;
	delete tree;
	delete bMinCost;
	splitSet.~SplitSet();	*/
/*	morePatterns.clear();
	moreAmounts.clear();
	lessPatterns.clear();
	lessAmounts.clear();*/
}

void Process::init(Params _params)
{
 	params = _params;

	//reading alignment	
 	align = new Alignment(params.alignFile);

	//reading tree
  	tree = new Tree(params.treeFile);
	//updating sequenceID	
  	tree->updateSeqID(align->seqNames);	
	//updating root of the tree	
  	tree->updateRoot(params.outgroup);		
	
	//if tree is not bifurcating ==> stop
	bool notBifurcating = false;	
	tree->checkValidTree(notBifurcating);

	if (notBifurcating == true)
		outError(ERR_NOT_BIFURCATING);

	//reading file containing pattern, number of occurences and loglikelihood
	if (params.patFile != NULL)
	{
 		alignPatterns = PatternSet(params.patFile);
		//update positions of each patterns in the alignment
 		alignPatterns.updatePositions(align->sequences);
	}
	else //run puzzle to compute site's likelihood for the original alignment
	{
		char prefix[MAX_FILE_NAME];
		int temp;
		//form the prefix
		temp = sprintf(prefix,"puzzle-%s", params.uprefix);		
		//prepare command line to run tree-puzzle
		string tpCommand("puzzle -usebranch -wsl "); 		
		tpCommand += params.alignFile;
		tpCommand += " ";
		tpCommand += params.pztree;
		tpCommand += " -prefix=";
		tpCommand += prefix;
		tpCommand += " < ";
		tpCommand += params.puzzleFile;
		tpCommand += " 2>&1 > ";
		tpCommand += prefix;
		tpCommand += ".puzzle.log";
		cout << "Running puzzle with alignment file: " << params.alignFile << endl;
// 		cout << "puzzle-command: " << tpCommand << endl;
		system(tpCommand.c_str());
		
		//name of the file containing site's likelihood
		char sitelhFile[MAX_FILE_NAME];
		temp = sprintf(sitelhFile, "%s.sitelh", prefix);
		//construct alignPatterns from align->sequences and the file containing site's likelihood
		alignPatterns = PatternSet(align->sequences, sitelhFile);
		
		//remove files produced by puzzle
		char tempFile[MAX_FILE_NAME];
		temp = sprintf(tempFile,"%s.dist", prefix);
		if ( remove(tempFile) != 0)
			outError("in deleting file: ", tempFile);
		temp = sprintf(tempFile,"%s.tree", prefix);
		if ( remove(tempFile) != 0)
			outError("in deleting file: ", tempFile);
		temp = sprintf(tempFile,"%s.puzzle", prefix);
		if ( remove(tempFile) != 0)
			outError("in deleting file: ", tempFile);
		temp = sprintf(tempFile,"%s.puzzle.log", prefix);
		if ( remove(tempFile) != 0)
			outError("in deleting file: ", tempFile);		
	}
	
	//update mutation step for all patterns in the alignment
 	for (PatternSet::iterator it = alignPatterns.begin(); it != alignPatterns.end(); it++)
	{
		int curStep = tree->mutScore((*it),true);
		(*it)->setMutStep(curStep);
	}	
	
	patNum = alignPatterns.getPatNum();
	seqLen = alignPatterns.getObsAmount();
	cout << "File contains " << patNum << " distinct gap-free patterns. Gap-free sequence's length: " << seqLen << endl;

 	if (!alignPatterns.checkObsNum())
 		outError("Amount of gap-free patterns in the alignment and in .sitelh file are not consistent! Check your data again!");

	//degree of freedom
	df = params.mdf + (int)params.ciBr * (2 * align->ntaxa - 3);

	//compute/update over/under represented patterns in the alignment
	alignPatterns.updateExDiff(df);

	//derive over represented patterns in the alignment
	morePatterns = PatternSet();
	alignPatterns.getMorePatterns(morePatterns);
	if (morePatterns.getPatNum() > 0)
	{
		moreAmounts = IntVec();	
		alignPatterns.getMoreAmount(moreAmounts, moreNum, totalMoreNum);
	}

	//derive under represented patterns in the alignment
	alignLessPatterns = PatternSet();
	alignPatterns.getLessPatterns(alignLessPatterns);
	if (alignLessPatterns.getPatNum() > 0)
	{
		alignLessAmounts = IntVec();
		alignPatterns.getLessAmount(alignLessAmounts, alignLessNum, totalAlignLessNum);
	}

	cout << "\nIn the alignment: number of over-represented patterns: " << moreNum << ", total sites need to be replaced: " << totalMoreNum << endl;
	cout << "                : number of observed, under-represented patterns: " << alignLessNum << ", total sites they can replace: " << totalAlignLessNum << endl;
	
	//if user wants to include observed, admissible patterns which do not yet reach their upper bound
	//into D-
	if (!params.noInit)
	{
		//update exAmount for observed patterns
		alignPatterns.updateExAmount(seqLen,0,df);
		alignPatterns.getLessPatterns(lessPatterns);
		totalAdditionNum = lessPatterns.getTotalExchangeAmount();
		cout << "                : " << lessPatterns.getPatNum() << " observed patterns not yet reach the upper bound and can replace for " << totalAdditionNum << " sites in the alignment." << endl;
	}
	else
	{
		lessPatterns = PatternSet(alignLessPatterns);
		totalAdditionNum = totalAlignLessNum;
		cout << "Under represented patterns were put into D- and can replace for " << totalAdditionNum << " sites in the alignment." << endl;
	}
	
	/*ofstream additionOut("addition.txt", ios::out);
	lessPatterns.printPatternSetMoreLess(additionOut);
	additionOut.close();*/
	
	//get all splits from the tree
	Split *sp = new Split(tree->leafNum);
	splitSet = SplitSet();
	tree->convertSplits(splitSet,sp);
// 	splitSet.print(cout);
}

void Process::generatePatterns()
{
	//derive the maximal log likelihood (overMaxll) of over represented patterns
	double overMaxll = morePatterns.getMaxll();	

	//total amount of patterns needed
	//int needed = totalMoreNum - totalAlignLessNum;	
	int needed = totalMoreNum - totalAdditionNum;
	if (needed <= 0)
	{	
		enoughPat = true;
		return;
	}

	//forming set of constant patterns
	PatternSet constPatSet;
	int taxonNum = tree->leafNum;
	string str;
	for (int i = 0; i < StateNum; i++)
	{
		str = string(taxonNum, Nucleotides[i]);
		Pattern *constPat;
		constPat = new Pattern(str,false,0);
		constPatSet.addPattern(constPat);
	}
	
	PatternSet source(constPatSet);	

	cout << "\nGenerating patterns from constant patterns to put in D- ..." << endl;		

	PatternSet genLessPatterns = PatternSet();
	
	generatePatterns(source, alignPatterns, genLessPatterns, needed);			
	//update less amount vector, total less num ..
 	lessPatterns += genLessPatterns;		

	if (needed > 0)
	{
		PatternSet genFromAlign = PatternSet();
		cout << "\nGenerating patterns from patterns in the alignment to put in D- ..." << endl;
		generatePatterns(alignPatterns,genLessPatterns, genFromAlign, needed, true);
		lessPatterns += genFromAlign;
	}	
			
/*	if (enoughPat == false)
	{
		//print all generated patterns into a file
		string tempOutFile1(params.alignFile);
		tempOutFile1 += ".misfits.genPat1";
		ofstream tempOut1(tempOutFile1.c_str());
		genLessPatterns.printPatternSetMoreLess(tempOut1);
		tempOut1.close();						
	}*/
/*	lessPatterns.getLessAmount(lessAmounts, lessNum, totalLessNum);
	cout << "Number of patterns under represented: " << lessNum << ", total amount: " << totalLessNum << endl;*/

	/**
	sort patterns in _lessPatterns in decreasing logll, then derive the set equivalent to D+
	*/
/*	PatVec lessPatVec = _lessPatterns.convert2Vector();
	std::sort(lessPatVec.begin(),lessPatVec.end(),logllCmp);

	//reset needed
// 	needed = totalMoreNum - totalAlignLessNum;
	needed = totalMoreNum - totalAdditionNum;
	if (lessPatVec[0]->getExAmount() >= needed)
	{
		Pattern *lastPattern = new Pattern(*lessPatVec[0]);
		lastPattern->exAmount = needed;
		lessPatterns.addPattern(lastPattern);
	}
	else
	{
		int tempNum = lessPatVec.size();
		//cumulative sum of exAmount in lessPatVec
		IntVec cumSum = IntVec(tempNum,0);
		int index = 1;
		cumSum[0] += lessPatVec[0]->getExAmount();
		while (index < tempNum)
		{
			cumSum[index] = cumSum[index-1] + lessPatVec[index]->getExAmount();
			if (cumSum[index] >= needed)
				break;
			else index++;		
		}
		if (index == tempNum)
			outError("internal error while deriving amount of less patterns in sorted vector. Please contact the authors!");
		for (int i = 0; i < index; i++)
		{
			lessPatterns.addPattern(lessPatVec[i]);
		}
		Pattern *lastPattern = new Pattern(*lessPatVec[index]);
		lastPattern->exAmount = needed-cumSum[index-1];
		lessPatterns.addPattern(lastPattern);
	}*/
}

//referSet: is alignPatterns if we are now generating from constant patterns, and is the already generated patterns if generating from patterns in the alignments
void Process::generatePatterns(const PatternSet& source, const PatternSet& referSet, PatternSet& retLessSet, int& neededNum, const bool recomputeMutStep)
{
	if (neededNum <= 0)
	{
		cout << "Already enough generated patterns!" << endl;
		return;
	}

	int needed = neededNum;
	
	PatternSet _source(source);
	PatternSet mainReferSet(source);	

	int mStep = 1;
	bool stop = false;

	// 	lessPatterns = PatternSet();
	PatternSet _lessPatterns = PatternSet();
// 	lessAmounts = IntVec();	

// 	int generatedAmount;

	while(!stop)
	{
		PatternSet curPatSet;
		PatternSet curInReferSet;
 		cout << "\nMutation step: " << mStep << ", amount of patterns still needed: " << needed << endl;
		
 		//unsigned long mem = (28 + align->seqNum) * 4 * pow(((2*align->seqNum-2) * 3),mStep);		
// 		unsigned long esGenNum = 4 * pow(((align->ntaxa-1) * 6),mStep);
		unsigned long esGenNum = 3 * 2*(align->ntaxa-1) * _source.getPatNum();
		unsigned long mem = (28 + align->ntaxa) * esGenNum;
		cout << "Maximal number of patterns generated at this step: " << esGenNum << endl;
		cout << "Maximal memory required for this step: " << mem << " bytes." << endl;
		if (mem > MaxMemAllow)
		{
			cout << "Too much memory storage required!" << endl;
			cout << "We stop generating patterns and move on to the next step!" << endl;
			stop = true;
			enoughPat = false;
	
// 			if (params.memStop)
// 				outError("As you wished, we stop the program!");		
		}
		else
		{
			splitSet.genPatterns(_source, mainReferSet, referSet, curPatSet, curInReferSet);
// 			curPatSet.print2Align(align->seqNames,"one_step_not_in_align.phy");
// 			curInReferSet.print2Align(align->seqNames,"one_step_in_align.phy");
			//if too many patterns are generated, need to break them into some alignments of sequence's length MaxGenAlignLen to run tree-puzzle
			int numAlign = (int)ceil((double)curPatSet.size()/(double)MaxGenAlignLen);
			cout << "Number of generated patterns at this step: " << curPatSet.size() << endl;
			cout << "Number of sub-alignments to run with puzzle: " << numAlign << endl;
			
			PatternSet::const_iterator it = curPatSet.begin();
			int curTotalAmount = 0;
			for (int j = 0; j < numAlign; j++)
			{
				PatternSet subPatSet;			
				if (j == numAlign-1)
				{
					for (PatternSet::const_iterator curIt = it; curIt != curPatSet.end(); curIt++)
						subPatSet.addPattern((*curIt));
				}
				else for (int index = 0; index < MaxGenAlignLen; index++)
				{
					subPatSet.addPattern((*it));
					it++;
				}			
				//prepare file name and command line to run tree-puzzle
				//alignment file containing generated patterns		
				char alignName[MAX_FILE_NAME];
				//prefix to run tree-puzzle
				char prefix[MAX_FILE_NAME];
				int temp;
				//form the prefix
				if (recomputeMutStep == false)
					temp = sprintf(prefix,"%s_%d_%d", params.uprefix, mStep, j);
				else
					temp = sprintf(prefix,"%s_%d_%d.fromAlign", params.uprefix, mStep, j);
				//form alignment file name
				temp = sprintf(alignName, "%s.phy", prefix);
				//derive alignment file
				subPatSet.print2Align(align->seqNames, alignName);		
				string tpCommand("puzzle -usebranch -wsl "); 		
				tpCommand += alignName;
				tpCommand += " ";
				tpCommand += params.pztree;
				tpCommand += " -prefix=";
				tpCommand += prefix;
				tpCommand += " < ";
				tpCommand += params.puzzleFile;
				tpCommand += " 2>&1 > ";
				tpCommand += prefix;
				tpCommand += ".puzzle.log";
				cout << "Running tree-puzzle with alignment file: " << alignName << endl;
// 				cout << "Command line: " << tpCommand << endl;
				system(tpCommand.c_str());
	
				//update loglikelihood of current pattern set
				char sitelhFile[MAX_FILE_NAME];
				temp = sprintf(sitelhFile, "%s.sitelh", prefix);
				subPatSet.updateLogll(sitelhFile);
				
				//remove files produced by puzzle
				char tempFile[MAX_FILE_NAME];
				temp = sprintf(tempFile,"%s.dist", prefix);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.tree", prefix);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.puzzle", prefix);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.puzzle.log", prefix);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.sitelh", prefix);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				if ( remove(alignName) != 0 )
					outError("in deleting file: ", alignName);

				//update expected number of occurence for this generated pattern set
// 				subPatSet.updateExAmount(seqLen, overMaxll,df);
				subPatSet.updateExAmount(seqLen,0,df);
				PatternSet subLessPatSet;
				subPatSet.getLessPatterns(subLessPatSet);
				
				//recompute mutStep when necessary (generate from patterns in the alignments)
				if (recomputeMutStep)
				{		
					for (PatternSet::iterator it = subLessPatSet.begin(); it != subLessPatSet.end(); it++)
					{
						int curStep = tree->mutScore((*it),true);
						(*it)->setMutStep(curStep);
					}
				}
				_lessPatterns += subLessPatSet;
				curTotalAmount += subLessPatSet.getTotalExAmount();		
			}		
			//amount of pattens is enough
			if (curTotalAmount >= needed)
			{
				stop = true;
 				enoughPat = true;
				needed = 0;		
			}
			else
			{
				if (curTotalAmount == 0) //patterns 
				{
					/*string tempOutFile(params.alignFile);
					tempOutFile += ".misfits.genPat";
					ofstream tempOut(tempOutFile.c_str());
					_lessPatterns.printPatternSetMoreLess(tempOut);
					tempOut.close();*/
					cout << "Generating patterns at step: " << mStep << endl;
// 					cout << "All patterns generated so far are written to: " << tempOutFile << endl;
					cout << "D- is not fulfilled yet. However, likelihood of generated patterns is no more greater than p*. p* is the minimum likelihood a pattern should have so that this pattern is expected to be in the alignment." << endl;
					stop = true;
 					enoughPat = false;			
				}
				else
				{		
					//update number of patterns needed
					needed -= curTotalAmount;
					//update mutation step
					mStep++;
					//update source and reference Set
					mainReferSet += curPatSet;
					mainReferSet += curInReferSet;
					
					_source = PatternSet(curPatSet);
					_source += curInReferSet;
				}
			}
		}
	}
	cout << "Patterns are generated up to " << mStep << "-step mutation, number of site patterns still need is: " << needed << endl;
	
/*	int tempi;
	char tempOutName[MAX_FILE_NAME];
	if (recomputeMutStep == false)
	{
		tempi = sprintf(tempOutName,"%s.misfits.fromConst.genPat", params.alignFile);
		cout << "Patterns generated from constant patterns are written to: " << tempOutName << endl;
	}
	else
	{		
		tempi = sprintf(tempOutName,"%s.misfits.fromAlign.genPat", params.alignFile);			
		cout << "Patterns generated from observed patterns are written to: " << tempOutName << endl;		
	}
	ofstream tempOut(tempOutName);
	_lessPatterns.printPatternSetMoreLess(tempOut);
	tempOut.close();*/
	//return values
	retLessSet += _lessPatterns;
	neededNum = needed;		
}

void Process::runProcess()
{
	//if the user wants to print additional information
	generatePatterns(params.mstep);

	generatePatterns();
	// the final less patterns (generated ones + the one in the alignments with p>p* and obsNum < upper(obsNum))
	lessPatterns.getExchangeAmount(lessAmounts, lessNum, totalLessNum);
	cout << "\nNumber of under represented patterns and generated patterns: " << lessNum << ", total sites they can replace: " << totalLessNum << endl;

	if (enoughPat == false) // not enough patterns in D-
	{
		//take the subset of over-represented patterns (small log likelihood first) those total units is equal to total units of patterns in D-
		//first sort D+ in increasing order of log likelihood

		cout << "Generated patterns are not enough to replace for over-represented patterns in D+. " << endl;
		cout << "We are now deriving the subset of D+ that can be matched with D-." << endl;
		PatVec morePatVec = morePatterns.convert2Vector();
		std::sort(morePatVec.begin(),morePatVec.end(),logllCmpLess);
		
		PatternSet subMorePatterns = PatternSet();
		int affordableUnits = totalLessNum;
		if (affordableUnits == 0)
		{
			cout << "No under-represented patterns after generating!" << endl;			
			return;
		}
		if (morePatVec[0]->getExDiff() >= affordableUnits)
		{
			Pattern *lastPattern = new Pattern(*morePatVec[0]);
			lastPattern->exDiff = affordableUnits;
			subMorePatterns.addPattern(lastPattern);
		}
		else
		{
			int tempNum = morePatVec.size();
			//cumulative sum of exDiff in morePatVec
			IntVec cumSum = IntVec(tempNum,0);
			int index = 1;
			cumSum[0] += morePatVec[0]->getExDiff();
			while (index < tempNum)
			{
				cumSum[index] = cumSum[index-1] + morePatVec[index]->getExDiff();
				if (cumSum[index] >= affordableUnits)
					break;
				else index++;		
			}
			if (index == tempNum)
				outError("internal error while deriving amount of more patterns in sorted vector. Please contact the authors!");
			for (int i = 0; i < index; i++)
			{
				subMorePatterns.addPattern(morePatVec[i]);
			}
			Pattern *lastPattern = new Pattern(*morePatVec[index]);
			lastPattern->exDiff = affordableUnits-cumSum[index-1];
			subMorePatterns.addPattern(lastPattern);
// 			outError("not enough patterns in D-!");
		}
		
		//print subMorePatterns into a file
		int tempi;
		char tempOutName[MAX_FILE_NAME];
		tempi = sprintf(tempOutName,"%s.misfits.subMorePat", params.uprefix);
		cout << "Subset of over-represented patterns are written to " << tempOutName << endl;			
		ofstream tempOut(tempOutName);
		subMorePatterns.printPatternSetMoreLess(tempOut);
		tempOut.close();

		//update morePatterns to subMorePatterns
		morePatterns = PatternSet();
		morePatterns = PatternSet(subMorePatterns);
		if (morePatterns.getPatNum() > 0)
		{
			moreAmounts = IntVec();	
			morePatterns.getMoreAmount(moreAmounts, moreNum, totalMoreNum);
		}
	}
	cout << "Number of over-represented patterns going to the matching: " << moreNum << ", number of sites are replaced: " << totalMoreNum << endl;
	//compute mutation pair score matrix	
	IntMatrix _scoreMatrix;

  	clock_t t_begin, t_end1, t_end2, t_end3;
	
 	t_begin = clock();

	cout << "\nComputing pairwise (morePattern, lessPattern) mutation cost ...." << endl;
	int maxScore = 0;
	int mIndex = 0;
	for (PatternSet::const_iterator moreIt = morePatterns.begin(); moreIt != morePatterns.end(); moreIt ++)
	{	int lIndex = 0;
		IntVec rowScore;
		for (PatternSet::const_iterator lessIt = lessPatterns.begin(); lessIt != lessPatterns.end(); lessIt ++)
		{
			//calcuate mutation cost from pat1 to pat2 on tree
			int tempCost = tree->mutScore((*moreIt), (*lessIt));			
			rowScore.push_back(tempCost);
			if (tempCost > maxScore)
				maxScore = tempCost;
			lIndex++;
		}
		_scoreMatrix.push_back(rowScore);
		mIndex++;
	}

 	t_end1 = clock();
 	params.mutRunTime = t_end1 - t_begin;

	cout << "Finish computing pairwise mutation cost." << endl;
 	cout << "Time used 1st part: " << (double)params.mutRunTime / CLOCKS_PER_SEC << " seconds." << endl;
	
	//return
	mutScoreMatrix = _scoreMatrix;

	/**
	if totalLessNum > totalMoreNum ==> create fake vertex in D+!!
	*/
	if (totalLessNum > totalMoreNum)
	{
		moreAmounts.push_back(totalLessNum - totalMoreNum);		
		maxScore *= 3;
		IntVec fakeScore(lessNum,maxScore);
		mutScoreMatrix.push_back(fakeScore);
	}
		
	cout << "\nComputing the matching ...." << endl;
	bMinCost = new BipartiteMinCost(moreAmounts, lessAmounts, mutScoreMatrix);
 	bMinCost->solve();	
	
 	t_end2 = clock();	
 	params.bmcRunTime = t_end2 - t_end1;
	cout << "Finish computing the matching." << endl;
	
	actualCost = bMinCost->totalCost;
	if (totalLessNum > totalMoreNum)
		actualCost -= (totalLessNum - totalMoreNum) * maxScore;
	cout << "Total cost: " << actualCost << endl;
		/**
			RE-CHECK
		*/
		//for misfits-simu
		/*int tempi1;
               	char tempOutName1[MAX_FILE_NAME];
                tempi1 = sprintf(tempOutName1,"%s.misfits.score", params.uprefix);
                ofstream tempOut1(tempOutName1);
		tempOut1 << actualCost;
                tempOut1.close();	*/
 	cout << "Time used 2nd part: " << (double)params.bmcRunTime / CLOCKS_PER_SEC << " seconds." << endl;

	if (params.ass == true)
	{				
		cout << "\nAssigning mutations on branches ..." << endl;
		int moreIndex = 0;		
		for (PatternSet::const_iterator moreIt = morePatterns.begin(); moreIt != morePatterns.end(); moreIt++)
		{
			int lessIndex = 0;
			for (PatternSet::const_iterator lessIt = lessPatterns.begin(); lessIt != lessPatterns.end(); lessIt++)
			{
// 				cout << "moreIndex: " << moreIndex << ", lessIndex: " << lessIndex << endl;			
				//two pattern are matched
				if (bMinCost->d[moreIndex][lessIndex] > 0)
				{					
					int tempCost = tree->mutScore((*moreIt), (*lessIt));
					tree->getFinalFitchSet();
					tree->assignAllCharSet();
					tree->computeMinMaxExBrCost();
					//assign mutations on branches favoring long internal branches
					tree->assignMutOnBr(bMinCost->d[moreIndex][lessIndex]);
					//assign mutations on branches favoring long external branches
					tree->assignMutOnBr(bMinCost->d[moreIndex][lessIndex], 0, NULL, NULL, false);
				}
				lessIndex++;	
			}
			moreIndex++;			
		}
	
		//after all, nomalize branch length by sequence's length
	// 	tree->normalizeBrCost(align->seqLen);
 		t_end3 = clock();
 		params.assRunTime = t_end3 - t_end2;
		cout << "Finish assigning mutations on branches." << endl;
 		cout << "Time used 3rd part: " << (double)params.assRunTime / CLOCKS_PER_SEC << " seconds." << endl;
		tree->resetBrId();
	}
}

void Process::printOutput()
{	
	params.outAll += params.uprefix;
	params.outScore += params.uprefix;
	
	params.outLess += params.uprefix;
// 	params.outMatching += params.uprefix;
// 	params.outScoreMatrix += params.uprefix;
	
	
	params.outAll += ".misfits";
	params.outScore += ".misfits.cost";	
	params.outLess += ".misfits.less";
// 	params.outMatching += ".misfits.matching";
// 	params.outScoreMatrix += ".misfits.pairScore";

/*	string finalMoreLess = params.uprefix;
	finalMoreLess += ".misfits.finalMoreLess";*/

	try {
		//summary output
		ofstream allOut;
		allOut.exceptions(ios::failbit | ios::badbit);
		allOut.open(params.outAll.c_str());
		allOut << "Number of gap-free sites (or gap-free alignment length): " << seqLen << "." << endl;
		allOut << "Number of distinct patterns: " << patNum << "." << endl;
		allOut << "Number of patterns observed more than expected (D+): " << moreNum << ", total sites need to be replaced: " << totalMoreNum << "." << endl;
		allOut << "Number of patterns in the alignment observed less than expected: " << alignLessNum << ", total sites they can replace: " << totalAlignLessNum << endl;
		allOut << "Number of all patterns observed less than expected (D-): " << lessNum << ", total sites they can replace: " << totalLessNum << "." << endl;
// 		allOut << "Total mutation cost: " << bMinCost->totalCost << "." << endl;
		allOut << "Total number of extra-substitutions: " << actualCost << endl;
		if(params.ass)
		{
			allOut << "Tree with branch label or id, note that the branch from the root to its ancestor is 0:" << endl;
			tree->printTreeWithBrId(allOut);
			allOut << endl;
			allOut << "Tree with branch length favoring long internal branches (ACCTRAN): " << endl;
			tree->printTreeWithMut(allOut);
			allOut << endl;
			allOut << "Amount of each type of mutations on the braches favoring long internal branches (ACCTRAN): " << endl;
			allOut << "brId\tmut.1\tmut.2\tmut.3\tTotal\tML-br." << endl;
			tree->printMutTypeAmount(allOut);
			allOut << endl;
			allOut << "Tree with branch length favoring long external branches (DELTRAN): " << endl;
			tree->printTreeWithMut(allOut, false);
			allOut << endl;
			allOut << "Amount of each type of mutations on the braches favoring long external branches (DELTRAN): " << endl;
			allOut << "brId\tmut.1\tmut.2\tmut.3\tTotal" << endl;
			tree->printMutTypeAmount(allOut, false);
			allOut << endl;
		}
		allOut.close();
		//output total score
		ofstream scoreOut;
		scoreOut.exceptions(ios::failbit | ios::badbit);
		scoreOut.open(params.outScore.c_str());
// 		scoreOut << bMinCost->totalCost << endl;
		scoreOut << actualCost << endl;
		scoreOut.close();		

		if (params.add == true){
			//output less patterns
			ofstream lessOut;
			lessOut.exceptions(ios::failbit | ios::badbit);
			lessOut.open(params.outLess.c_str());		
			lessPatterns.printPatternSetMoreLess(lessOut);
			lessOut.close();

			//output matched patterns			
			params.outMatchingPat += params.uprefix;
			params.outMatchingPat += ".misfits.paired.pat";
			ofstream matchingPatOut(params.outMatchingPat.c_str());
			matchingPatOut << "overPat\tunderPat\tunit\tscore\tmutPat" << endl;
			int moreIndex = 0;		
			for (PatternSet::const_iterator moreIt = morePatterns.begin(); moreIt != morePatterns.end(); moreIt++)
			{
				int lessIndex = 0;
				for (PatternSet::const_iterator lessIt = lessPatterns.begin(); lessIt != lessPatterns.end(); lessIt++)
				{
					//two pattern are matched
					if (bMinCost->d[moreIndex][lessIndex] > 0)
					{
					//print info
						matchingPatOut << (*moreIt)->convert2Str() << "\t" << (*lessIt)->convert2Str() << "\t" << bMinCost->d[moreIndex][lessIndex] << "\t" << mutScoreMatrix[moreIndex][lessIndex] << "\t" << mutatedVec2Str(getMutatedPattern((*moreIt)->convert2Str(),(*lessIt)->convert2Str())) << endl;
					}
					lessIndex++;
				}
				moreIndex++;
			}
			matchingPatOut.close();			
		}

		//output less patterns
/*		ofstream finalMoreLessOut;
		finalMoreLessOut.exceptions(ios::failbit | ios::badbit);
		finalMoreLessOut.open(finalMoreLess.c_str());
		finalMoreLessOut<<"finalMoreNum\tfinalMoreUnits\tfinalLessNum\tfinalLessUnits" << endl;
		finalMoreLessOut << moreNum << "\t" << totalMoreNum << "\t" << lessNum << "\t" << totalLessNum << endl;
		finalMoreLessOut.close();	*/

/*		if (actualCost != -1)
		{
			//output pairwise score matrix
			ofstream scoreMatrixOut;
			scoreMatrixOut.exceptions(ios::failbit | ios::badbit);
			scoreMatrixOut.open(params.outScoreMatrix.c_str());
			printIntMatrix(scoreMatrixOut, mutScoreMatrix);
			scoreMatrixOut.close();
	
			//output matching
			ofstream matchingOut;
			matchingOut.exceptions(ios::failbit | ios::badbit);
			matchingOut.open(params.outMatching.c_str());
			printIntMatrix(matchingOut, bMinCost->d);
			matchingOut.close();
		}*/
		
		
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT);
	}

	if (params.ass)
		{
			params.outTreeBrLb += params.uprefix;
			params.outTreeMin += params.uprefix;
			params.outTreeMax += params.uprefix;
			params.outTableMin += params.uprefix;
			params.outTableMax += params.uprefix;

			params.outTreeBrLb += ".misfits.branchLabel.tree";
			params.outTreeMin += ".misfits.longInterBr.tree";
			params.outTreeMax += ".misfits.longExterBr.tree";
			params.outTableMin += ".misfits.longInterBr.table";
			params.outTableMax += ".misfits.longExterBr.table";
						
			tree->printTreeWithMut(params.outTreeMin.c_str());
			tree->printTreeWithMut(params.outTreeMax.c_str(), false);
			if (params.add == true){
				tree->printMutTypeAmount(params.outTableMin.c_str());
				tree->printMutTypeAmount(params.outTableMax.c_str(), false);
				tree->printTreeWithBrId(params.outTreeBrLb.c_str());			
			}
		}
	
	cout << "\n";
	cout << "Results are written to: " << endl;
	cout << "\t" << params.outAll << ": general information." << endl;
	cout << "\t" << params.outScore << ": the cost (number of extra-substitutions)." << endl;
	if (params.add == true)
		cout << "\t" << params.outLess << ": information about under-represented patterns." << endl;
 	
	if (params.ass)
	{		
		cout << "\t " << params.outTreeMin << ": the tree with extra-substitutions assigned using ACCTRAN" << endl;
		cout << "\t " << params.outTreeMax << ": the tree with extra-substitutions assigned using DELTRAN" << endl;
		if (params.add == true){
			cout << "\t " << params.outTreeBrLb << ": table contains labels for branches on the tree." << endl;
			cout << "\t " << params.outTableMin << ": table contains type of extra-substitutions assigned on each branch using ACCTRAN." << endl;
			cout << "\t " << params.outTableMax << ": table contains type of extra-substitutions assigned on each branch using DELTRAN." << endl;			
		}
	}

 	cout << "\nTotal time used for computing: " << (double)(params.mutRunTime + params.bmcRunTime + params.assRunTime) / CLOCKS_PER_SEC << "seconds." << endl;

 	time_t beginTime;
 	time (&beginTime);
	char *date;
	date = ctime(&beginTime);		
	cout << "Finished time: " << date << endl;

// 	cout << "The tree after all procedures: " << endl;
// 	tree->printInfo();
}

void Process::printPreOutput()
{
	params.outMore += params.uprefix;
	params.outMoreAlign += params.uprefix;
	params.outOverPos += params.uprefix;
	params.outAlignPat += params.uprefix;
	params.outAlignMoreLess += params.uprefix;
	params.outAlignLess += params.uprefix;

	params.outMore += ".misfits.more";
	params.outMoreAlign += ".misfits.more.phy";
	params.outOverPos += ".misfits.overPos";
	params.outAlignPat += ".misfits.alignPat";
	params.outAlignMoreLess += ".misfits.alignMoreLess";
	params.outAlignLess += ".misfits.alignLess";

	string outOverPosFull(params.outOverPos);
	outOverPosFull += "Full";
	string outOverPosSure(params.outOverPos);
	outOverPosSure += "Sure";
	try{
		ofstream alignMoreLessOut;
		alignMoreLessOut.exceptions(ios::failbit | ios::badbit);
		alignMoreLessOut.open(params.outAlignMoreLess.c_str());
		//Format: (number of sequences) (gap-free sequence length) (number of over-represented patterns) (total over amount) (number of under- patterns) (total under amount)
		alignMoreLessOut << "seqNum\tpatNum\tseqLen\tmoreNum\tmoreSites\tlessNum\tlessSites" << endl;
		alignMoreLessOut << align->ntaxa << "\t" << patNum << "\t" << seqLen << "\t" << moreNum << "\t" << totalMoreNum << "\t" << alignLessNum << "\t" << totalAlignLessNum << endl;
		alignMoreLessOut.close();
		if (params.add == true)
		{
			//output more patterns
			ofstream moreOut;
			moreOut.exceptions(ios::failbit | ios::badbit);
			moreOut.open(params.outMore.c_str());		
			morePatterns.printPatternSetMoreLess(moreOut);
			moreOut.close();
	
			ofstream moreAlignOut;
			moreAlignOut.exceptions(ios::failbit | ios::badbit);
			moreAlignOut.open(params.outMoreAlign.c_str());
			morePatterns.print2Align(align->seqNames,moreAlignOut);
			moreAlignOut.close();
		
			ofstream alignLessOut;
			alignLessOut.exceptions(ios::failbit | ios::badbit);
			alignLessOut.open(params.outAlignLess.c_str());
			alignLessPatterns.printPatternSet(alignLessOut);
			alignLessOut.close();

			//output all patterns in the alignment with detailed info. including mutation step
			ofstream alignPatOut;
			alignPatOut.exceptions(ios::failbit | ios::badbit);
			alignPatOut.open(params.outAlignPat.c_str());
			alignPatterns.printPatternSet(alignPatOut);
			alignPatOut.close();		

		// 		cout << "morePatterns infos: " << endl;
		// 		morePatterns.printAllPositions(cout);

			IntervalSet deterPos, allPos;		
			morePatterns.getOverInterval(deterPos,allPos);
			//output positions of over-represented patterns
			ofstream patOverPos;
			patOverPos.exceptions(ios::failbit | ios::badbit);
			patOverPos.open(params.outOverPos.c_str());
			allPos.printIntervalSet(patOverPos);
			patOverPos.close();
		
// 		cout << "over-represented position: " << endl;
// 		allPos.printIntervalSet(cout);
		ofstream patOverPosFull;
		patOverPosFull.exceptions(ios::failbit | ios::badbit);
		patOverPosFull.open(outOverPosFull.c_str());
		//allPos.printIntervalSet(patOverPosFull);
		morePatterns.printAllPositions(patOverPosFull);
		patOverPosFull.close();
		
			ofstream patOverPosSure;
			patOverPosSure.exceptions(ios::failbit | ios::badbit);
			patOverPosSure.open(outOverPosSure.c_str());
			deterPos.printIntervalSet(patOverPosSure);
			patOverPosSure.close();
		}
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT);
	}

	cout << "Information about patterns in the alignment are written to:" << endl;
	cout << "\t " << params.outAlignMoreLess << ": general information." << endl;
	if (params.add == true){
		cout << "Additional information are written in: " << endl;
		cout << "\t " << params.outMore << endl;
		cout << "\t " << params.outAlignLess << endl;
		cout << "\t " << params.outOverPos << endl;
		cout << "\t " << outOverPosSure << endl;
		cout << "\t " << params.outAlignPat << endl;
	}
}

/*!
    \fn Process::generatePatterns(const int mstep)
 */
void Process::generatePatterns(const int mstep)
{
	if (mstep <= 0) return;
	cout << "\nGenerating patterns until " << mstep << " for additional information!" << endl;
    //forming set of constant patterns
	PatternSet constPatSet;
	int taxonNum = tree->leafNum;
	string str;
	for (int i = 0; i < StateNum; i++)
	{
		str = string(taxonNum, Nucleotides[i]);
		Pattern *constPat;
		constPat = new Pattern(str,false,0);
		constPatSet.addPattern(constPat);
	}
	
	PatternSet source(constPatSet);	
	PatternSet mainReferSet(source);
	PatternSet referSet(alignPatterns);

	bool stop = false;
	for (int step=1; step <= mstep; step++ )
	{
		if (stop) break;
		PatternSet curPatSet;
		PatternSet curInReferSet; 		
		unsigned long esGenNum = 3 * 2*(align->ntaxa-1) * source.getPatNum();
		unsigned long mem = (28 + align->ntaxa) * esGenNum;		
		cout << "Mutation step: " << step << ", maximal number of generated patterns: " << esGenNum << endl;
		cout << "Maximal memory required for this step: " << mem << " bytes." << endl;
		if (mem > MaxMemAllow)
		{
			cout << "Too much memory storage required!" << endl;
			cout << "We stop generating patterns and move on to the next step!" << endl;
			stop = true;		
		}
		else
		{
			splitSet.genPatterns(source, mainReferSet, referSet, curPatSet, curInReferSet);

			//print the generated patterns into aligments
			char inAlign[MAX_FILE_NAME];
			char notInAlign[MAX_FILE_NAME];
			int temp;
			temp = sprintf(inAlign,"%s.%d_step_in_align", params.uprefix, step);
			temp = sprintf(notInAlign,"%s.%d_step_not_in_align", params.uprefix, step);
 			curPatSet.print2Align(align->seqNames,notInAlign);
 			curInReferSet.print2Align(align->seqNames,inAlign);
			
			/**
				RUNING TREE-PUZZLE TO COMPUTE SITE LIKELIHOOD FOR THE TWO SETS: notInAlign and inAlign
			*/			
			//compute site likelihood for notInAlign: if too many patterns are generated, need to break them into some alignments of sequence's length MaxGenAlignLen to run tree-puzzle
			int numAlign = curPatSet.size()/MaxGenAlignLen;			
			PatternSet::const_iterator it = curPatSet.begin();
			for (int j = 0; j <= numAlign; j++)
			{
				PatternSet subPatSet;			
				if (j == numAlign)
				{
					for (PatternSet::const_iterator curIt = it; curIt != curPatSet.end(); curIt++)
						subPatSet.addPattern((*curIt));
				}
				else for (int index = 0; index < MaxGenAlignLen; index++)
				{
					subPatSet.addPattern((*it));
					it++;
				}			
				//prepare file name and command line to run tree-puzzle
				//alignment file containing generated patterns		
				char alignName[MAX_FILE_NAME];
				if (numAlign == 0)
					strcpy(alignName,notInAlign);
				else
				{			
					int temp1;				
					//form alignment file name
					temp1 = sprintf(alignName, "%s_%d", notInAlign,j);
				}
				//derive alignment file
				subPatSet.print2Align(align->seqNames, alignName);	
				string tpCommand("puzzle -usebranch -wsl ");
				tpCommand += alignName;
				tpCommand += " ";
				tpCommand += params.pztree;
				tpCommand += " -prefix=";
				tpCommand += alignName;
				tpCommand += " < ";
				tpCommand += params.puzzleFile;
				tpCommand += " 2>&1 > ";
				tpCommand += alignName;
				tpCommand += ".puzzle.log";
				cout << "Running tree-puzzle with alignment file: " << alignName << endl;
				system(tpCommand.c_str());
				
				//remove files produced by puzzle
				char tempFile[MAX_FILE_NAME];
				temp = sprintf(tempFile,"%s.dist", alignName);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.tree", alignName);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.puzzle", alignName);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
				temp = sprintf(tempFile,"%s.puzzle.log", alignName);
				if ( remove(tempFile) != 0)
					outError("in deleting file: ", tempFile);
			}
	
			//compute site likelihood for inAlign patterns	
			string tpCommand2("puzzle -usebranch -wsl ");
			tpCommand2 += inAlign;
			tpCommand2 += " ";
			tpCommand2 += params.pztree;
			tpCommand2 += " -prefix=";
			tpCommand2 += inAlign;
			tpCommand2 += " < ";
			tpCommand2 += params.puzzleFile;
			tpCommand2 += " 2>&1 > ";
			tpCommand2 += inAlign;
			tpCommand2 += ".puzzle.log";
			cout << "Running tree-puzzle with alignment file: " << inAlign << endl;
			system(tpCommand2.c_str());
			
			//remove files produced by puzzle
			char tempFile[MAX_FILE_NAME];
			temp = sprintf(tempFile,"%s.dist", inAlign);
			if ( remove(tempFile) != 0)
				outError("in deleting file: ", tempFile);
			temp = sprintf(tempFile,"%s.tree", inAlign);
			if ( remove(tempFile) != 0)
				outError("in deleting file: ", tempFile);
			temp = sprintf(tempFile,"%s.puzzle", inAlign);
			if ( remove(tempFile) != 0)
				outError("in deleting file: ", tempFile);
			temp = sprintf(tempFile,"%s.puzzle.log", inAlign);
			if ( remove(tempFile) != 0)
				outError("in deleting file: ", tempFile);

			//update source and reference Set
			mainReferSet += curPatSet;
			mainReferSet += curInReferSet;
			
			source = PatternSet(curPatSet);
			source += curInReferSet;						
		}
	}
}
