/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROCESS_H
#define PROCESS_H

/**
	The whole process
	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/

#include "tree.h"
#include "alignment.h"
#include "bipartitemincost.h"
#include "splitset.h"
#include "split.h"
#include "pattern.h"
#include "patternset.h"
#include "utility.h"
#include "intervalset.h"

class Process{
public:
	/** 
		default, empty constructor
	*/
	Process(){};

	/**
		constructor from a list of parameters stored in Params
		@param _params contains a list of paremeters
	*/
    Process(Params _params);

	/**
		initiated from a list of parameters stored in Params
		@param _params contains a list of parameters
	*/
	void init(Params _params);
	
	/**
		generate patterns to fill in D-. This task is carried out after loading and processing all input data.
	*/
	void generatePatterns();
	
	/**
		generate patterns to fill in D-.
		@param source the patterns used to generate
		@param referSet the generated patterns should not be in this set
		@param retLessSet (IN/OUT) the generated patterns will be added to this set and returned
		@param neededNum the total units of patterns in need.
		@param recomputeMutStep if patterns are generated from constant patterns, then the mutation step does NOT need to be recomputed, otherwise YES.
		This function is used in two cases:
		1. We begin generating patterns from constant patterns, in this case: 
			- source = set containing the 4 constant patterns
			- referSet = patterns in the alignment (alignPatterns)
			- recomputeMutStep = false
		2. In case, step 1 can not generate enough patterns to fill D-, we continue to generate patterns from patterns in the alignment:
			- source = patterns in the alignment (alignPatterns)
			- referSet = patterns which were generated at step 1 and having likelihood > p*
			- recomputeMutStep = true
	*/
	
	void generatePatterns(const PatternSet& source, const PatternSet& referSet, PatternSet& retLessSet, int& neededNum, const bool recomputeMutStep = false);

	void runProcess();
	void printOutput();
	void printPreOutput();
	/*void printMore(ostream &out);
	void printLess(ostream &out);*/


    ~Process();
    void generatePatterns(const int mstep);
public:
	Params params;
	Alignment *align;
	Tree *tree;
	BipartiteMinCost *bMinCost;
	SplitSet splitSet;
	//all patterns in the alignment
	PatternSet alignPatterns;

	//patterns observed more than expected
	//in the case there are not enough patterns in D-, take a subset of D+ (with lowest logll first) which can be fully matched with D-, then update this set to the new set for the matching
	PatternSet morePatterns;
	//patterns observed less than expected
	PatternSet alignLessPatterns;	
	//patterns to match with D+, includes observed less than expected patterns and generated patterns
	PatternSet lessPatterns;

	//amount of each pattern observed more than expected
	IntVec moreAmounts;
	//amount of each pattern observed less than expected and of generated patterns
	IntVec lessAmounts;
	//amount of each pattern observed less than expected
	IntVec alignLessAmounts;
	
	//score matric
	IntMatrix mutScoreMatrix;

	int actualCost; //over all cost = total number of extra mutations needed

	int moreNum; //number of patterns observed more than expected
	int alignLessNum; //number of observed patterns under represented.
	int lessNum; //number of patterns in D-, includes observed less than expected patterns and generated patterns

	int seqLen; //gap-free alignment length
	int patNum; //number of distinct patterns in the alignment

	int totalMoreNum; //total amount of patterns observed more than expected
	int totalLessNum; //total amount of (genertated/observed) patterns less than expected
	int totalAlignLessNum; //total amount of patterns in the alignment observed less than expected

	int totalAdditionNum; //total amount of patterns in the alignment to put into D- (as long as its obsNum<upperBound)

	int df; //degree of freedom = df.model + df.data

	//if under represented patterns + generated patterns are enough for D+
	bool enoughPat;	
};

#endif

