/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "tree.h"

const char* ROOT_NAME = "fake_root";
const char* ROOT_NAME2 = "_root";

Tree::Tree(){
	root = NULL;
	leafNum = 0;
	nodeNum = 0;
	brNum = 0;
	rooted = false;
	outgroup = NULL;
}

Tree::Tree(const char *treeFile){
	readTree(treeFile);	
}

Tree::Tree(Tree &atree){
	root = atree.root;
	leafNum = atree.leafNum;
	nodeNum = atree.nodeNum;
	brNum = atree.brNum;
	rooted = atree.rooted;
	outgroup = atree.outgroup;
	//have to delete the root when exchange to another object
	atree.root = NULL;
	atree.outgroup = NULL;
}

Tree::~Tree(){
	if (root != NULL)
		freeNode();
	root = NULL;
	outgroup = NULL;
}

/*!
    \fn Tree::freeNode(Node *node = NULL, Node *dad = NULL)
 */
void Tree::freeNode(Node *node, Node *dad)
{
    if (!node) node = root;
	NeighborVec::reverse_iterator it;
	for (it = node->neighbors.rbegin(); it != node->neighbors.rend(); it++)
		if ((*it)->node != dad)
		{
			(*it)->minMutTypeAmount.clear(); //added on 2008.11.14
			(*it)->maxMutTypeAmount.clear(); //added on 2008.11.14
			freeNode((*it)->node, node);
		}
	delete node;
}

/*!
    \fn Tree::readTree(const char *infile)
 */
void Tree::readTree(const char *infile)
{
	cout << "\nReading tree file " << infile << " ..." << endl;
	ifstream in;
	try {
		in.exceptions(ios::failbit | ios::badbit);
		in.open(infile);
		readTree(in);
		in.close();
	} catch (ios::failure) {
		outError(ERR_READ_INPUT, infile);		
	}

// 	cout << "Tree contains " << leafNum - rooted << 
// 		" taxa and " << nodeNum-1-rooted << " branches" << endl;
	cout << "Tree contains " << leafNum << 
		" taxa and " << nodeNum-1 << " branches" << endl;
}
/*!
    \fn Tree::readTree(ifstream &in)
 */
void Tree::readTree(ifstream &in)
{
	try {
		char ch;
		in >> ch;
		if (ch != '(')
			throw "Tree file not started with an opening-bracket '('";
	
		leafNum = 0;
		rooted=false;
	
		double branch_len;
		Node *node;
		parseFile(in, ch, node, branch_len);		
		//the tree is rooted (inferred from input file)
		if (node->neighbors.size() == 2 || branch_len > 0.0) {
			if (branch_len == -1.0) branch_len = 0.0;		
			if (branch_len < 0.0) 
				throw ERR_NEG_BRANCH; 
			rooted = true;
			root = new Node(leafNum, ROOT_NAME);
 			root->neighbors.push_back(new Neighbor(node, branch_len));
 			node->neighbors.push_back(new Neighbor(root, branch_len));			
			//leafNum++;	//COMMENT ON 2009.09.13
		}		
		// make sure that root is a leaf
// 		assert(root->isLeaf());	
		if (in.eof() || ch != ';')
			throw "Tree file must be ended with a semi-colon ';'";
	} catch (bad_alloc) {
		outError(ERR_NO_MEMORY);
	} catch (const char *str) {
		outError(str);
	} catch (char *str) {
		outError(str);
	} catch (string str) {
		outError(str);
	} catch (ios::failure) {
		outError(ERR_READ_INPUT);
	} catch (...) {
		// anything else
		outError(ERR_READ_ANY);
	}
		
 	nodeNum = leafNum;	
	initializeTree();
	resetBrId();
	//bool stop = false;
	//checkValidTree(stop);
}

/*!
    \fn Tree::parseFile(ifstream &in, char &ch, Node* &currentNode, double &branchLen)
 */
void Tree::parseFile(ifstream &infile, char &ch, Node* &currentNode, double &branchLen)
{
	Node *node;
	int maxlen = 100;
	char seqname[100];
	int seqlen;
	double brlen;
	branchLen = -1.0;

	currentNode = new Node();

	if (ch == '(') { // internal node		
		infile >> ch;
		while (ch != ')' && !infile.eof())
		{
			node = NULL;
			parseFile(infile, ch, node, brlen);			
 			currentNode->neighbors.push_back(new Neighbor(node, brlen));
 			node->neighbors.push_back(new Neighbor(currentNode, brlen));			
			if (infile.eof())
				throw "Expecting ')', but end of file instead";
			if (ch == ',')
				infile >> ch;
			else if (ch != ')') {
				string err = "Expecting ')', but found '";
				err += ch;
				err += "' instead";
				throw err;
			}
		}
		if (!infile.eof()) infile >> ch;
	}
	// now read the node name
	seqlen = 0;
	while (!is_newick_token(ch) && !controlchar(ch) && !infile.eof() && seqlen < maxlen)
	{
		seqname[seqlen] = ch;
		seqlen++;
		ch = infile.get();
	}
	if (controlchar(ch) && !infile.eof()) 
		infile >> ch;
	if (seqlen == maxlen)
		throw "Too long name ( > 100)";
	seqname[seqlen] = 0;
	if (seqlen == 0 && currentNode->isLeaf())
		throw "A taxon has no name.";
	if (seqlen > 0) 
		currentNode->name += seqname;
	if (currentNode->isLeaf()) {
		// is a leaf, assign its ID
		currentNode->id = leafNum;
		currentNode->seqID = leafNum;
 		if (leafNum == 0)
 			root = currentNode;
		leafNum++;
	}

	if (ch == ';' || infile.eof())
		return;
	if (ch == ':')
	{
		infile >> ch;
		seqlen = 0;
		while (!is_newick_token(ch) && !controlchar(ch) && !infile.eof() && seqlen < maxlen)
		{
			seqname[seqlen] = ch;
			seqlen++;
			ch = infile.get();
		}
		if (controlchar(ch) && !infile.eof()) 
			infile >> ch;
		if (seqlen == maxlen || infile.eof())
			throw "branch length format error.";
		seqname[seqlen] = 0;
		branchLen = convert_double(seqname);
	}
}

/*!
    \fn Tree::initializeTree(Node *node = NULL, Node *dad = NULL)
 */
void Tree::initializeTree(Node *node, Node *dad)
{	
	if (!node)
		node = root;		
	if (!node->isLeaf())
	{
		node->id = nodeNum;
 		nodeNum++;
		//node->name = node->id;
	}	

 	FOR_NEIGHBOR_IT(node, dad, it)			
 		initializeTree((*it)->node, node);		
}

/**----------PRINT TREE, SUB-TREE------*/
/*-------------------------------------*/
void Tree::printInfo(Node *node, Node *dad)
{
 	if (node == NULL) node = root;
	FOR_NEIGHBOR_IT(node, dad, it) {
		cout << node->name << "_" << node->seqID << "\t" << (*it)->node->name << "_" << (*it)->node->seqID << " " << "\t" << (*it)->length << "_" << (*it)->brId << endl;
		printInfo((*it)->node, node);
	}
}

void Tree::printInfoDetail(Node *node, Node *dad){
	if (node == NULL) node = root;
	FOR_NEIGHBOR_IT(node, dad, it) {
		cout << node->name << "_" << node->seqID << "_" << node->fitchScore << "_" << node->fitchSet << "_" << node->finalFitchSet << "  " << (*it)->node->name << "_" << (*it)->node->seqID << "_" << (*it)->node->fitchScore << "_" << (*it)->node->fitchSet << "_" << (*it)->node->finalFitchSet << "  " << (*it)->length << endl;
		printInfoDetail((*it)->node, node);
	}
}

void Tree::printInfoCharSet(Node *node, Node *dad){
	if (node == NULL) node = root;
	FOR_NEIGHBOR_IT(node, dad, it) {
		cout << node->name << "_" << node->charSet[0] << "_" << node->charSet[1] << "_" << node->charSet[2] << "_" << node->charSet[3] << "_" << node->allCharSet << "  " << (*it)->node->name << "_" << (*it)->node->charSet[0] << "_" << (*it)->node->charSet[1] << "_" << (*it)->node->charSet[2] << "_" << (*it)->node->charSet[3] << "_" << (*it)->node->allCharSet << "  " << endl;
		printInfoCharSet((*it)->node, node);
	}
}

void Tree::printInfoMinExBrCost(Node *node, Node *dad)
{
	if (node == NULL) node = root;
	FOR_NEIGHBOR_IT(node, dad, it) {
		cout << node->name << "_" << node->minExBrCost[0] << "_" << node->minExBrCost[1] << "_" << node->minExBrCost[2] << "_" << node->minExBrCost[3] << "_" << node->allCharSet << "  " << (*it)->node->name << "_" << (*it)->node->minExBrCost[0] << "_" << (*it)->node->minExBrCost[1] << "_" << (*it)->node->minExBrCost[2] << "_" << (*it)->node->minExBrCost[3] << "_" << (*it)->node->allCharSet << "  " << (*it)->minMutCost << endl;
		printInfoMinExBrCost((*it)->node, node);
	}
}

void Tree::printInfoMaxExBrCost(Node *node, Node *dad)
{
	if (node == NULL) node = root;
	FOR_NEIGHBOR_IT(node, dad, it) {
		cout << node->name << "_" << node->maxExBrCost[0] << "_" << node->maxExBrCost[1] << "_" << node->maxExBrCost[2] << "_" << node->maxExBrCost[3] << "_" << node->allCharSet << "  " << (*it)->node->name << "_" << (*it)->node->maxExBrCost[0] << "_" << (*it)->node->maxExBrCost[1] << "_" << (*it)->node->maxExBrCost[2] << "_" << (*it)->node->maxExBrCost[3] << "_" << (*it)->node->allCharSet << "  " << (*it)->maxMutCost << endl;
		printInfoMaxExBrCost((*it)->node, node);
	}
}

void Tree::printTree(const char *ofile, BranchType brtype)
{
	try {
		ofstream out;
		out.exceptions(ios::failbit | ios::badbit);
		out.open(ofile);
		printTree(out, brtype);
		out.close();
		cout << "Tree was printed to " << ofile << endl;
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT, ofile);
	}
}

void Tree::printTree(ostream &out, BranchType brtype) {
	if (root->isLeaf()) {
		if (root->neighbors[0]->node->isLeaf()) {
			// tree has only 2 taxa!
			out << "(";
			printTree(out, brtype, root);
			out << "," << root->neighbors[0]->node->name;
			switch (brtype) {
			case BR_LEN: out << ":0"; break;
			default: break;
			}
			out << ")";
		} else
			// tree has more than 2 taxa
			printTree(out, brtype, root->neighbors[0]->node);
	} else 
		printTree(out, brtype, root);

	out << ";";
}

void Tree::printTree(ostream &out, BranchType brtype, Node *node, Node *dad)
{
	if (!node) node = root;
	if (node->isLeaf()) {
		out << node->name;
		switch (brtype) {
		case BR_LEN: out << ":" << node->neighbors[0]->length; break;		
		default: break;
		}
	} else {
		// internal node
		out << "(";
		bool first = true;
		double length = 0.0;		
		FOR_NEIGHBOR_IT(node, dad, it) {
 			if ((*it)->node->name != ROOT_NAME) {
				if (!first)
					out << ",";
				printTree(out, brtype, (*it)->node, node);
				first = false;
			} else
				length = (*it)->length;
		} else {
			length = (*it)->length;
		}
		out << ")";
		if (!node->name.empty())
			out << node->name;
		if (dad != NULL || length > 0.0)
			switch (brtype) {
			case BR_LEN: out << ":" << length; break;			
			default: break;
			}
	}
}

void Tree::printTreeWithBrId(const char *ofile)
{
	try {
		ofstream out;
		out.exceptions(ios::failbit | ios::badbit);
		out.open(ofile);
		printTreeWithBrId(out);
		out.close();
		cout << "Tree with brId was printed to " << ofile << endl;
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT, ofile);
	}
}
void Tree::printTreeWithBrId(ostream & out)
{
	if (root->isLeaf()) {
		if (root->neighbors[0]->node->isLeaf()) {
			// tree has only 2 taxa!
			out << "(";
			printTreeWithBrId(out, root);
			out << "," << root->neighbors[0]->node->name;
			out << ":" << root->neighbors[0]->brId;
			out << ")";
		} else
			// tree has more than 2 taxa
			printTreeWithBrId(out, root->neighbors[0]->node);
	} else 
		printTreeWithBrId(out, root);

	out << ";";
}
void Tree::printTreeWithBrId(ostream &out, Node *node, Node *dad)
{
	if (!node) node = root;
	if (node->isLeaf()) {
		out << node->name;
		out << ":" << node->neighbors[0]->brId;
	} else {
		// internal node
		out << "(";
		bool first = true;
		int _brId = -1;		
		FOR_NEIGHBOR_IT(node, dad, it) {
			if ((*it)->node->name != ROOT_NAME){
				if (!first)
					out << ",";
				printTreeWithBrId(out, (*it)->node, node);
				first = false;
			}
			else
				_brId = (*it)->brId;
		} else {
			_brId = (*it)->brId;
		}
		out << ")";
		if (!node->name.empty())
			out << node->name;
		if (dad != NULL || _brId >-1)
			out << ":" << _brId;
	}
}

void Tree::printTreeWithMut(const char *ofile, bool minEx)
{
	try {
		ofstream out;
		out.exceptions(ios::failbit | ios::badbit);
		out.open(ofile);
		printTreeWithMut(out, minEx);
		out.close();
		cout << "Tree with mutations on branches was printed to " << ofile << endl;
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT, ofile);
	}
}
	
void Tree::printTreeWithMut(ostream & out, bool minEx)
{
	if (root->isLeaf()) {
		if (root->neighbors[0]->node->isLeaf()) {
			// tree has only 2 taxa!
			out << "(";
			printTreeWithMut(out, minEx, root);
			out << "," << root->neighbors[0]->node->name;
			if (minEx)
				out << ":" << root->neighbors[0]->minMutCost;
			else
				out << ":" << root->neighbors[0]->maxMutCost;			
			out << ")";
		} else
			// tree has more than 2 taxa
			printTreeWithMut(out, minEx, root->neighbors[0]->node);
	} else 
		printTreeWithMut(out, minEx, root);

	out << ";";
}

void Tree::printTreeWithMut(ostream &out, bool minEx, Node *node, Node *dad)
{
	if (!node) node = root;
	if (node->isLeaf()) {
		out << node->name;
		if (minEx)
			out << ":" << node->neighbors[0]->minMutCost;		
		else
			out << ":" << node->neighbors[0]->maxMutCost;		
	} else {
		// internal node
		out << "(";
		bool first = true;
		int mutCost = 0;		
		FOR_NEIGHBOR_IT(node, dad, it) {
			if ((*it)->node->name != ROOT_NAME)	{ 
				if (!first)
					out << ",";
				printTreeWithMut(out, minEx, (*it)->node, node);
				first = false;
			} else {
				if (minEx)
					mutCost = (*it)->minMutCost;
				else
					mutCost = (*it)->maxMutCost;
			}
		} else {
			if (minEx)
				mutCost = (*it)->minMutCost;
			else
				mutCost = (*it)->maxMutCost;			
		}
		out << ")";
		if (!node->name.empty())
			out << node->name;
		if (dad != NULL || mutCost >= 0)
			out << ":" << mutCost; 
	}
}

void Tree::printMutTypeAmount(const char *outfile, bool minEx)
{
	try {
		ofstream out;
		out.exceptions(ios::failbit | ios::badbit);
		out.open(outfile);
		out << "brId\tmut.1\tmut.2\tmut.3\tTotal\tML-br." << endl;
		printMutTypeAmount(out, minEx);
		out.close();
		cout << "Table of branch Id and type of mutations is printed to: " << outfile << endl;
	} catch (ios::failure) {
		outError(ERR_WRITE_OUTPUT, outfile);
	}
}

void Tree::printMutTypeAmount(ostream & out, bool minEx, Node *node, Node *dad)
{
	if (node == NULL) node = root;
	FOR_NEIGHBOR_IT(node, dad, it)
	{
		out << (*it)->brId;
		if (minEx)	{
			for (int index = 1; index < StateNum; index++)
				out << "\t" << (*it)->minMutTypeAmount[index];
			out << "\t" << (*it)->minMutCost << "\t" << (*it)->length << endl;
		} else {
			for (int index = 1; index < StateNum; index++)
				out << "\t" << (*it)->maxMutTypeAmount[index];
			out << "\t" << (*it)->maxMutCost << "\t" << (*it)->length << endl;
		}
		printMutTypeAmount(out, minEx, (*it)->node, node);
	}
	
}

Node *Tree::findNodeName(string &name, Node *node, Node *dad) {
	if (!node) node = root;
	if (node->name == name) return node;
	FOR_NEIGHBOR_IT(node, dad, it) {
		Node *res = findNodeName(name, (*it)->node, node);
		if (res) return res;
	}
	return NULL;
}

int Tree::findSeqID(string &name, Node *node, Node *dad) {	
	Node *res = findNodeName(name,node,dad);
	if (res) 
	{		
		return res->seqID;
	}
	return -1;
}

void Tree::checkValidTree(bool &stop, Node *node, Node *dad)
{
	if (!node) node = root;
	if (node->neighbors.size() != 1 && node->neighbors.size() != 3) {
		cout << "Tree is not bifurcating." << endl;
		stop = true;
		return;
	}
	//for (int i = 0; i < node->neighbors.size(); i++)
		//if (node->neighbors[i]->node != dad) {
	FOR_NEIGHBOR_IT(node, dad, it) {
		checkValidTree(stop, (*it)->node, node);
		if (stop) 
			return;
	}
}

void Tree::updateRoot(string outgroupName)
{
	if (rooted == true && outgroupName != "")
		outError(ERR_CONFLICT_ROOT);
	if (!rooted)
	{
		//user provides an outgroup, find node with outgroupName in the tree
		if (outgroupName != "")
		{
			Node *newOutGroup = findNodeName(outgroupName);
			if (newOutGroup == NULL)
			{
				string err = ERR_NO_LEAF_NAME;
				err += outgroupName;
				outError(err);
			}
			if (!newOutGroup->isLeaf())
			{
				string err = ERR_ROOT_AT_INNER;
				err += outgroupName;
				outError(err);
			}
			//found Node with outgroupName ==> assign this Node to outgroup
			outgroup = newOutGroup;
		}
		else
			//user does not provide any outgroup, assign outgroup to the first leaf in Nexus file by default
			outgroup = root;
		
		//create an internal node as the root of the binary tree, determined by outgroup
		Node* newRoot = new Node(nodeNum, ROOT_NAME2);
		double branch_len = outgroup->neighbors[0]->length;
		newRoot->neighbors.push_back(new Neighbor(outgroup, branch_len));
		newRoot->neighbors.push_back(new Neighbor(outgroup->neighbors[0]->node, 0.0));
		outgroup->neighbors[0]->node->replaceNeighbor(outgroup, newRoot, 0.0);
		outgroup->replaceNeighbor(outgroup->neighbors[0]->node, newRoot, branch_len);
	
		//create a fake root as a leaf, connected to the above fake root ==> tree now can be treated as unrooted tree, every node has degree of either 1 or 3. This fake root always has state 1.
		Node* fakeRoot = new Node(leafNum, ROOT_NAME);
		fakeRoot->neighbors.push_back(new Neighbor(newRoot, 0.0));
		newRoot->neighbors.push_back(new Neighbor(fakeRoot, 0.0));
		root = fakeRoot;
	}
}

/**
	\fn updateSeqID
*/
void Tree::updateSeqID(StringVec leafNameVec, Node *node, Node *dad){
	if (node == NULL) node = root;
	if (node->isLeaf())
	{
		//if (node == root && rooted) //is commented out on 2008.11.04
		if (node == root) //added on 2008.11.04
		{
// 			node->seqID = -1; //commented out on 2009.10.14
			if (node->id >= 0 && node->id < leafNum)
			{
				int seq_id = searchString(node->name, leafNameVec);
				if (seq_id == -1)
					outError(ERR_NO_SEQUENCE_NAME, node->name);
				else node->seqID = seq_id;
			}				
		}
		else
		{
			int seq_id = searchString(node->name, leafNameVec);
			if (seq_id == -1)
				outError(ERR_NO_SEQUENCE_NAME, node->name);
			else node->seqID = seq_id;
		}
	}	
	FOR_NEIGHBOR_IT(node, dad, it)
	{
		updateSeqID(leafNameVec, (*it)->node, node);
	}
}

/*!
    \fn Tree::mutScore(string pattern1, string pattern2)
 */
int Tree::mutScore(string pattern1, string pattern2, bool compStep)
{
	int retScore = 0;
    IntVec mutatedPattern = getMutatedPattern(pattern1, pattern2);

	//print for testing only
/* 	cout << "Difference between " << pattern1 << " and " << pattern2 << " is: ";
  	int pattLen = strlen(pattern1.c_str());
  	for (int i = 0; i < pattLen; i++)
  		cout << mutatedPattern[i];*/
	//end of print
	
	resetAllStates();
	assignFitchSet(mutatedPattern, retScore, NULL, NULL, compStep);
	
	//print for testing
//    	cout << ". Mutation's cost: " << retScore << endl;
	return retScore;
}

/**
		compute Fitch score of a pattern (nucleotide characters) on this tree
		equivalent to the mutation score between it and a constant pattern??? --> check it!
		@param pattern the pattern
		@param RETURN over all score on this tree
	*/
int Tree::mutScore(string pattern, bool compStep)
{
	//translate the pattern
	IntVec mutPat;
	int patLen = strlen( pattern.c_str() );	
	for (int i = 0; i < patLen; i++)
	{
		int index = -1;
		switch ( toupper(pattern[i]) ){
			case 'A': index = 1; break;
			case 'C': index = 2; break;
			case 'G': index = 4; break;
			case 'T': index = 8; break;
			case 'U': index = 8; break;
			default: break;
		}		
		if (index == -1)
		{
			string errMsg = "There is non-{ACGT} in ";
			errMsg += pattern;
			outError(errMsg);
		}
		mutPat.push_back(index);
	}
	
	//reset everything related to Fitch's
	resetAllStates();
	//comput Fitch score
	int retScore = 0;
	assignFitchSet(mutPat, retScore, NULL, NULL, compStep);
	//return value
	return retScore;
	
}

/**
	compute Fitch score of a pattern (class Pattern) on this tree
	@param pattern the pattern
	@param RETURN	over all score on this tree
*/
int Tree::mutScore(Pattern *pattern, bool compStep)
{
	//translate the pattern
	IntVec mutPat;
	int patLen = pattern->getNTaxa();
	string patCode = pattern->getCode();
	for (int i = 0; i < patLen; i++)
	{
		int index = -1;
		switch (patCode[i]){
			case '0': index = 1; break;
			case '1': index = 2; break;
			case '2': index = 4; break;
			case '3': index = 8; break;
			default: break;
		}
		if (index == -1)
		{
			outError("There is non-{ACGT} in ", pattern->convert2Str());
		}
		mutPat.push_back(index);
	}
	//reset everything related to Fitch's
	resetAllStates();
	//comput Fitch score
	int retScore = 0;
	assignFitchSet(mutPat, retScore, NULL, NULL, compStep);
	//return value
	return retScore;
}

/**
	compute mutation score of two pattern in class Pattern
	@param pattern1 the first pattern
	@param pattern2 the second pattern
	@param RETURN 	over all score of the mutated pattern on this tree
*/
int Tree::mutScore(Pattern *pattern1, Pattern* pattern2, bool compStep)
{
	int patLen = pattern1->getNTaxa();
	assert(patLen == pattern2->getNTaxa());
	string patCode1 = pattern1->getCode();
	string patCode2 = pattern2->getCode();
	//get the mutated patterns under IntVec;
	IntVec mutPat;
	for (int i = 0; i < patLen; i++)
	{
		int index1 = (int)(patCode1[i] - '0');
		int index2 = (int)(patCode2[i] - '0');
		mutPat.push_back(K3stMatrix[index1][index2]);
	}
	
	//reset everything related to Fitch's
	resetAllStates();
	//comput Fitch score
	int retScore = 0;
	assignFitchSet(mutPat, retScore, NULL, NULL, compStep);
	//return value
	return retScore;
}

/**
	compute score of a mutated pattern
	@param mutatedPattern	the mutated pattern that is encoded already
	@param RETURN	over all score of this mutated pattern on this tree
*/
int Tree::mutScore(IntVec mutatedPattern, bool compStep)
{
	//reset everything related to Fitch's
	resetAllStates();
	//comput Fitch score
	int retScore = 0;
	assignFitchSet(mutatedPattern, retScore, NULL, NULL, compStep);
	//return value
	return retScore;
}

void Tree::resetFitchSet(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
	node->fitchSet = value;
	FOR_NEIGHBOR_IT(node, dad, it)
		resetFitchSet(value, (*it)->node, node);
}

void Tree::resetFinalFitchSet(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
	node->finalFitchSet = value;
	FOR_NEIGHBOR_IT(node, dad, it)
		resetFinalFitchSet(value, (*it)->node, node);
}

void Tree::resetFitchScore(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
	node->fitchScore = value;
	FOR_NEIGHBOR_IT(node, dad, it)
		resetFitchScore(value, (*it)->node, node);
}

void Tree::resetMinExBrCost(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
// 	node->minExBrCost = IntVec(StateNum, value);
	resetIntVector(node->minExBrCost, value);
	FOR_NEIGHBOR_IT(node, dad, it)
		resetMinExBrCost(value, (*it)->node, node);
}

void Tree::resetMaxExBrCost(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
// 	node->maxExBrCost = IntVec(StateNum, value);
	resetIntVector(node->maxExBrCost, value);
	FOR_NEIGHBOR_IT(node, dad, it)
		resetMaxExBrCost(value, (*it)->node, node);
}

void Tree::resetCharSet(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
// 	node->charSet = IntVec(StateNum, value);
	resetIntVector(node->charSet, value);
	FOR_NEIGHBOR_IT(node, dad, it)
		resetCharSet(value, (*it)->node, node);
}

void Tree::resetAllCharSet(int value, Node *node, Node *dad)
{
	if (node == NULL) node = root;
	node->allCharSet = value;
	FOR_NEIGHBOR_IT(node, dad, it)
		resetAllCharSet(value, (*it)->node, node);
}

void Tree::resetAllStates()
{
	resetFitchSet();
	resetFitchScore();
	resetFinalFitchSet();
	resetMinExBrCost();
	resetMaxExBrCost();
	resetCharSet();
	resetAllCharSet();	
}

void Tree::setBrId(Node *node, Node *dad)
{
	if (node == NULL) node = root;	
	FOR_NEIGHBOR_IT(node, dad, it)
	{	
		(*it)->brId = brNum;

		for (NeighborVec::iterator nn = (*it)->node->neighbors.begin(); nn != (*it)->node->neighbors.end(); nn++)
		{
			if ((*nn)->node == node)
				(*nn)->brId = brNum;
		}
		brNum++;
		setBrId((*it)->node, node);	
	}
}

void Tree::resetBrId()
{
	brNum = 0;
	setBrId();
}

// To form the preliminary set in Fitch 1971 algorithm. At each node we have fitchSet
void Tree::assignFitchSet(IntVec pattern, int &score, Node* node, Node* dad, bool compStep)
{
	if (node == NULL) node = root;
	if ( node->isLeaf() )
	{
		//if (node == root && rooted) //node->seqID=-1 //commented out on 2008.11.04
		if (node == root)
			node->fitchSet = 1;
		else
			node->fitchSet = pattern[node->seqID];
	}

	FOR_NEIGHBOR_IT(node, dad, it)
	{
		assignFitchSet(pattern, score, (*it)->node, node, compStep);
	}
	
	if ( !node->isLeaf() )
	{
		int temp1 = 0, temp2 = 0;
		FOR_NEIGHBOR_IT(node, dad, it)
		{
			if ( (*it)->node->fitchSet )
			{
				if (!temp1) temp1 = (*it)->node->fitchSet;
				else		temp2 = (*it)->node->fitchSet;
			}
		}
		//both descendants of a internal node are assigned
		if (temp1 && temp2)
		{
			//their intersection is not empty
			if (temp1 & temp2)
				node->fitchSet = temp1 & temp2; //fitchSet = the intersection
			else //sets at 2 descendants do not intersect
			{
				node->fitchSet = temp1 | temp2; //fitchSet = the union
				score++; //increase the score
				node->fitchScore++;
			}
		}		
	}
	
	//node is root and its neighbor's fitchSet is already assigned, need to process artificial/real leaf root
	if (!compStep)
	{
		if (node == root && node->neighbors[0]->node->fitchSet)
		{ 		
			//root's fitch set and its neighbor's fitchSet do not intersect, then,increase the score
			if (!(node->fitchSet & node->neighbors[0]->node->fitchSet))
				score++;			
		}
	}
}
// To form the final set in Fitch 1971 algorithm, finalFitchSet at each node
void Tree::getFinalFitchSet(Node* node, Node* dad)
{
	if (node == NULL) node = root;
	//current node is root, assign its only neighbor's finalFitchSet = fitchSet, continue with its neighor's neighbors.
	if (node == root)
	{	
		node->finalFitchSet = node->fitchSet;
		node->neighbors[0]->node->finalFitchSet = node->neighbors[0]->node->fitchSet;		
		FOR_NEIGHBOR_IT(node->neighbors[0]->node, node, it)
			getFinalFitchSet((*it)->node,node->neighbors[0]->node);
	}	
	else if (!node->isLeaf())//current node is an internal node
	{
		//the preliminary nodal set (node->fitchSet) contains all of the nucleotides present in the final nodal set of its immediate ancestor
		if ((node->fitchSet & dad->finalFitchSet) == dad->finalFitchSet)
			//Eliminate all nucleotides from the preliminary nodal set that are not present in the final nodal set of its intermediate ancestor, i.e. 
			node->finalFitchSet = dad->finalFitchSet;		
		else //the preliminary nodal set (node->fitchSet) DO NOT contains all of the nucleotides present in the final nodal set of its immediate ancestor
		{
			if (node->fitchScore > 0) //the preliminary nodal set was formed by a union of its descendent sets
				//add to the preliminary nodal set any nucleotides in the final set of its immediate ancestor that are not present in the preliminary set, i.e.
				node->finalFitchSet = node->fitchSet | dad->finalFitchSet;
			else
			{
				int temp=0;
				//temp contains union of this node's descendent's fitchSets
				FOR_NEIGHBOR_IT(node, dad, it)
				{
					temp = (temp | (*it)->node->fitchSet);
				}	
				//this finalFitchSet = add to the preliminary nodel set any nucleotides not already present provided that they are present in both the final set of the immediate ancestor and in at least one of the two immediately descendent preliminary sets
				node->finalFitchSet = (node->fitchSet | (dad->finalFitchSet & temp));
			}				
		}
		//Descend one node as long as any preliminary nodal sets remain
		FOR_NEIGHBOR_IT(node, dad, it)
			getFinalFitchSet((*it)->node, node);
	}
	else //node is leaf and is not root
		node->finalFitchSet = node->fitchSet;
		
}

void Tree::assignAllCharSet(Node* node, Node* dad)
{
	if (node == NULL) node = root;
	if (node == root) 
		assignCharSet(0);
	else
	{
		for (int index = 0; index < StateNum; index ++)		
			if (dad->allCharSet & MutState[index])			
				assignCharSet(index, node, dad);
	}
	// walk down the tree
	FOR_NEIGHBOR_IT(node, dad, it)
	{					
		assignAllCharSet((*it)->node, node);									
	}	
}

// To enumerate all possible links in Fitch 1971 algorithm. Each node having a vector of size StateNum (4 in this case) called charSet. charSet[0] means all possible characters at this node, e.g. 0001, 0110, ... if its immediate ancestor state index is 0. The union of charSet[0] U ... U charSet[3] is allCharSet meaning all possible characters at this node when its parent index is 0 or 1 or 2 or 3. This also follows Fitch 1971 rules.
void Tree::assignCharSet(int dadStateIndex, Node* node, Node* dad)
{
	if (node == NULL) node = root;
	if (node->isLeaf()) // current node is leaf
	{	
		//its charSet is always equal to its fitchSet
		node->charSet[dadStateIndex] = node->fitchSet;
		//its all allowed character set is also equal to its fitchSet
		node->allCharSet = node->fitchSet;		
	}
	else //current node is internal node
	{
		//rule 1 in Fitch 1971 - Permitted links between nucleotides in successive nodal sets
		//N_i -> N_i or (N_i) -> N_i is obligatory
		if ((MutState[dadStateIndex] & (node->fitchSet & node->finalFitchSet)) != 0)
		{
			node->charSet[dadStateIndex] = MutState[dadStateIndex];
			node->allCharSet = (node->allCharSet | MutState[dadStateIndex]);
		}
		else
		{
			//put every character in the final nodal set
			node->charSet[dadStateIndex] = node->finalFitchSet;
			//exclude the ones: Ni -> (Nj), (Ni) -> (Nj), i != j
			int notInPreliSet = node->finalFitchSet & (~node->fitchSet);
			node->charSet[dadStateIndex] -= (notInPreliSet & (~MutState[dadStateIndex]));	
					
			node->allCharSet = (node->allCharSet | node->charSet[dadStateIndex]);			
		}
	}	
}

void Tree::computeMinMaxExBrCost(int currentStateIndex, Node* node, Node* dad)
{
	if (node == NULL) node = root;
	
	node->minExBrCost[currentStateIndex] = 0;
	node->maxExBrCost[currentStateIndex] = 0;
	if (node == root || (!node->isLeaf())) //node is root or internal node
	{
		FOR_NEIGHBOR_IT(node, dad, it)
		{
			if ((*it)->node->isLeaf()) // its neighbor is a leaf
			{	
				//assign minExBrCost[its neighbor state] = 0, minExBrCost for the other states at this leaf is not assigned (applicable).
  				(*it)->node->minExBrCost[InversedMutState[(*it)->node->allCharSet]] = 0;
				(*it)->node->maxExBrCost[InversedMutState[(*it)->node->allCharSet]] = 0;
				//compare the currentState with the state at the leaf. If they are different, increases minExBrCost by 1.
				if (MutState[currentStateIndex] != (*it)->node->charSet[currentStateIndex])
				{
					node->minExBrCost[currentStateIndex]++;
					node->maxExBrCost[currentStateIndex]++;
				}
			}
			else //its neighbor is an internal node
			{
				for (int index = 0; index < StateNum; index++)
				{
					//compute minExBrCost for this neighbor if it is not yet computed.
					if (((*it)->node->allCharSet & MutState[index]) != 0)
					{
						if ((*it)->node->minExBrCost[index] >= MaxExBrCost)
							computeMinMaxExBrCost(index, (*it)->node, node);
					}
				}
				//in the possible links from this node to this neighbor, choose the one which yields minimum number of mutations on external branches.
				node->minExBrCost[currentStateIndex] += getMin((*it)->node->minExBrCost, (*it)->node->charSet[currentStateIndex]);
				node->maxExBrCost[currentStateIndex] += getMax((*it)->node->maxExBrCost, (*it)->node->charSet[currentStateIndex]);
			}
		}
	}
}
// 	assigning mutations on branches favoring long internal branches (minExBr = true) or long 	external branches (minExBr = false).
// 	This will update mutCost on each branch (mutCost is a attribute of Neighbor class).
void Tree::assignMutOnBr(double factor, int currentStateIndex, Node* node, Node* dad, bool minExBr)
{
	if (node == NULL) node = root;

	if (node == root || (!node->isLeaf())) // current node is an internal node or root
	{
		if (minExBr == true) //favor long internal branches
		{
			//examine its neighbors
			FOR_NEIGHBOR_IT(node, dad, it)
			{
				if ((*it)->node->isLeaf()) // its neighbor is a leaf
				{
					// current state and the state at the leaf are different ==> increase #. mutations on this branch by 1*factor.
					if (MutState[currentStateIndex] != (*it)->node->charSet[currentStateIndex])
					{
						//branch from currentNode->its neighbor
						(*it)->minMutCost += factor;
						int index = MutProduct[currentStateIndex][InversedMutState[(*it)->node->charSet[currentStateIndex]]];
						(*it)->minMutTypeAmount[index] += factor;
						//branch from currentNode's neighbor -> currentNode
						for (NeighborVec::iterator nn = (*it)->node->neighbors.begin(); nn != (*it)->node->neighbors.end(); nn++)
						{
							if ((*nn)->node == node)
							{
								(*nn)->minMutCost += factor;
								(*nn)->minMutTypeAmount[index] += factor;
							}
						}
					}
				}
				else // its neighbor is an internal node
				{
					int nextIndex;
					//assign this neighbor state to the possible state which yields minimum/maximum #. mutations on external branches of the subtree rooted at this neighbor node.
					nextIndex = getRandomIndex((*it)->node->minExBrCost, (*it)->node->charSet[currentStateIndex], minExBr);
					//if current state and the assigned state at the neighbor node are different, increase #. mutations on this branch (the branch connecting these 2 nodes) by 1.
					if (currentStateIndex != nextIndex)
					{
						//branch from currentNode->its neighbor
						(*it)->minMutCost += factor;
						(*it)->minMutTypeAmount[MutProduct[currentStateIndex][nextIndex]] += factor;
						//branch from currentNode's neighbor -> currentNode
						for (NeighborVec::iterator nn = (*it)->node->neighbors.begin(); nn != (*it)->node->neighbors.end(); nn++)
						{
							if ((*nn)->node == node)
							{
								(*nn)->minMutCost += factor;
								(*nn)->minMutTypeAmount[MutProduct[currentStateIndex][nextIndex]] += factor;
							}
						}
					}
					//walk down the tree
					assignMutOnBr(factor, nextIndex, (*it)->node, node, minExBr);
				}
			}
		}else //favor long external branches
		{
			//examine its neighbors
			FOR_NEIGHBOR_IT(node, dad, it)
			{
				if ((*it)->node->isLeaf()) // its neighbor is a leaf
				{
					// current state and the state at the leaf are different ==> increase #. mutations on this branch by 1*factor.
					if (MutState[currentStateIndex] != (*it)->node->charSet[currentStateIndex])
					{
						//branch from currentNode->its neighbor
						(*it)->maxMutCost += factor;
						int index = MutProduct[currentStateIndex][InversedMutState[(*it)->node->charSet[currentStateIndex]]];
						(*it)->maxMutTypeAmount[index] += factor;
						//branch from currentNode's neighbor -> currentNode
						for (NeighborVec::iterator nn = (*it)->node->neighbors.begin(); nn != (*it)->node->neighbors.end(); nn++)
						{
							if ((*nn)->node == node)
							{
								(*nn)->maxMutCost += factor;
								(*nn)->maxMutTypeAmount[index] += factor;
							}
						}
						
					}
				}
				else // its neighbor is an internal node
				{
					int nextIndex;
					//assign this neighbor state to the possible state which yields minimum/maximum #. mutations on external branches of the subtree rooted at this neighbor node.
					nextIndex = getRandomIndex((*it)->node->maxExBrCost, (*it)->node->charSet[currentStateIndex], minExBr);
					//if current state and the assigned state at the neighbor node are different, increase #. mutations on this branch (the branch connecting these 2 nodes) by 1*factor.
					if (currentStateIndex != nextIndex)
					{
						//branch from currentNode->its neighbor
						(*it)->maxMutCost += factor;
						(*it)->maxMutTypeAmount[MutProduct[currentStateIndex][nextIndex]] += factor;
						//branch from currentNode's neighbor -> currentNode
						for (NeighborVec::iterator nn = (*it)->node->neighbors.begin(); nn != (*it)->node->neighbors.end(); nn++)
						{
							if ((*nn)->node == node)
							{
								(*nn)->maxMutCost += factor;
								(*nn)->maxMutTypeAmount[MutProduct[currentStateIndex][nextIndex]] += factor;
							}
						}
					}
					//walk down the tree
					assignMutOnBr(factor, nextIndex, (*it)->node, node, minExBr);
				}
			}	
		}
	}
}

void Tree::normalizeBrCost(double factor, Node* node, Node *dad)
{
	if (node == NULL) node = root;
	if (node == root || (!node->isLeaf()))
	{
		//examine its neighbors
		FOR_NEIGHBOR_IT(node, dad, it)
		{
			(*it)->minMutCost /= factor;
			(*it)->maxMutCost /= factor;
			normalizeBrCost(factor, (*it)->node, node);
		}
	}
}

void Tree::convertSplits(SplitSet &spSet, Split *resp, Node* node, Node *dad)
{
	if (!node || node == root)
	{
		node = root->neighbors[0]->node;
		dad = root;
	}
	assert(resp->getNTaxa() == leafNum);
	bool has_child = false;
	FOR_NEIGHBOR_IT(node, dad, it) {
		Split *sp = new Split(leafNum);
		convertSplits(spSet, sp, (*it)->node, node);
		*resp += *sp;
		spSet.push_back(sp);
		has_child = true;
	}
	if (!has_child)
		resp->addTaxon(node->seqID);
}

void Tree::updateRoot(StringVec taxa)
{
	if (rooted == true && !taxa.empty())
		outError(ERR_CONFLICT_ROOT);
	//number of taxa in the outgroup
	int outNum = taxa.size();	
	if (!rooted)
	{
		
		Node *otherNode = new Node();
		//user provides outgroup, find the branch (split) on the tree corresponding to those taxa		
		if (outNum > 0)
		{
			//form a split (according to the seqID) reflecting the outgroup set
			Split givenSplit(leafNum);
			for (int i=0; i<outNum; i++)
			{
				int curSeqID = findSeqID(taxa[i]);
				if (curSeqID == -1)
				{
					string err = ERR_NO_LEAF_NAME;
					err += taxa[i];
					outError(err);
				}
				givenSplit.addTaxon(curSeqID);
			}
			//find whether the givenSplit is actually on the tree, return 1 node, the other node of the branch is otherNode;			
			Split *tempSplit = new Split(leafNum);
			Node *newOutGroup = findSplit(givenSplit,tempSplit,otherNode);
			//not found
			if (newOutGroup == NULL)
			{				
				outError("No branch on the tree contains the given taxon set");
			}			
			//found a node with descendants having the given names ==> assign this Node to outgroup
			outgroup = newOutGroup;			
		}
		else
		{
			//user does not provide any outgroup, assign outgroup to the first leaf in Nexus file by default
			outgroup = root;
			otherNode = outgroup->neighbors[0]->node;
		}
		
		//create an internal node as the root of the binary tree, determined by outgroup and otherNode
		Node* newRoot = new Node(nodeNum, ROOT_NAME2);
		double branch_len; //= outgroup->neighbors[0]->length;
		for (NeighborVec::iterator it = outgroup->neighbors.begin(); it != outgroup->neighbors.end(); it++)
			if ((*it) -> node == otherNode) branch_len = (*it)->length;		 
		newRoot->neighbors.push_back(new Neighbor(outgroup, branch_len));
		newRoot->neighbors.push_back(new Neighbor(otherNode, 0.0));
		otherNode->replaceNeighbor(outgroup, newRoot, 0.0);
		outgroup->replaceNeighbor(otherNode, newRoot, branch_len);
	
		//create a fake root as a leaf, connected to the above fake root ==> tree now can be treated as unrooted tree, every node has degree of either 1 or 3. This fake root always has state 1.
		Node* fakeRoot = new Node(leafNum, ROOT_NAME);
		fakeRoot->neighbors.push_back(new Neighbor(newRoot, 0.0));
		newRoot->neighbors.push_back(new Neighbor(fakeRoot, 0.0));
		root = fakeRoot;
	}
}

Node* Tree::findSplit(const Split querySplit, Split *resp, Node *&retNode2, Node* node, Node *dad)
{
	assert(querySplit.getNTaxa() == leafNum);
	assert(resp->getNTaxa() == leafNum);
	if (!node) 
	{
		node = root;
		if (node->seqID >= 0)
			resp->addTaxon(node->seqID);
		if (*resp == querySplit)
		{			
			retNode2 = node->neighbors[0]->node;			
			return node;
		}	
	}
	bool has_child = false;
	FOR_NEIGHBOR_IT(node, dad, it) {
		Split *sp = new Split(leafNum);
		Node* res = findSplit(querySplit, sp, retNode2, (*it)->node, node);
		if (res)
			return res;
		*resp += *sp;			
		has_child = true;
	}
	if (!has_child)
		resp->addTaxon(node->seqID);
	if (*resp == querySplit)
	{		
		retNode2 = dad;
		return node;
	}
	return NULL; 
}

