/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef TREE_H
#define TREE_H

#include "node.h"
#include "split.h"
#include "splitset.h"
#include "pattern.h"
/**
Describe a common tree.

	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/

class Tree{
/*------------METHODS-------------------*/
/*--------------------------------------*/
public:
	friend class Pattern;
	friend class PatternSet;
	/**
		Default constructor
	*/
    Tree();
	/**
		Construct the tree from a treeFile
		@param treeFile name of the file containing the tree
	*/
	Tree(const char *treeFile);
	/**
		Copy constructor
		@param atree another tree
	*/
	Tree(Tree &atree);	

	virtual ~Tree();
	
	/*------READ TREE FROM FILE-----------*/
	/*-------------------------------------*/
	/**
		read the tree from the input file
		@param infile the input file name
	*/
    void readTree(const char *infile);

	/**
		read the tree from the ifstream
		@param in the input stream
	*/
    void readTree(ifstream &in);

	/**
		parse the tree (node) from input stream
		@param in the input stream
		@param ch (IN/OUT) current char
		@param currentNode (IN/OUT) the current node
		@param branchLen (OUT) branch length associated to the current node
	*/	
	void parseFile(ifstream &in, char &ch, Node* &currentNode, double &branchLen);

	/**
		initialize tree, set node structure (nodeID)
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void initializeTree(Node *node = NULL, Node *dad = NULL);

	/**
		release the memory
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
    void freeNode(Node *node = NULL, Node *dad = NULL);

	/*-----------PRINT TREE, SUB-TREE------*/
	/*-------------------------------------*/
	/**
		print information
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void printInfo(Node *node = NULL, Node *dad = NULL);

	/**
		print information with seqID, fitchScore, fitchSet, finalFitchSet
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void printInfoDetail(Node *node = NULL, Node *dad = NULL);

	/**
		print information char sets of possible links
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void printInfoCharSet(Node *node = NULL, Node *dad = NULL);

	/**
		print information of minExBrCost of possible links
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void printInfoMinExBrCost(Node *node = NULL, Node *dad = NULL);
	void printInfoMaxExBrCost(Node *node = NULL, Node *dad = NULL);
	
	/**
		print the tree to the output file in newick format
		@param outfile the output file.
		@param brtype type of branch to print
	*/
	void printTree(const char *outfile, BranchType brtype = BR_LEN);

	/**
		print the tree to the output file in newick format
		@param out the output stream.
		@param brtype type of branch to print
	*/
	void printTree(ostream & out, BranchType brtype = BR_LEN);

	/**
		print the tree to the output file in newick format
		@param out the output file.
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param brtype type of branch to print
	*/
	void printTree(ostream &out, BranchType brtype, Node *node, Node *dad = NULL);

	/**
		print the tree to the output file in newick format with brId
		@param outfile the output file.		
	*/
	void printTreeWithBrId(const char *outfile);

	/**
		print the tree to the out stream in newick format with brId
		@param out the output stream		
	*/
	void printTreeWithBrId(ostream & out);

	/**
		print the tree to the out stream in newick format with brId
		@param out the output stream
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search		
	*/
	void printTreeWithBrId(ostream &out, Node *node, Node *dad = NULL);
		
	/**
		print the tree to the output file in newick format with number of mutations on branches
		@param outfile the output file.
		@param minEx = true, favors short external branches (=false favors long external branches)
	*/
	void printTreeWithMut(const char *outfile, bool minEx = true);

	/**
		print the tree to the out stream in newick format with number of mutations on branches
		@param out the output stream
		@param minEx = true, favors short external branches (=false favors long external branches)
	*/
	void printTreeWithMut(ostream & out, bool minEx = true);

	/**
		print the tree to the out stream in newick format with number of mutations on branches
		@param out the output stream
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param minEx = true, favors short external branches (=false favors long external branches)
	*/
	void printTreeWithMut(ostream &out, bool minEx, Node *node, Node *dad = NULL);

/**
		print amount of mutations of each type on each branch to the output file
		@param outfile the output file.
		@param minEx = true, favors short external branches (=false favors long external branches)
	*/
	void printMutTypeAmount(const char *outfile, bool minEx = true);

	/**
		print amount of mutations of each type on each branch to the output stream
		@param out the output stream
		@param minEx = true, favors short external branches (=false favors long external branches)
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void printMutTypeAmount(ostream & out, bool minEx = true, Node *node = NULL, Node *dad = NULL);	

	/*-----SEARCHING AND OPERATION ON TREE--------*/
	/*-------------------------------------------*/
	/**
		find a node with corresponding name
		@param name node name
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@return node if found, otherwise NULL
	*/
	Node *findNodeName(string &name, Node *node = NULL, Node* dad = NULL);

	/**
		find seqID of a node with a given name
		@param name node name
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@return seqID if found, otherwise -1
	*/
	int findSeqID(string &name, Node *node = NULL, Node* dad = NULL);

	/**
		find a branch/split on the tree corresponding to the given split
		@param querySplit the given split to find
		@param resp the split at the current node (directed by dad)
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@return a node if found, other NULL
	*/
	Node* findSplit(const Split querySplit, Split *resp, Node *&retNode2, Node* node = NULL, Node *dad = NULL);

	/**
		update root of the tree
		@param name of the outgroup to root the tree		
	*/
	void updateRoot(string outgroupName="");

	/**
		update root of the tree on the branch seperating the given taxon set
		@param taxa a set of taxon's names
	*/
	void updateRoot(StringVec taxa);


	/*------CHECKING THE TREE-----------------*/
	/*----------------------------------------*/	
	/**
		check tree is bifurcating tree (every leaf with level 1 or 3)
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param stop (IN/OUT) set = true to stop the search
		@NOTE tree is bifurcating if stop == false at the end
	*/
	void checkValidTree(bool& stop, Node *node = NULL, Node *dad = NULL);

	/*----------SPECIFIC FOR PATTERN MUTATION----*/
	/*-------------------------------------------*/
	/**
		update seqID
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void updateSeqID(StringVec leafName, Node *node = NULL, Node *dad = NULL);

	/**
		compute the score to mutate pattern1 to pattern2 on this tree
		@param pattern1
		@param pattern2
		@param RETURN over all score on this tree
	*/
    int mutScore(string pattern1, string pattern2, bool compStep = false);

	/**
		compute Fitch score of a pattern (nucleotide characters) on this tree
		equivalent to the mutation score between it and a constant pattern
		@param pattern the pattern
		@param RETURN over all score on this tree
	*/
	int mutScore(string pattern, bool compStep = false);

	/**
		compute Fitch score of a pattern (class Pattern) on this tree
		@param pattern the pattern
		@param RETURN	over all score on this tree
	*/
	int mutScore(Pattern *pattern, bool compStep = false);

	/**
		compute mutation score of two pattern in class Pattern
		@param pattern1 the first pattern
		@param pattern2 the second pattern
		@param RETURN 	over all score of the mutated pattern on this tree
	*/
	int mutScore(Pattern *pattern1, Pattern* pattern2, bool compStep = false);

	/**
		compute score of a mutated pattern
		@param mutatedPattern	the mutated pattern that is encoded already
		@param RETURN	over all score of this mutated pattern on this tree
	*/
	int mutScore(IntVec mutatedPattern, bool compStep = false);
	
	/**
		reset all kind of states related to Fitch's: fitchSet, fitchScore, finalFitchSet, MinExBrCost, MaxExBrCost, charSet, allCharSet
	*/
	void resetAllStates();

	/**
		assign fitch set - preliminary phase in Fitch algorithm (digitalized as number in the K3stMatrix) and compute the score
		@param pattern to set to the leaf
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param score (IN/OUT) the score (cost/number of mutations needed)
		@param compStep to actually compute the mutation step of the current patterns.
	*/
	void assignFitchSet(IntVec pattern, int &score, Node* node = NULL, Node* dad = NULL, bool compStep = false);

	/**
		get final fitch set - final phase in Fitch algorithm. Used only after assignFitchSet being called.		
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search		
	*/
	void getFinalFitchSet(Node* node = NULL, Node* dad = NULL);

	/**
		To enumerate all possible links in Fitch 1971 algorithm. Each node having a vector of size StateNum (4 in this case) called charSet. charSet[0] means all possible characters at this node, e.g. 0001, 0110, ... if its immediate ancestor state index is 0. The union of charSet[0] U ... U charSet[3] is allCharSet meaning all possible characters at this node when its parent index is 0 or 1 or 2 or 3. This also follows Fitch 1971 rules.

		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM:
		assigning possible character set at this node given the character state at its ancestor.		
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param dadStateIndex index (0..3) of character state at dad
		==> this will change charSet!
	*/
	void assignCharSet(int dadStateIndex, Node* node = NULL, Node* dad = NULL);
	void assignAllCharSet(Node* node = NULL, Node* dad = NULL);

	/**
		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM:
		computing the minimum of the sum of all external branches in a subtree rooted at node, for all allowed characters at this node.
		At each node we have a vector minExBrCost of size StateNum (size 4 for nucleotides). minExBrCost[i] is the minimum of the total mutations on all external branches of the substree rooted at this node when the state index at this node is i (i = 0.. 3).
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param currentStateIndex index (0..3) of character state at current node
	*/
	void computeMinMaxExBrCost(int currentStateIndex = 0, Node* node = NULL, Node* dad = NULL);
	
	/**
		USE IN ASSIGNING MUTATIONS ON BRANCHES - FINDING POSSIBLE LINKS IN FITCH ALGORITHM:
		assigning mutations on branches favoring long internal branches (minExBr = true) or long external branches (minExBr = false).
		This will update min/maxMutCost on each branch (min/maxCost is a attribute of Neighbor class).
		@param minExBr favors long internal branches (true) or long external branches (false)
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
		@param factor #.mutations on each branch will be multiple by this factor. It is used if 2 patterns have been matched with the other more than once.
	*/
	void assignMutOnBr(double factor = 1.0, int currentStateIndex = 0, Node* node = NULL, Node* dad = NULL, bool minExBr = true);

	/**
		reset fitchSet on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetFitchSet(int value = 0, Node *node = NULL, Node *dad = NULL);

	/**
		reset finalFitchSet on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetFinalFitchSet(int value = 0, Node *node = NULL, Node *dad = NULL);

	/**
		reset fitchScore on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetFitchScore(int value = 0, Node *node = NULL, Node *dad = NULL);
	
	/**
		reset minExBrCost on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetMinExBrCost(int value = MaxExBrCost, Node *node = NULL, Node *dad = NULL);
	/**
		reset maxExBrCost on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetMaxExBrCost(int value = -1, Node *node = NULL, Node *dad = NULL);

	/**
		reset charSet on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetCharSet(int value = 0, Node *node = NULL, Node *dad = NULL);
	/**
		reset allCharSet on all nodes of the (sub)tree
		@param value the new value
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void resetAllCharSet(int value = 0, Node *node = NULL, Node *dad = NULL);
	
	/**
		set Id for the branches of a subtree rooted at node
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void setBrId(Node *node = NULL, Node *dad = NULL);

	/**
		reset brID for the whole tree
	*/
	void resetBrId();

	/**
		nomalize branch cost - #. mutations of branches by factor
		@param factor the factor to nomalize, usually is the sequence length
		@param node the starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void normalizeBrCost(double factor = 1.0, Node* node = NULL, Node *dad = NULL);	

	/**
		convert a (sub) tree rooted at node into a set of splits. Tree is treated as rooted tree. In the splits, taxon order is the same as in the alignment. Split set is then used to generate 1, 2, 3 step mutated patterns.
		@param spSet (OUT) returned split set
		@param resp (OUT) the split at current node
		@param node starting node, NULL to start from the root
		@param dad dad of the node, used to direct the search
	*/
	void convertSplits(SplitSet &spSet, Split *resp, Node* node = NULL, Node *dad = NULL);
	
	

/*-------------ATTRIBUTES---------------*/
/*--------------------------------------*/
/**
	Root of the tree. When reading from file, it's an artificial root. If user sets it, it will be updated (will change) by this time.
*/
	Node* root;
/**
	Number of leaves on the tree
*/
	int leafNum;
/**
	Total number of nodes on the tree
*/
	int nodeNum;
/**
	Total number of branches on the tree
*/
	int brNum;
/**
	if the tree is really rooted infered from tree-file. TRUE if
	for example: (1) (newick format):_num; //_num>0
				(2) (newick format); //and the artificial root has exactly 2 neighbor --> create a new Node, call _root, _root.neighbor=root, assign root=_root. This is to make sure that root is a leaf.
	TODO: after parseFile (node, branchLength)
	if (branchLength>0): create a new Node, call _root, _root.neighbor=root, assign root=_root.
	else if (root has 2 neighbor): create a new Node, call _root, _root.neighbor=root, assign root=_root.
	==> rewrite the code for more efficient
*/
	bool rooted;
	Node* outgroup;
};

#endif
