/***************************************************************************
 *   Copyright (C) 2009 by Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler   *
 *   {minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef UTILITY_H
#define UTILITY_H

#include <vector>
#include <set>
#include <string>
#include <string.h>
#include <iostream>
#include <fstream>
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <exception>
#include <ctime>
#include <cassert>
#include <algorithm>

using namespace std;

/**
common utilities

	@author Minh Anh Thi Nguyen, Steffen Klaere, Arndt von Haeseler <{minh.anh.nguyen, steffen.klaere, arndt.von.haeseler}@univie.ac.at>
*/
/**=================================================*/
/**======== CONSTANT VARIABLES =====================*/
/** 
	significance level
*/
const double alpha = 0.05;
/**
	Mutation matrix due to Kimura 3st, orginal looks like this, 1, 2, 3 is the mutation type.
		A	C	G	T
	A	-	2	1	3
	C	2	-	3	1
	G	1	3	-	2
	T	3	1	2	-
	(A:0, C:1, G:2, T:3)
	To make it easy for computing fitch's score by bitwise AND and inclusive OR, use the following instead.
	Note:	1 = 0001 ==> e0
			2 = 0010 ==> e1
			4 = 0100 ==> e2
			8 = 1000 ==> e3
*/
const int K3stMatrix[4][4] ={1, 4, 2, 8,
							4, 1, 8, 2,
							2, 8, 1, 4,
							8, 2, 4, 1};

/**
	product of 2 mutations. E.g. e1 * e0 = e1, e1 * e1 = e0, e1 * e2 = e3
	its looks like this
	e0	e1	e2	e3
e0	-	e1	e2	e3
e1		-	e3	e2
e2			-	e1
e3				-
*/
const int MutProduct[4][4] = {	0, 1, 2, 3,
								1, 0, 3, 2,
								2, 3, 0, 1,
								3, 2, 1, 0};
/**
	to store the mutation
*/
const int MutState[4] = {1, 2, 4, 8};
const int InversedMutState[9] = {-1, 0, 1, -1, 2, -1, -1, -1, 3};
		//corresponding mutState  -, 1, 2,  -, 4,  -,  -,  -, 8

const int MaxExBrCost = 20000;

/**
	maximum sequence's length in a generated alignment to run tree-puzzle.
	When there are more than MaxGenAlignLen patterns generated, need to divide
	them into smaller alignments. It is to avoid the memory problem.
*/
const int MaxGenAlignLen = 200000;

/**
	When the estimated memory usage exceed this number (4GB), simply stop the program.
*/
const unsigned long MaxMemAllow = 4000000000;

/**
	number of nucleotides (A,C,G,T/U)
*/
const int StateNum = 4;
const char Nucleotides[4] = {'A','C','G','T'};

/**
	Given a nucleotide character(Char) and a mutation type (Mut), output the mutated character
	Char\Mut	|	0	1	2	3
		--------|----------------------
			A	|	A	G	C	T
			C	|	C	T	A	G
			G	|	G	A	T	C
			T	|	T	C	G	A
	Note A=0, C=1, G=2, T=3
*/
const char MutatedChar[4][4] = {'0', '2', '1', '3',
								'1', '3', '0', '2',
								'2', '0', '3', '1',
								'3', '1', '2', '0'};

/**
	number of mutation types: 4
	type 0: no change
	type 1, 2, 3 see the above comment
*/
const int MutType = 4;
/**
	uncertain character ? and gap -
*/
const char UGAP[] 	= ".-?RYMKWSBDHVNXrymkwsbdhvnx";

/**
	maximum number of space between sequence's name and the sequence itself
	used when reading interleave Phylip format
*/
const int MAX_NUM_SPACE = 256;

/**
	maximum size of a file name
*/
const int MAX_FILE_NAME = 500;
/**========================================================================*/
/**============ DEFINE SOME DATA TYPES ====================================*/
typedef vector< string > StringVec;
typedef vector< int > IntVec;
typedef vector< double > DoubleVec;
typedef vector< long > LongVec;
typedef vector< bool > BoolVec;
typedef vector< long double > LongDoubleVec;

typedef set< int, std::less< int> > IntSet;

//used for Split and Pattern
// typedef int UINT;
// const int UINT_BITS = sizeof(UINT) * 8;

#define matrix(T) vector< vector< T > >

/**
	matrix of double
*/
typedef matrix( double ) DoubleMatrix;

/**
	matrix of integers
*/
typedef matrix( int ) IntMatrix;

/**
	matrix of long integers
*/
typedef matrix( long ) LongMatrix;

typedef matrix( bool ) BoolMatrix;

/**
	when print tree: 
		BR_LEN - output branch length
		BR_NONE - don't output branch length		
*/
enum BranchType {BR_LEN, BR_NONE};

/**==============================================================================*/
/**
	parameters for the whole programs (mainly taken from command line arguments)
*/
struct Params{
	/**=================================================*/
	/**				INPUT								*/
	/**=================================================*/
	/**
		alignment file name
	*/
	char* alignFile;
	/**
		input tree file name
	*/
	char* treeFile;
	/**
		tree to run puzzle if it different from the above tree
	*/
	char* pztree; 
	/**
		if the user provides likelihood of the patterns in the alignment
		Format: pattern Number_of_occurences LogLikelihood
	*/
	char* patFile;
	/**
		params to run TREE-PUZZLE, to compute likelihood of patterns on a given tree
		Must be in correct format
	*/
	char* puzzleFile;
	/**
		file contains outgroup taxa
	*/
	char *outgroupFile;
	/**
		if the user want to assign extra-substitutions on the tree
	*/
	bool ass;
	/**
		to stop the program if it requires too much memory while generating patterns.
	*/
	bool memStop;
	/**
		whether user wants to include the number of branches into the degree of freedom.
	*/
	bool ciBr;
	/**
		number of degree of freedom from the model, inputted by user
	*/
	int mdf;
	/**
		hidden Option: to not include observed pattern which not yet reach the upper bound into D- (under-represented set)
	*/
	bool noInit;
	/**
		to print unobserved, generated patterns upto mstep-mutation away from the constant pattens.
	*/
	int mstep;
	/**
		to print additional output files
	*/
	bool add;
	/**=============== derived input ===================*/
	/**
		string vector contains outgroup taxa, inputted by users
	*/
	StringVec outgroup;
	
	/**================================================*/
	/**					FOR OUTPUTTING					*/
	/**================================================*/
	/** 
		prefix of the output files provided by the user
	*/
	char* uprefix;
	/**
		file containing the final score (number of extra-substitutions
	*/
	string outScore;
	/**
		file containing the matching
	*/
	string outMatching;
	/**
		file containing patterns observed more: pattern - number of times observed more
	*/
	string outMore;

	//add on 2009.09.10
	/**
		file containing patterns observed more, write in the format of an alignment
	*/
	string outMoreAlign;
	/**
		file containing the matching in visible way
	*/
	string outMatchingPat;

	/**
		file containing patterns observed less: pattern - number of times observed less
	*/
	string outLess;
	/**
		file containing the score matrix between each pattern observed more and each pattern observed less
	*/
	string outScoreMatrix;
	/**
		file containing general output information
	*/
	string outAll;

	/**
		file containing tree with labeled branches
	*/
	string outTreeBrLb;
	/**
		file containing tree with mutations assigned on branches favoring long internal branches
	*/
	string outTreeMin;
	/**
		file containing tree with mutations assigned on branches favoring long external branches
	*/
	string outTreeMax;
	/**
		file (table - 5 columns) containing (1)branch label,(2)-(4) number of mutations of type 1,2,3 on this branch, (5) total number of mutations on this branch. (5)=(2)+(3)+(4). This assignment favors long internal branch.
	*/
	string outTableMin;
	/**
		file (table - 5 columns) containing (1)branch label,(2)-(4) number of mutations of type 1,2,3 on this branch, (5) total number of mutations on this branch. (5)=(2)+(3)+(4). This assignment favors long external branch.
	*/
	string outTableMax;
	/**
		to output positions of over-represented patterns
	*/
	string outOverPos;
	/**
		to output align less patterns
	*/
	string outAlignLess;
	/**
		to output all patterns in the alignment with mutation step
	*/
	string outAlignPat;
	/**
		to output more and less patterns from the alignment
	*/
	string outAlignMoreLess;

	/** 
		to compute some running time
	*/
	long mutRunTime;
	long bmcRunTime;
	long assRunTime;	
};

/*--------------------------------------------------------------*/
/*--------------------------------------------------------------*/
/**
	@return TRUE if ch is a control character (ascii <= 32)
*/
inline bool controlchar(char ch) {
	return ch <= 32;
}
/**
	@return TRUE of ch is a character (not alphabet) used in Newick format
*/
inline bool is_newick_token(char ch) {
	return ch == ':' || ch == ';' || ch == ',' || ch == ')' || ch == '(';
}
/*--------------------------------------------------------------*/
/*--------------------------------------------------------------*/
/**
	print error message then exit program
*/
void outError(const char *error);

/**
	print error message then exit program
*/
void outError(string error);

/*--------------------------------------------------------------*/
/*--------------------------------------------------------------*/
/**
	print double error messages then exit the program
*/
void outError(const char *error, const char *msg);

/**
	print double error messages then exit program
*/
void outError(const char *error, string msg);

/*--------------------------------------------------------------*/
/*--------------------------------------------------------------*/
/**
	convert string to integer, with error checking
	@param str original string
	@return the integer value
*/
int convert_int(const char *str) throw (string);

/**
	convert string to double, with error checking
	@param str original string
	@return the double
*/
double convert_double(const char *str) throw (string);


/**
	search for a string in a vector of strings.
	@param stringToFind the string to search (target)
	@param strVec a vector of string
	@RETURN the index of the stringToFind in strVec if found, otherwise -1	
*/
int searchString(string stringToFind, StringVec strVec);

/**
	get the ordinary rounding of a double number
	@param num a double number
	@RETURN its orinary rounding (integer)
*/
double ordinaryRound(double num);

/**
	print a matrix
	@param out outstream
	@param matr the matrix to print
*/
void printIntMatrix(ostream &out, IntMatrix matr);

/**
	print a matrix
	@param out outstream
	@param matr the matrix to print
*/
void printBoolMatrix(ostream &out, BoolMatrix matr);

/**
	initialize a matrix of a given size with a given value
	@param intMat (IN/OUT) the matrix need to be initialized
	@param row,col size of the matrix
	@param value initial value
*/
void initIntMatrix(IntMatrix &matr, int row, int col, int value);

/**
	reset all elements of an integer vector to a new value
	@param vec (IN/OUT) the vector
	@param value the new value
*/
void resetIntVector(IntVec &vec, int value);

/**
	reset all elements of a boolean vector to a new value
	@param vec (IN/OUT) the vector
	@param value the new value
*/
void resetBoolVector(BoolVec &vec, bool value);

/**
	reset all elements of an integer matrix to a new value
	@param matr (IN/OUT) the matrix
	@param value the new value
*/
void resetIntMatrix(IntMatrix &matr, int value);


/*--------------------------------------------------------------*/
/*--------------------------------------------------------------*/
/**
	get the mutated pattern from 2 patterns due to Kimura 3st.
	@param pattern1 the first of 2 input patterns
	@param pattern2 the second of 2 input patterns
	@RETURN the mutated pattern due to Kimura 3st
*/
IntVec getMutatedPattern(string pattern1, string pattern2);

/**
	convert an IntVec to string
*/
string mutatedVec2Str(IntVec avec);

/**
	Common error messages
*/
const char ERR_DUPLICATED_LEAVE[] 		= "Duplicated taxon's name in the tree: ";
const char ERR_DUPLICATED_SEQUENCE[] 	= "Duplicated sequence name: ";
const char ERR_CONFLICT_ROOT[] 			= "Tree is already rooted, -o <taxon> is not allowed.";
const char ERR_NO_LEAF_NAME[] 			= "Find no taxon in the tree with name: ";
const char ERR_NO_SEQUENCE_NAME[] 		= "Find no sequence with name: ";
const char ERR_NEG_BRANCH[]        		= "Negative branch length not allowed.";
const char ERR_TOO_FEW_TAXA[]			= "Number of taxa must be greater than 2.";
const char ERR_NOT_BIFURCATING[]		= "Tree is not bifurcating";
const char ERR_ROOT_AT_INNER[]			= "Outgroup is not a leaf: ";

const char ERR_NO_MEMORY[]         = "Not enough memory!";

const char ERR_READ_INPUT[]        = "File not found or incorrect input, pls check it again: ";
const char ERR_UNEXPECTED_EOF[]    = "Unexpected end of file: ";
const char ERR_READ_ANY[]          = "Unidentified error while reading file, pls check it carefully again: ";
const char ERR_WRITE_OUTPUT[]      = "Cannot write to file: ";
const char ERR_READ_MISSING_DATA[]   = "Missing data in file: ";

/*--------------------------------------------------------------*/
/*--------------------------------------------------------------*/
/**
	print copy right
*/
void printCopyright();

/**
	print help - usage
	@param argv to get the name of the program (argv[0])
*/
void printHelp(char* argv[]);

/**
	parse the argument in command line parameter list
	@param argc number of arguments
	@param argv array contains the arguments
	@param params (IN/OUT) to store the arguments
*/
void parseArg(int argc, char* argv[], Params &params);

/**--utilities only used in this scope to read input, process and output*/
/**
	read strings from a file, each string in one line.
	@param inFile input file
	@param retVec the returned vector of strings
*/
void readStringVec(const char* inFile, StringVec &retVec);

/**
	read strings from a stream, each string in one line.
	@param in input stream
	@param retVec the returned vector of strings
*/
void readStringVec(ifstream &in, StringVec &retVec);
/**
	return the minimum value of a vector of integer, with index in indexSet
	indexSet is 0001, 0011, ..., 1111
	@param inputVec vector of integer, should be of size 4
	@param indexSet range from 0000, 0001, ..., 1111
	indexSet = 0 means all indices are taken into account
	@return the minimum value
*/
int getMin(IntVec inputVec, int indexSet = 0);

int getMax(IntVec inputVec, int indexSet = 0);
/**
	return the index of the minimum (if min == true) or maximum (if min == false) of a vector of integer, with index in indexSet. indexSet is 0001, 0010, 0011, ..., 1111
	@param inputVec vector of integer, should be of size 4
	@param indexSet range from 0000, ..., 1111
	@return the index of the minimum or maximum value selected randomly if more than 1 existing.
*/
int getRandomIndex(IntVec inputVec, int indexSet = 0, bool min = true);

/**
	generate a random integer number of interval [0..max]
*/
int genRanInt(const int max);

/**
	remove all white spaces in a string.
	@param str (IN/OUT) the string need to exclude white spaces
*/
void removeSpaces(string &str);

/**
	Read a vector of double (site likelihood) from an output file of puzzle or iqpnni .sitelh
	@param file file contains site likelihood
	@param logllVec (OUT) double vector contains site's log likelihood
*/
void readSitelh (const char* file, DoubleVec &logllVec);

/**
	Read a vector of double (site likelihood) from an input stream in format of .sitelh outputted by iqpnni & puzzle
	@param in input stream
	@param logllVec (OUT) double vector contains site's log likelihood
*/
void readSitelh (ifstream &in, DoubleVec &logllVec);

/**
	Decompose a vector of ascending sorted integers into intervals of consecutive numbers.
	This is an utility to determine positions of over-represented patterns that should be replaced.
	@param intVec the input vector of sorted integers.
	The returning matrix of integers is format as follows:
	It contains a number of vector of integers.
	Each vector of integer contains 2 number. The first one is a postion in the alignment. The second one denotes the number of consecutive postions in the alignment starting by the first one.
	
*/
IntMatrix decomposeInterval(const IntVec intVec);

/**
	add an integer vector (containning a starting point as the first element and the number of consecutive numbers as the second element) into a matrix contains decomposed intervals of integer numbers.
	The number of elements to be added must not exceed a certain amount.
	Target: if the input vector can be combined to any vector in the target matrix, just combine it. Otherwise, add one more row to the target matrix.
	@param intMatrix a matrix to add a vector into
	@param intVec the vector to be added
	@param amount (IN/OUT) maximum amount to add. If (amount > intVec[1]) return the remaining (amount -= amount - intVec[1]);
*/
void add2Intervals(IntMatrix &intMatrix, const IntVec intVec, int &amount);

/**=========== NOT USE ANYMORE ====================================*/

/**
	read the sequence's names from alignment file (input file), alignment must be in phylip sequential format and at least 1 space between the name and the biological sequence
*/
// void readSeqNameFile (const char* inFile, int &seqNum, StringVec &seqNames);

/**
	read the sequence's names from alignment stream (input file), alignment must be in phylip sequential format and at least 1 space between the name and the biological sequence
*/
 //void readSeqNameStream (ifstream &in, int &seqNum, StringVec &seqNames);

/**
	read input file in the format of iqpnni output, the file with extension .patll
*/
// void readPatllFile (const char* inFile, int &seqLen, int &pattNum, StringVec &patternVec, IntVec &observedNum, IntVec &expectedNum);

/**
	read input from input stream in the format of iqpnni output, the file with extension .patll
*/
// void readPatllStream (ifstream &inFile, int &seqLen, int &pattNum, StringVec &patterns, IntVec &observedNum, IntVec &expectedNum);

/**
	compute the pattern observed more, less than expected
*/
// void computeDiff (StringVec patternVec, int pattNum, IntVec observedNum, IntVec expectedNum, StringVec &morePatterns, StringVec &lessPatterns, IntVec &moreAmounts, IntVec &lessAmounts);

/**
	compute the expected number of occurence from log-likelihood due to rounding
*/
//void computeExOccur(int seqLen, int pattNum, DoubleVec logLL, IntVec &expectedNum);

/**
	compute confidence intervals for a vector of logLLs
*/
// void computeConInter(int seqLen, DoubleVec logLLs, DoubleVec &upperBounds, DoubleVec &lowerBounds);

//seqLen = 1...5000. This table provide the (1-alpha/(2*seqLen)) quantile of the standard normal distribution, where alpha = 0.05.
// const double QnormTable[10000] = {1.959964,2.241403,2.39398,2.497705,2.575829,2.638257,2.690110,2.734369,2.772921,2.807034,2.837597,2.86526,2.890512,2.913726,2.935199,2.955167,2.97382,2.991316,3.007787,3.023341,3.038074,3.052065,3.065383,3.078088,3.090232,3.101862,3.113017,3.123735,3.134046,3.14398,3.153563,3.162818,3.171766,3.180426,3.188815,3.19695,3.204845,3.212514,3.219968,3.227218,3.234277,3.241152,3.247854,3.254389,3.260767,3.266995,3.273078,3.279024,3.284839,3.290527,3.296094,3.301545,3.306885,3.312118,3.317247,3.322278,3.327213,3.332056,3.33681,3.341479,3.346065,3.350571,3.355,3.359354,3.363635,3.367847,3.371991,3.376069,3.380084,3.384036,3.387929,3.391763,3.395541,3.399264,3.402933,3.40655,3.410117,3.413634,3.417104,3.420527,3.423904,3.427237,3.430527,3.433775,3.436982,3.440148,3.443276,3.446365,3.449417,3.452433,3.455413,3.458358,3.461269,3.464147,3.466993,3.469807,3.472589,3.475341,3.478063,3.480756,3.483421,3.486057,3.488666,3.491248,3.493804,3.496334,3.498838,3.501318,3.503773,3.506205,3.508613,3.510998,3.51336,3.5157,3.518018,3.520315,3.522591,3.524846,3.527081,3.529296,3.531492,3.533668,3.535825,3.537963,3.540084,3.542186,3.544271,3.546338,3.548388,3.550421,3.552438,3.554438,3.556422,3.558390,3.560343,3.562281,3.564203,3.566110,3.568003,3.569881,3.571745,3.573596,3.575432,3.577254,3.579064,3.580860,3.582642,3.584412,3.58617,3.587915,3.589647,3.591368,3.593076,3.594772,3.596457,3.598130,3.599792,3.601443,3.603083,3.604711,3.606329,3.607937,3.609533,3.611120,3.612696,3.614262,3.615818,3.617364,3.6189,3.620427,3.621944,3.623452,3.62495,3.626439,3.627920,3.629391,3.630853,3.632307,3.633752,3.635188,3.636616,3.638036,3.639447,3.64085,3.642245,3.643632,3.645012,3.646383,3.647747,3.649103,3.650451,3.651792,3.653126,3.654452,3.655771,3.657083,3.658387,3.659685,3.660976,3.66226,3.663537,3.664807,3.666071,3.667328,3.668579,3.669823,3.671061,3.672292,3.673517,3.674736,3.675949,3.677156,3.678356,3.679551,3.68074,3.681923,3.6831,3.684271,3.685437,3.686597,3.687752,3.688901,3.690044,3.691182,3.692315,3.693442,3.694564,3.695681,3.696793,3.697899,3.699000,3.700097,3.701188,3.702275,3.703356,3.704433,3.705504,3.706571,3.707634,3.708691,3.709744,3.710792,3.711836,3.712875,3.71391,3.71494,3.715966,3.716987,3.718004,3.719016,3.720025,3.721029,3.722029,3.723025,3.724016,3.725004,3.725987,3.726966,3.727941,3.728913,3.72988,3.730844,3.731803,3.732759,3.733711,3.734659,3.735603,3.736544,3.73748,3.738414,3.739343,3.740269,3.741191,3.74211,3.743025,3.743937,3.744845,3.745749,3.746651,3.747548,3.748443,3.749334,3.750221,3.751106,3.751987,3.752865,3.753739,3.754611,3.755479,3.756344,3.757206,3.758064,3.75892,3.759772,3.760622,3.761468,3.762312,3.763152,3.763989,3.764824,3.765655,3.766484,3.767309,3.768132,3.768952,3.769769,3.770583,3.771395,3.772203,3.773009,3.773812,3.774613,3.775410,3.776205,3.776998,3.777787,3.778574,3.779359,3.780141,3.78092,3.781696,3.782470,3.783242,3.784011,3.784778,3.785542,3.786303,3.787062,3.787819,3.788573,3.789325,3.790074,3.790821,3.791566,3.792308,3.793048,3.793785,3.794521,3.795254,3.795984,3.796713,3.797439,3.798163,3.798884,3.799604,3.800321,3.801036,3.801749,3.80246,3.803168,3.803875,3.804579,3.805281,3.805982,3.806680,3.807375,3.808069,3.808761,3.809451,3.810139,3.810824,3.811508,3.81219,3.812870,3.813547,3.814223,3.814897,3.815569,3.816239,3.816907,3.817573,3.818237,3.8189,3.81956,3.820219,3.820876,3.821531,3.822184,3.822835,3.823484,3.824132,3.824778,3.825422,3.826064,3.826705,3.827344,3.827981,3.828616,3.829249,3.829881,3.830511,3.83114,3.831766,3.832392,3.833015,3.833637,3.834257,3.834875,3.835492,3.836107,3.836720,3.837332,3.837943,3.838551,3.839158,3.839764,3.840368,3.84097,3.841571,3.84217,3.842768,3.843364,3.843959,3.844552,3.845143,3.845734,3.846322,3.846909,3.847495,3.848079,3.848662,3.849243,3.849823,3.850401,3.850978,3.851553,3.852128,3.8527,3.853271,3.853841,3.854410,3.854977,3.855542,3.856106,3.856669,3.857231,3.857791,3.85835,3.858907,3.859463,3.860018,3.860571,3.861124,3.861674,3.862224,3.862772,3.863319,3.863865,3.864409,3.864952,3.865494,3.866034,3.866573,3.867111,3.867648,3.868184,3.868718,3.869251,3.869783,3.870313,3.870842,3.871371,3.871898,3.872423,3.872948,3.873471,3.873993,3.874514,3.875034,3.875553,3.87607,3.876586,3.877102,3.877616,3.878128,3.87864,3.879151,3.87966,3.880168,3.880676,3.881182,3.881687,3.882191,3.882693,3.883195,3.883696,3.884195,3.884694,3.885191,3.885687,3.886182,3.886677,3.88717,3.887662,3.888153,3.888643,3.889131,3.889619,3.890106,3.890592,3.891077,3.89156,3.892043,3.892525,3.893006,3.893485,3.893964,3.894442,3.894918,3.895394,3.895869,3.896343,3.896815,3.897287,3.897758,3.898228,3.898697,3.899165,3.899632,3.900098,3.900563,3.901027,3.90149,3.901953,3.902414,3.902874,3.903334,3.903793,3.90425,3.904707,3.905163,3.905618,3.906072,3.906525,3.906977,3.907429,3.907879,3.908329,3.908777,3.909225,3.909672,3.910118,3.910564,3.911008,3.911451,3.911894,3.912336,3.912777,3.913217,3.913656,3.914094,3.914532,3.914969,3.915405,3.91584,3.916274,3.916707,3.91714,3.917572,3.918003,3.918433,3.918862,3.919291,3.919718,3.920145,3.920571,3.920997,3.921421,3.921845,3.922268,3.92269,3.923112,3.923532,3.923952,3.924371,3.92479,3.925207,3.925624,3.92604,3.926455,3.92687,3.927284,3.927697,3.928109,3.928520,3.928931,3.929341,3.929751,3.930159,3.930567,3.930974,3.931381,3.931786,3.932191,3.932595,3.932999,3.933402,3.933804,3.934205,3.934606,3.935006,3.935405,3.935804,3.936202,3.936599,3.936995,3.937391,3.937786,3.938181,3.938574,3.938967,3.93936,3.939751,3.940142,3.940533,3.940923,3.941312,3.9417,3.942088,3.942475,3.942861,3.943247,3.943632,3.944016,3.9444,3.944783,3.945166,3.945548,3.945929,3.946309,3.946689,3.947069,3.947447,3.947825,3.948203,3.948579,3.948956,3.949331,3.949706,3.95008,3.950454,3.950827,3.951199,3.951571,3.951942,3.952313,3.952683,3.953053,3.953421,3.953790,3.954157,3.954524,3.954891,3.955256,3.955622,3.955986,3.956350,3.956714,3.957077,3.957439,3.957801,3.958162,3.958523,3.958883,3.959242,3.959601,3.959959,3.960317,3.960674,3.961031,3.961387,3.961742,3.962097,3.962452,3.962806,3.963159,3.963512,3.963864,3.964216,3.964567,3.964917,3.965267,3.965617,3.965966,3.966314,3.966662,3.967009,3.967356,3.967702,3.968048,3.968393,3.968738,3.969082,3.969426,3.969769,3.970111,3.970453,3.970795,3.971136,3.971476,3.971816,3.972156,3.972495,3.972833,3.973171,3.973509,3.973846,3.974182,3.974518,3.974854,3.975189,3.975523,3.975857,3.976191,3.976524,3.976856,3.977188,3.97752,3.977851,3.978181,3.978511,3.978841,3.97917,3.979499,3.979827,3.980154,3.980482,3.980808,3.981135,3.98146,3.981786,3.982110,3.982435,3.982759,3.983082,3.983405,3.983728,3.98405,3.984371,3.984692,3.985013,3.985333,3.985653,3.985972,3.986291,3.98661,3.986928,3.987245,3.987562,3.987879,3.988195,3.988511,3.988826,3.989141,3.989455,3.989769,3.990083,3.990396,3.990709,3.991021,3.991333,3.991644,3.991955,3.992266,3.992576,3.992885,3.993195,3.993503,3.993812,3.99412,3.994427,3.994734,3.995041,3.995347,3.995653,3.995959,3.996264,3.996568,3.996872,3.997176,3.99748,3.997783,3.998085,3.998387,3.998689,3.998991,3.999291,3.999592,3.999892,4.000192,4.000491,4.00079,4.001089,4.001387,4.001685,4.001982,4.002279,4.002576,4.002872,4.003168,4.003463,4.003758,4.004053,4.004347,4.004641,4.004934,4.005227,4.00552,4.005812,4.006104,4.006396,4.006687,4.006978,4.007268,4.007558,4.007848,4.008137,4.008426,4.008715,4.009003,4.009291,4.009578,4.009866,4.010152,4.010439,4.010725,4.01101,4.011295,4.01158,4.011865,4.012149,4.012433,4.012716,4.013000,4.013282,4.013565,4.013847,4.014128,4.01441,4.014691,4.014971,4.015252,4.015531,4.015811,4.01609,4.016369,4.016648,4.016926,4.017204,4.017481,4.017758,4.018035,4.018312,4.018588,4.018864,4.019139,4.019414,4.019689,4.019963,4.020237,4.020511,4.020785,4.021058,4.02133,4.021603,4.021875,4.022147,4.022418,4.022689,4.02296,4.023230,4.023501,4.02377,4.02404,4.024309,4.024578,4.024846,4.025114,4.025382,4.02565,4.025917,4.026184,4.026451,4.026717,4.026983,4.027248,4.027514,4.027779,4.028043,4.028308,4.028572,4.028836,4.029099,4.029362,4.029625,4.029887,4.03015,4.030412,4.030673,4.030934,4.031195,4.031456,4.031716,4.031976,4.032236,4.032496,4.032755,4.033014,4.033272,4.033530,4.033788,4.034046,4.034303,4.034560,4.034817,4.035074,4.03533,4.035586,4.035841,4.036097,4.036352,4.036606,4.036861,4.037115,4.037369,4.037622,4.037876,4.038129,4.038381,4.038634,4.038886,4.039138,4.039389,4.039641,4.039891,4.040142,4.040393,4.040643,4.040893,4.041142,4.041392,4.041641,4.041889,4.042138,4.042386,4.042634,4.042881,4.043129,4.043376,4.043623,4.043869,4.044116,4.044362,4.044607,4.044853,4.045098,4.045343,4.045587,4.045832,4.046076,4.04632,4.046563,4.046807,4.04705,4.047293,4.047535,4.047777,4.048019,4.048261,4.048502,4.048744,4.048985,4.049225,4.049466,4.049706,4.049946,4.050185,4.050425,4.050664,4.050903,4.051141,4.05138,4.051618,4.051856,4.052093,4.052331,4.052568,4.052805,4.053041,4.053277,4.053514,4.053749,4.053985,4.05422,4.054455,4.05469,4.054925,4.055159,4.055393,4.055627,4.055861,4.056094,4.056327,4.05656,4.056793,4.057025,4.057257,4.057489,4.057721,4.057952,4.058183,4.058414,4.058645,4.058875,4.059105,4.059335,4.059565,4.059795,4.060024,4.060253,4.060482,4.06071,4.060938,4.061167,4.061394,4.061622,4.061849,4.062076,4.062303,4.06253,4.062757,4.062983,4.063209,4.063434,4.06366,4.063885,4.06411,4.064335,4.06456,4.064784,4.065008,4.065232,4.065456,4.065679,4.065903,4.066126,4.066349,4.066571,4.066794,4.067016,4.067238,4.067459,4.067681,4.067902,4.068123,4.068344,4.068564,4.068785,4.069005,4.069225,4.069445,4.069664,4.069883,4.070102,4.070321,4.07054,4.070758,4.070976,4.071194,4.071412,4.07163,4.071847,4.072064,4.072281,4.072498,4.072714,4.072931,4.073147,4.073363,4.073578,4.073794,4.074009,4.074224,4.074439,4.074653,4.074868,4.075082,4.075296,4.07551,4.075723,4.075937,4.07615,4.076363,4.076575,4.076788,4.077,4.077212,4.077424,4.077636,4.077848,4.078059,4.07827,4.078481,4.078692,4.078902,4.079113,4.079323,4.079533,4.079742,4.079952,4.080161,4.08037,4.080579,4.080788,4.080996,4.081205,4.081413,4.081621,4.081829,4.082036,4.082243,4.082451,4.082658,4.082864,4.083071,4.083277,4.083484,4.083690,4.083895,4.084101,4.084306,4.084512,4.084717,4.084922,4.085126,4.085331,4.085535,4.085739,4.085943,4.086147,4.08635,4.086554,4.086757,4.08696,4.087163,4.087365,4.087568,4.08777,4.087972,4.088174,4.088375,4.088577,4.088778,4.088979,4.08918,4.089381,4.089582,4.089782,4.089982,4.090182,4.090382,4.090582,4.090781,4.090980,4.09118,4.091379,4.091577,4.091776,4.091974,4.092173,4.092371,4.092568,4.092766,4.092964,4.093161,4.093358,4.093555,4.093752,4.093949,4.094145,4.094341,4.094538,4.094733,4.094929,4.095125,4.09532,4.095516,4.095711,4.095906,4.0961,4.096295,4.096489,4.096683,4.096877,4.097071,4.097265,4.097459,4.097652,4.097845,4.098038,4.098231,4.098424,4.098616,4.098809,4.099001,4.099193,4.099385,4.099576,4.099768,4.099959,4.10015,4.100341,4.100532,4.100723,4.100913,4.101104,4.101294,4.101484,4.101674,4.101863,4.102053,4.102242,4.102432,4.102621,4.102810,4.102998,4.103187,4.103375,4.103563,4.103752,4.103939,4.104127,4.104315,4.104502,4.104689,4.104877,4.105064,4.10525,4.105437,4.105623,4.10581,4.105996,4.106182,4.106368,4.106554,4.106739,4.106924,4.10711,4.107295,4.10748,4.107664,4.107849,4.108033,4.108218,4.108402,4.108586,4.10877,4.108953,4.109137,4.10932,4.109503,4.109687,4.109869,4.110052,4.110235,4.110417,4.1106,4.110782,4.110964,4.111146,4.111327,4.111509,4.11169,4.111872,4.112053,4.112234,4.112414,4.112595,4.112776,4.112956,4.113136,4.113316,4.113496,4.113676,4.113855,4.114035,4.114214,4.114393,4.114573,4.114751,4.11493,4.115109,4.115287,4.115466,4.115644,4.115822,4.116000,4.116177,4.116355,4.116532,4.11671,4.116887,4.117064,4.117241,4.117417,4.117594,4.117770,4.117947,4.118123,4.118299,4.118475,4.118651,4.118826,4.119002,4.119177,4.119352,4.119527,4.119702,4.119877,4.120051,4.120226,4.1204,4.120574,4.120748,4.120922,4.121096,4.12127,4.121443,4.121617,4.12179,4.121963,4.122136,4.122309,4.122482,4.122654,4.122827,4.122999,4.123171,4.123343,4.123515,4.123687,4.123858,4.12403,4.124201,4.124372,4.124543,4.124714,4.124885,4.125056,4.125226,4.125397,4.125567,4.125737,4.125907,4.126077,4.126247,4.126416,4.126586,4.126755,4.126924,4.127094,4.127263,4.127431,4.1276,4.127769,4.127937,4.128105,4.128274,4.128442,4.128610,4.128777,4.128945,4.129113,4.12928,4.129447,4.129614,4.129781,4.129948,4.130115,4.130282,4.130448,4.130615,4.130781,4.130947,4.131113,4.131279,4.131445,4.131610,4.131776,4.131941,4.132107,4.132272,4.132437,4.132602,4.132766,4.132931,4.133096,4.13326,4.133424,4.133588,4.133752,4.133916,4.13408,4.134244,4.134407,4.134571,4.134734,4.134897,4.13506,4.135223,4.135386,4.135549,4.135711,4.135874,4.136036,4.136198,4.13636,4.136522,4.136684,4.136846,4.137007,4.137169,4.13733,4.137491,4.137653,4.137814,4.137974,4.138135,4.138296,4.138456,4.138617,4.138777,4.138937,4.139097,4.139257,4.139417,4.139577,4.139736,4.139896,4.140055,4.140214,4.140374,4.140533,4.140692,4.14085,4.141009,4.141168,4.141326,4.141484,4.141642,4.141801,4.141959,4.142116,4.142274,4.142432,4.142589,4.142747,4.142904,4.143061,4.143218,4.143375,4.143532,4.143689,4.143845,4.144002,4.144158,4.144315,4.144471,4.144627,4.144783,4.144939,4.145094,4.14525,4.145405,4.145561,4.145716,4.145871,4.146026,4.146181,4.146336,4.146491,4.146645,4.1468,4.146954,4.147109,4.147263,4.147417,4.147571,4.147725,4.147878,4.148032,4.148186,4.148339,4.148492,4.148646,4.148799,4.148952,4.149105,4.149257,4.14941,4.149563,4.149715,4.149867,4.15002,4.150172,4.150324,4.150476,4.150628,4.150779,4.150931,4.151082,4.151234,4.151385,4.151536,4.151687,4.151838,4.151989,4.15214,4.152291,4.152441,4.152592,4.152742,4.152892,4.153042,4.153192,4.153342,4.153492,4.153642,4.153792,4.153941,4.154090,4.15424,4.154389,4.154538,4.154687,4.154836,4.154985,4.155134,4.155282,4.155431,4.155579,4.155727,4.155876,4.156024,4.156172,4.15632,4.156467,4.156615,4.156763,4.15691,4.157058,4.157205,4.157352,4.157499,4.157646,4.157793,4.15794,4.158087,4.158233,4.15838,4.158526,4.158673,4.158819,4.158965,4.159111,4.159257,4.159403,4.159548,4.159694,4.159839,4.159985,4.16013,4.160275,4.160421,4.160566,4.160711,4.160855,4.161,4.161145,4.161289,4.161434,4.161578,4.161723,4.161867,4.162011,4.162155,4.162299,4.162442,4.162586,4.16273,4.162873,4.163017,4.16316,4.163303,4.163446,4.163589,4.163732,4.163875,4.164018,4.164161,4.164303,4.164446,4.164588,4.16473,4.164873,4.165015,4.165157,4.165299,4.165440,4.165582,4.165724,4.165865,4.166007,4.166148,4.166289,4.166431,4.166572,4.166713,4.166854,4.166994,4.167135,4.167276,4.167416,4.167557,4.167697,4.167837,4.167978,4.168118,4.168258,4.168398,4.168537,4.168677,4.168817,4.168956,4.169096,4.169235,4.169374,4.169514,4.169653,4.169792,4.169931,4.170070,4.170208,4.170347,4.170486,4.170624,4.170762,4.170901,4.171039,4.171177,4.171315,4.171453,4.171591,4.171729,4.171866,4.172004,4.172141,4.172279,4.172416,4.172554,4.172691,4.172828,4.172965,4.173102,4.173238,4.173375,4.173512,4.173648,4.173785,4.173921,4.174058,4.174194,4.17433,4.174466,4.174602,4.174738,4.174874,4.175009,4.175145,4.175281,4.175416,4.175551,4.175687,4.175822,4.175957,4.176092,4.176227,4.176362,4.176497,4.176631,4.176766,4.176900,4.177035,4.177169,4.177304,4.177438,4.177572,4.177706,4.17784,4.177974,4.178107,4.178241,4.178375,4.178508,4.178642,4.178775,4.178908,4.179042,4.179175,4.179308,4.179441,4.179574,4.179706,4.179839,4.179972,4.180104,4.180237,4.180369,4.180502,4.180634,4.180766,4.180898,4.18103,4.181162,4.181294,4.181426,4.181557,4.181689,4.18182,4.181952,4.182083,4.182214,4.182346,4.182477,4.182608,4.182739,4.182870,4.183,4.183131,4.183262,4.183392,4.183523,4.183653,4.183783,4.183914,4.184044,4.184174,4.184304,4.184434,4.184564,4.184694,4.184823,4.184953,4.185082,4.185212,4.185341,4.185471,4.1856,4.185729,4.185858,4.185987,4.186116,4.186245,4.186374,4.186502,4.186631,4.186759,4.186888,4.187016,4.187145,4.187273,4.187401,4.187529,4.187657,4.187785,4.187913,4.188041,4.188168,4.188296,4.188424,4.188551,4.188678,4.188806,4.188933,4.18906,4.189187,4.189314,4.189441,4.189568,4.189695,4.189822,4.189948,4.190075,4.190202,4.190328,4.190454,4.190581,4.190707,4.190833,4.190959,4.191085,4.191211,4.191337,4.191463,4.191588,4.191714,4.191840,4.191965,4.19209,4.192216,4.192341,4.192466,4.192591,4.192716,4.192841,4.192966,4.193091,4.193216,4.193341,4.193465,4.19359,4.193714,4.193839,4.193963,4.194087,4.194211,4.194335,4.194460,4.194584,4.194707,4.194831,4.194955,4.195079,4.195202,4.195326,4.195449,4.195573,4.195696,4.195819,4.195943,4.196066,4.196189,4.196312,4.196435,4.196557,4.19668,4.196803,4.196926,4.197048,4.197171,4.197293,4.197415,4.197538,4.19766,4.197782,4.197904,4.198026,4.198148,4.19827,4.198392,4.198514,4.198635,4.198757,4.198878,4.199,4.199121,4.199243,4.199364,4.199485,4.199606,4.199727,4.199848,4.199969,4.20009,4.200211,4.200331,4.200452,4.200573,4.200693,4.200814,4.200934,4.201054,4.201175,4.201295,4.201415,4.201535,4.201655,4.201775,4.201895,4.202014,4.202134,4.202254,4.202373,4.202493,4.202612,4.202732,4.202851,4.20297,4.203089,4.203209,4.203328,4.203447,4.203566,4.203684,4.203803,4.203922,4.204041,4.204159,4.204278,4.204396,4.204515,4.204633,4.204751,4.204869,4.204987,4.205106,4.205224,4.205342,4.205459,4.205577,4.205695,4.205813,4.20593,4.206048,4.206165,4.206283,4.2064,4.206517,4.206635,4.206752,4.206869,4.206986,4.207103,4.20722,4.207337,4.207454,4.20757,4.207687,4.207804,4.20792,4.208037,4.208153,4.208269,4.208386,4.208502,4.208618,4.208734,4.20885,4.208966,4.209082,4.209198,4.209314,4.209429,4.209545,4.209661,4.209776,4.209892,4.210007,4.210122,4.210238,4.210353,4.210468,4.210583,4.210698,4.210813,4.210928,4.211043,4.211158,4.211273,4.211387,4.211502,4.211617,4.211731,4.211845,4.21196,4.212074,4.212188,4.212303,4.212417,4.212531,4.212645,4.212759,4.212873,4.212987,4.2131,4.213214,4.213328,4.213441,4.213555,4.213668,4.213782,4.213895,4.214008,4.214122,4.214235,4.214348,4.214461,4.214574,4.214687,4.2148,4.214912,4.215025,4.215138,4.215251,4.215363,4.215476,4.215588,4.215701,4.215813,4.215925,4.216037,4.21615,4.216262,4.216374,4.216486,4.216598,4.216710,4.216821,4.216933,4.217045,4.217157,4.217268,4.21738,4.217491,4.217603,4.217714,4.217825,4.217936,4.218048,4.218159,4.21827,4.218381,4.218492,4.218603,4.218713,4.218824,4.218935,4.219046,4.219156,4.219267,4.219377,4.219488,4.219598,4.219709,4.219819,4.219929,4.220039,4.220149,4.220259,4.220369,4.220479,4.220589,4.220699,4.220809,4.220918,4.221028,4.221138,4.221247,4.221357,4.221466,4.221575,4.221685,4.221794,4.221903,4.222012,4.222122,4.222231,4.222340,4.222448,4.222557,4.222666,4.222775,4.222884,4.222992,4.223101,4.223209,4.223318,4.223426,4.223535,4.223643,4.223751,4.22386,4.223968,4.224076,4.224184,4.224292,4.2244,4.224508,4.224616,4.224723,4.224831,4.224939,4.225046,4.225154,4.225261,4.225369,4.225476,4.225584,4.225691,4.225798,4.225905,4.226013,4.22612,4.226227,4.226334,4.226441,4.226547,4.226654,4.226761,4.226868,4.226974,4.227081,4.227188,4.227294,4.227401,4.227507,4.227613,4.227720,4.227826,4.227932,4.228038,4.228144,4.22825,4.228356,4.228462,4.228568,4.228674,4.22878,4.228885,4.228991,4.229097,4.229202,4.229308,4.229413,4.229518,4.229624,4.229729,4.229834,4.229940,4.230045,4.23015,4.230255,4.23036,4.230465,4.23057,4.230675,4.230779,4.230884,4.230989,4.231093,4.231198,4.231302,4.231407,4.231511,4.231616,4.23172,4.231824,4.231929,4.232033,4.232137,4.232241,4.232345,4.232449,4.232553,4.232657,4.232761,4.232864,4.232968,4.233072,4.233175,4.233279,4.233382,4.233486,4.233589,4.233693,4.233796,4.233899,4.234002,4.234106,4.234209,4.234312,4.234415,4.234518,4.234621,4.234724,4.234826,4.234929,4.235032,4.235135,4.235237,4.23534,4.235442,4.235545,4.235647,4.23575,4.235852,4.235954,4.236057,4.236159,4.236261,4.236363,4.236465,4.236567,4.236669,4.236771,4.236873,4.236974,4.237076,4.237178,4.23728,4.237381,4.237483,4.237584,4.237686,4.237787,4.237888,4.23799,4.238091,4.238192,4.238293,4.238395,4.238496,4.238597,4.238698,4.238799,4.238900,4.239,4.239101,4.239202,4.239303,4.239403,4.239504,4.239604,4.239705,4.239805,4.239906,4.240006,4.240107,4.240207,4.240307,4.240407,4.240507,4.240607,4.240707,4.240807,4.240907,4.241007,4.241107,4.241207,4.241307,4.241406,4.241506,4.241606,4.241705,4.241805,4.241904,4.242004,4.242103,4.242202,4.242302,4.242401,4.2425,4.242599,4.242698,4.242798,4.242897,4.242996,4.243094,4.243193,4.243292,4.243391,4.24349,4.243588,4.243687,4.243786,4.243884,4.243983,4.244081,4.24418,4.244278,4.244376,4.244475,4.244573,4.244671,4.244769,4.244867,4.244966,4.245064,4.245162,4.245259,4.245357,4.245455,4.245553,4.245651,4.245748,4.245846,4.245944,4.246041,4.246139,4.246236,4.246334,4.246431,4.246529,4.246626,4.246723,4.24682,4.246918,4.247015,4.247112,4.247209,4.247306,4.247403,4.2475,4.247597,4.247693,4.24779,4.247887,4.247984,4.24808,4.248177,4.248273,4.24837,4.248466,4.248563,4.248659,4.248756,4.248852,4.248948,4.249044,4.249141,4.249237,4.249333,4.249429,4.249525,4.249621,4.249717,4.249813,4.249908,4.250004,4.2501,4.250196,4.250291,4.250387,4.250482,4.250578,4.250673,4.250769,4.250864,4.25096,4.251055,4.25115,4.251245,4.251341,4.251436,4.251531,4.251626,4.251721,4.251816,4.251911,4.252006,4.252101,4.252195,4.25229,4.252385,4.25248,4.252574,4.252669,4.252763,4.252858,4.252952,4.253047,4.253141,4.253236,4.25333,4.253424,4.253518,4.253613,4.253707,4.253801,4.253895,4.253989,4.254083,4.254177,4.254271,4.254364,4.254458,4.254552,4.254646,4.254739,4.254833,4.254927,4.25502,4.255114,4.255207,4.255301,4.255394,4.255487,4.255581,4.255674,4.255767,4.255860,4.255954,4.256047,4.25614,4.256233,4.256326,4.256419,4.256512,4.256605,4.256697,4.25679,4.256883,4.256976,4.257068,4.257161,4.257254,4.257346,4.257439,4.257531,4.257623,4.257716,4.257808,4.257900,4.257993,4.258085,4.258177,4.258269,4.258361,4.258453,4.258546,4.258638,4.258729,4.258821,4.258913,4.259005,4.259097,4.259189,4.25928,4.259372,4.259464,4.259555,4.259647,4.259738,4.25983,4.259921,4.260013,4.260104,4.260195,4.260287,4.260378,4.260469,4.26056,4.260651,4.260742,4.260833,4.260924,4.261015,4.261106,4.261197,4.261288,4.261379,4.26147,4.26156,4.261651,4.261742,4.261832,4.261923,4.262014,4.262104,4.262194,4.262285,4.262375,4.262466,4.262556,4.262646,4.262736,4.262827,4.262917,4.263007,4.263097,4.263187,4.263277,4.263367,4.263457,4.263547,4.263637,4.263727,4.263816,4.263906,4.263996,4.264085,4.264175,4.264265,4.264354,4.264444,4.264533,4.264623,4.264712,4.264801,4.264891,4.26498,4.265069,4.265159,4.265248,4.265337,4.265426,4.265515,4.265604,4.265693,4.265782,4.265871,4.26596,4.266049,4.266137,4.266226,4.266315,4.266404,4.266492,4.266581,4.266670,4.266758,4.266847,4.266935,4.267024,4.267112,4.2672,4.267289,4.267377,4.267465,4.267553,4.267642,4.26773,4.267818,4.267906,4.267994,4.268082,4.26817,4.268258,4.268346,4.268434,4.268521,4.268609,4.268697,4.268785,4.268872,4.26896,4.269048,4.269135,4.269223,4.26931,4.269398,4.269485,4.269572,4.26966,4.269747,4.269834,4.269922,4.270009,4.270096,4.270183,4.27027,4.270357,4.270444,4.270531,4.270618,4.270705,4.270792,4.270879,4.270966,4.271053,4.271139,4.271226,4.271313,4.271399,4.271486,4.271573,4.271659,4.271746,4.271832,4.271918,4.272005,4.272091,4.272178,4.272264,4.27235,4.272436,4.272522,4.272609,4.272695,4.272781,4.272867,4.272953,4.273039,4.273125,4.273211,4.273297,4.273382,4.273468,4.273554,4.27364,4.273725,4.273811,4.273897,4.273982,4.274068,4.274153,4.274239,4.274324,4.27441,4.274495,4.274580,4.274666,4.274751,4.274836,4.274922,4.275007,4.275092,4.275177,4.275262,4.275347,4.275432,4.275517,4.275602,4.275687,4.275772,4.275857,4.275942,4.276026,4.276111,4.276196,4.276280,4.276365,4.27645,4.276534,4.276619,4.276703,4.276788,4.276872,4.276957,4.277041,4.277125,4.27721,4.277294,4.277378,4.277462,4.277547,4.277631,4.277715,4.277799,4.277883,4.277967,4.278051,4.278135,4.278219,4.278303,4.278386,4.27847,4.278554,4.278638,4.278721,4.278805,4.278889,4.278972,4.279056,4.279139,4.279223,4.279306,4.27939,4.279473,4.279557,4.27964,4.279723,4.279807,4.27989,4.279973,4.280056,4.280139,4.280223,4.280306,4.280389,4.280472,4.280555,4.280638,4.280721,4.280803,4.280886,4.280969,4.281052,4.281135,4.281217,4.2813,4.281383,4.281465,4.281548,4.281631,4.281713,4.281796,4.281878,4.281961,4.282043,4.282125,4.282208,4.28229,4.282372,4.282455,4.282537,4.282619,4.282701,4.282783,4.282865,4.282947,4.283029,4.283111,4.283193,4.283275,4.283357,4.283439,4.283521,4.283603,4.283685,4.283766,4.283848,4.28393,4.284011,4.284093,4.284174,4.284256,4.284338,4.284419,4.284501,4.284582,4.284663,4.284745,4.284826,4.284907,4.284989,4.28507,4.285151,4.285232,4.285313,4.285395,4.285476,4.285557,4.285638,4.285719,4.2858,4.285881,4.285961,4.286042,4.286123,4.286204,4.286285,4.286366,4.286446,4.286527,4.286608,4.286688,4.286769,4.286849,4.28693,4.28701,4.287091,4.287171,4.287252,4.287332,4.287412,4.287493,4.287573,4.287653,4.287734,4.287814,4.287894,4.287974,4.288054,4.288134,4.288214,4.288294,4.288374,4.288454,4.288534,4.288614,4.288694,4.288774,4.288854,4.288933,4.289013,4.289093,4.289173,4.289252,4.289332,4.289411,4.289491,4.289571,4.28965,4.289729,4.289809,4.289888,4.289968,4.290047,4.290126,4.290206,4.290285,4.290364,4.290443,4.290523,4.290602,4.290681,4.29076,4.290839,4.290918,4.290997,4.291076,4.291155,4.291234,4.291313,4.291392,4.291470,4.291549,4.291628,4.291707,4.291786,4.291864,4.291943,4.292021,4.2921,4.292179,4.292257,4.292336,4.292414,4.292493,4.292571,4.292649,4.292728,4.292806,4.292884,4.292963,4.293041,4.293119,4.293197,4.293275,4.293354,4.293432,4.29351,4.293588,4.293666,4.293744,4.293822,4.2939,4.293978,4.294055,4.294133,4.294211,4.294289,4.294367,4.294444,4.294522,4.2946,4.294677,4.294755,4.294833,4.29491,4.294988,4.295065,4.295143,4.29522,4.295298,4.295375,4.295452,4.29553,4.295607,4.295684,4.295761,4.295839,4.295916,4.295993,4.29607,4.296147,4.296224,4.296301,4.296378,4.296455,4.296532,4.296609,4.296686,4.296763,4.29684,4.296917,4.296994,4.29707,4.297147,4.297224,4.297301,4.297377,4.297454,4.29753,4.297607,4.297684,4.29776,4.297837,4.297913,4.297989,4.298066,4.298142,4.298219,4.298295,4.298371,4.298448,4.298524,4.2986,4.298676,4.298752,4.298828,4.298905,4.298981,4.299057,4.299133,4.299209,4.299285,4.299361,4.299437,4.299512,4.299588,4.299664,4.29974,4.299816,4.299892,4.299967,4.300043,4.300119,4.300194,4.30027,4.300345,4.300421,4.300497,4.300572,4.300648,4.300723,4.300798,4.300874,4.300949,4.301025,4.3011,4.301175,4.301250,4.301326,4.301401,4.301476,4.301551,4.301626,4.301702,4.301777,4.301852,4.301927,4.302002,4.302077,4.302152,4.302227,4.302301,4.302376,4.302451,4.302526,4.302601,4.302676,4.30275,4.302825,4.3029,4.302974,4.303049,4.303124,4.303198,4.303273,4.303347,4.303422,4.303496,4.303571,4.303645,4.303719,4.303794,4.303868,4.303942,4.304017,4.304091,4.304165,4.304239,4.304314,4.304388,4.304462,4.304536,4.30461,4.304684,4.304758,4.304832,4.304906,4.30498,4.305054,4.305128,4.305202,4.305276,4.30535,4.305423,4.305497,4.305571,4.305645,4.305718,4.305792,4.305866,4.305939,4.306013,4.306086,4.30616,4.306233,4.306307,4.306380,4.306454,4.306527,4.306601,4.306674,4.306747,4.306821,4.306894,4.306967,4.307040,4.307114,4.307187,4.30726,4.307333,4.307406,4.307479,4.307552,4.307625,4.307698,4.307771,4.307844,4.307917,4.30799,4.308063,4.308136,4.308209,4.308282,4.308354,4.308427,4.3085,4.308573,4.308645,4.308718,4.308791,4.308863,4.308936,4.309008,4.309081,4.309153,4.309226,4.309298,4.309371,4.309443,4.309516,4.309588,4.30966,4.309733,4.309805,4.309877,4.309949,4.310022,4.310094,4.310166,4.310238,4.31031,4.310382,4.310454,4.310526,4.310598,4.31067,4.310742,4.310814,4.310886,4.310958,4.31103,4.311102,4.311174,4.311245,4.311317,4.311389,4.311461,4.311532,4.311604,4.311676,4.311747,4.311819,4.31189,4.311962,4.312033,4.312105,4.312176,4.312248,4.312319,4.312391,4.312462,4.312533,4.312605,4.312676,4.312747,4.312819,4.31289,4.312961,4.313032,4.313103,4.313175,4.313246,4.313317,4.313388,4.313459,4.31353,4.313601,4.313672,4.313743,4.313814,4.313885,4.313956,4.314026,4.314097,4.314168,4.314239,4.31431,4.31438,4.314451,4.314522,4.314592,4.314663,4.314734,4.314804,4.314875,4.314945,4.315016,4.315086,4.315157,4.315227,4.315298,4.315368,4.315438,4.315509,4.315579,4.315649,4.31572,4.31579,4.31586,4.315931,4.316001,4.316071,4.316141,4.316211,4.316281,4.316351,4.316421,4.316491,4.316561,4.316631,4.316701,4.316771,4.316841,4.316911,4.316981,4.317051,4.317121,4.317190,4.31726,4.31733,4.3174,4.317469,4.317539,4.317609,4.317678,4.317748,4.317818,4.317887,4.317957,4.318026,4.318096,4.318165,4.318235,4.318304,4.318373,4.318443,4.318512,4.318582,4.318651,4.31872,4.318789,4.318859,4.318928,4.318997,4.319066,4.319135,4.319205,4.319274,4.319343,4.319412,4.319481,4.31955,4.319619,4.319688,4.319757,4.319826,4.319895,4.319964,4.320032,4.320101,4.32017,4.320239,4.320308,4.320376,4.320445,4.320514,4.320583,4.320651,4.32072,4.320789,4.320857,4.320926,4.320994,4.321063,4.321131,4.3212,4.321268,4.321337,4.321405,4.321473,4.321542,4.32161,4.321679,4.321747,4.321815,4.321883,4.321952,4.32202,4.322088,4.322156,4.322224,4.322292,4.322361,4.322429,4.322497,4.322565,4.322633,4.322701,4.322769,4.322837,4.322905,4.322973,4.323040,4.323108,4.323176,4.323244,4.323312,4.323380,4.323447,4.323515,4.323583,4.323650,4.323718,4.323786,4.323853,4.323921,4.323989,4.324056,4.324124,4.324191,4.324259,4.324326,4.324394,4.324461,4.324528,4.324596,4.324663,4.324731,4.324798,4.324865,4.324932,4.325,4.325067,4.325134,4.325201,4.325269,4.325336,4.325403,4.32547,4.325537,4.325604,4.325671,4.325738,4.325805,4.325872,4.325939,4.326006,4.326073,4.32614,4.326207,4.326274,4.326340,4.326407,4.326474,4.326541,4.326608,4.326674,4.326741,4.326808,4.326874,4.326941,4.327008,4.327074,4.327141,4.327207,4.327274,4.32734,4.327407,4.327473,4.32754,4.327606,4.327673,4.327739,4.327805,4.327872,4.327938,4.328004,4.328071,4.328137,4.328203,4.328269,4.328336,4.328402,4.328468,4.328534,4.3286,4.328666,4.328732,4.328798,4.328865,4.328931,4.328997,4.329063,4.329128,4.329194,4.32926,4.329326,4.329392,4.329458,4.329524,4.329590,4.329655,4.329721,4.329787,4.329853,4.329918,4.329984,4.33005,4.330115,4.330181,4.330247,4.330312,4.330378,4.330443,4.330509,4.330574,4.33064,4.330705,4.330771,4.330836,4.330901,4.330967,4.331032,4.331098,4.331163,4.331228,4.331293,4.331359,4.331424,4.331489,4.331554,4.331619,4.331685,4.33175,4.331815,4.33188,4.331945,4.33201,4.332075,4.33214,4.332205,4.33227,4.332335,4.3324,4.332465,4.33253,4.332595,4.33266,4.332724,4.332789,4.332854,4.332919,4.332984,4.333048,4.333113,4.333178,4.333242,4.333307,4.333372,4.333436,4.333501,4.333565,4.33363,4.333695,4.333759,4.333824,4.333888,4.333953,4.334017,4.334081,4.334146,4.33421,4.334275,4.334339,4.334403,4.334467,4.334532,4.334596,4.33466,4.334724,4.334789,4.334853,4.334917,4.334981,4.335045,4.335109,4.335173,4.335238,4.335302,4.335366,4.33543,4.335494,4.335558,4.335622,4.335685,4.335749,4.335813,4.335877,4.335941,4.336005,4.336069,4.336132,4.336196,4.33626,4.336324,4.336387,4.336451,4.336515,4.336578,4.336642,4.336706,4.336769,4.336833,4.336896,4.33696,4.337024,4.337087,4.337150,4.337214,4.337277,4.337341,4.337404,4.337468,4.337531,4.337594,4.337658,4.337721,4.337784,4.337848,4.337911,4.337974,4.338037,4.338100,4.338164,4.338227,4.33829,4.338353,4.338416,4.338479,4.338542,4.338605,4.338668,4.338731,4.338794,4.338857,4.33892,4.338983,4.339046,4.339109,4.339172,4.339235,4.339298,4.339360,4.339423,4.339486,4.339549,4.339612,4.339674,4.339737,4.3398,4.339862,4.339925,4.339988,4.34005,4.340113,4.340175,4.340238,4.340301,4.340363,4.340426,4.340488,4.340550,4.340613,4.340675,4.340738,4.3408,4.340863,4.340925,4.340987,4.341050,4.341112,4.341174,4.341236,4.341299,4.341361,4.341423,4.341485,4.341547,4.341610,4.341672,4.341734,4.341796,4.341858,4.34192,4.341982,4.342044,4.342106,4.342168,4.34223,4.342292,4.342354,4.342416,4.342478,4.34254,4.342601,4.342663,4.342725,4.342787,4.342849,4.342911,4.342972,4.343034,4.343096,4.343157,4.343219,4.343281,4.343342,4.343404,4.343466,4.343527,4.343589,4.34365,4.343712,4.343773,4.343835,4.343896,4.343958,4.344019,4.344081,4.344142,4.344203,4.344265,4.344326,4.344387,4.344449,4.34451,4.344571,4.344633,4.344694,4.344755,4.344816,4.344878,4.344939,4.345,4.345061,4.345122,4.345183,4.345244,4.345305,4.345366,4.345427,4.345488,4.345549,4.34561,4.345671,4.345732,4.345793,4.345854,4.345915,4.345976,4.346037,4.346098,4.346158,4.346219,4.34628,4.346341,4.346402,4.346462,4.346523,4.346584,4.346644,4.346705,4.346766,4.346826,4.346887,4.346947,4.347008,4.347069,4.347129,4.34719,4.34725,4.347311,4.347371,4.347432,4.347492,4.347552,4.347613,4.347673,4.347734,4.347794,4.347854,4.347915,4.347975,4.348035,4.348095,4.348156,4.348216,4.348276,4.348336,4.348396,4.348457,4.348517,4.348577,4.348637,4.348697,4.348757,4.348817,4.348877,4.348937,4.348997,4.349057,4.349117,4.349177,4.349237,4.349297,4.349357,4.349417,4.349477,4.349536,4.349596,4.349656,4.349716,4.349776,4.349835,4.349895,4.349955,4.350015,4.350074,4.350134,4.350194,4.350253,4.350313,4.350372,4.350432,4.350492,4.350551,4.350611,4.35067,4.35073,4.350789,4.350849,4.350908,4.350968,4.351027,4.351086,4.351146,4.351205,4.351265,4.351324,4.351383,4.351442,4.351502,4.351561,4.35162,4.351680,4.351739,4.351798,4.351857,4.351916,4.351975,4.352035,4.352094,4.352153,4.352212,4.352271,4.35233,4.352389,4.352448,4.352507,4.352566,4.352625,4.352684,4.352743,4.352802,4.352861,4.35292,4.352979,4.353037,4.353096,4.353155,4.353214,4.353273,4.353331,4.35339,4.353449,4.353508,4.353566,4.353625,4.353684,4.353742,4.353801,4.35386,4.353918,4.353977,4.354035,4.354094,4.354153,4.354211,4.354270,4.354328,4.354387,4.354445,4.354503,4.354562,4.35462,4.354679,4.354737,4.354795,4.354854,4.354912,4.35497,4.355029,4.355087,4.355145,4.355203,4.355262,4.35532,4.355378,4.355436,4.355494,4.355553,4.355611,4.355669,4.355727,4.355785,4.355843,4.355901,4.355959,4.356017,4.356075,4.356133,4.356191,4.356249,4.356307,4.356365,4.356423,4.356481,4.356539,4.356597,4.356654,4.356712,4.35677,4.356828,4.356886,4.356943,4.357001,4.357059,4.357117,4.357174,4.357232,4.35729,4.357347,4.357405,4.357463,4.35752,4.357578,4.357635,4.357693,4.357751,4.357808,4.357866,4.357923,4.357981,4.358038,4.358095,4.358153,4.35821,4.358268,4.358325,4.358382,4.35844,4.358497,4.358554,4.358612,4.358669,4.358726,4.358784,4.358841,4.358898,4.358955,4.359013,4.35907,4.359127,4.359184,4.359241,4.359298,4.359355,4.359412,4.359470,4.359527,4.359584,4.359641,4.359698,4.359755,4.359812,4.359869,4.359926,4.359983,4.360039,4.360096,4.360153,4.36021,4.360267,4.360324,4.360381,4.360437,4.360494,4.360551,4.360608,4.360665,4.360721,4.360778,4.360835,4.360891,4.360948,4.361005,4.361061,4.361118,4.361175,4.361231,4.361288,4.361344,4.361401,4.361457,4.361514,4.36157,4.361627,4.361683,4.36174,4.361796,4.361853,4.361909,4.361965,4.362022,4.362078,4.362135,4.362191,4.362247,4.362304,4.36236,4.362416,4.362472,4.362529,4.362585,4.362641,4.362697,4.362753,4.36281,4.362866,4.362922,4.362978,4.363034,4.36309,4.363146,4.363202,4.363258,4.363314,4.363370,4.363426,4.363482,4.363538,4.363594,4.36365,4.363706,4.363762,4.363818,4.363874,4.36393,4.363986,4.364042,4.364097,4.364153,4.364209,4.364265,4.364321,4.364376,4.364432,4.364488,4.364543,4.364599,4.364655,4.364710,4.364766,4.364822,4.364877,4.364933,4.364989,4.365044,4.3651,4.365155,4.365211,4.365266,4.365322,4.365377,4.365433,4.365488,4.365544,4.365599,4.365654,4.36571,4.365765,4.365821,4.365876,4.365931,4.365987,4.366042,4.366097,4.366152,4.366208,4.366263,4.366318,4.366373,4.366429,4.366484,4.366539,4.366594,4.366649,4.366704,4.36676,4.366815,4.36687,4.366925,4.36698,4.367035,4.36709,4.367145,4.3672,4.367255,4.36731,4.367365,4.36742,4.367475,4.36753,4.367585,4.367639,4.367694,4.367749,4.367804,4.367859,4.367914,4.367969,4.368023,4.368078,4.368133,4.368188,4.368242,4.368297,4.368352,4.368406,4.368461,4.368516,4.36857,4.368625,4.36868,4.368734,4.368789,4.368843,4.368898,4.368952,4.369007,4.369061,4.369116,4.369170,4.369225,4.369279,4.369334,4.369388,4.369443,4.369497,4.369551,4.369606,4.36966,4.369715,4.369769,4.369823,4.369877,4.369932,4.369986,4.37004,4.370095,4.370149,4.370203,4.370257,4.370311,4.370366,4.37042,4.370474,4.370528,4.370582,4.370636,4.37069,4.370744,4.370798,4.370853,4.370907,4.370961,4.371015,4.371069,4.371123,4.371177,4.371230,4.371284,4.371338,4.371392,4.371446,4.3715,4.371554,4.371608,4.371662,4.371715,4.371769,4.371823,4.371877,4.371931,4.371984,4.372038,4.372092,4.372145,4.372199,4.372253,4.372307,4.37236,4.372414,4.372467,4.372521,4.372575,4.372628,4.372682,4.372735,4.372789,4.372843,4.372896,4.372950,4.373003,4.373057,4.37311,4.373163,4.373217,4.37327,4.373324,4.373377,4.373430,4.373484,4.373537,4.373591,4.373644,4.373697,4.373751,4.373804,4.373857,4.37391,4.373964,4.374017,4.37407,4.374123,4.374176,4.37423,4.374283,4.374336,4.374389,4.374442,4.374495,4.374548,4.374602,4.374655,4.374708,4.374761,4.374814,4.374867,4.37492,4.374973,4.375026,4.375079,4.375132,4.375185,4.375237,4.37529,4.375343,4.375396,4.375449,4.375502,4.375555,4.375608,4.37566,4.375713,4.375766,4.375819,4.375872,4.375924,4.375977,4.37603,4.376082,4.376135,4.376188,4.376241,4.376293,4.376346,4.376398,4.376451,4.376504,4.376556,4.376609,4.376661,4.376714,4.376766,4.376819,4.376872,4.376924,4.376976,4.377029,4.377081,4.377134,4.377186,4.377239,4.377291,4.377344,4.377396,4.377448,4.377501,4.377553,4.377605,4.377658,4.37771,4.377762,4.377814,4.377867,4.377919,4.377971,4.378023,4.378076,4.378128,4.37818,4.378232,4.378284,4.378336,4.378389,4.378441,4.378493,4.378545,4.378597,4.378649,4.378701,4.378753,4.378805,4.378857,4.378909,4.378961,4.379013,4.379065,4.379117,4.379169,4.379221,4.379273,4.379325,4.379377,4.379428,4.37948,4.379532,4.379584,4.379636,4.379688,4.379739,4.379791,4.379843,4.379895,4.379946,4.379998,4.38005,4.380102,4.380153,4.380205,4.380257,4.380308,4.38036,4.380412,4.380463,4.380515,4.380566,4.380618,4.380670,4.380721,4.380773,4.380824,4.380876,4.380927,4.380979,4.38103,4.381082,4.381133,4.381184,4.381236,4.381287,4.381339,4.38139,4.381441,4.381493,4.381544,4.381595,4.381647,4.381698,4.381749,4.381801,4.381852,4.381903,4.381954,4.382006,4.382057,4.382108,4.382159,4.382211,4.382262,4.382313,4.382364,4.382415,4.382466,4.382517,4.382568,4.382620,4.382671,4.382722,4.382773,4.382824,4.382875,4.382926,4.382977,4.383028,4.383079,4.38313,4.383181,4.383232,4.383282,4.383333,4.383384,4.383435,4.383486,4.383537,4.383588,4.383639,4.383689,4.38374,4.383791,4.383842,4.383893,4.383943,4.383994,4.384045,4.384096,4.384146,4.384197,4.384248,4.384298,4.384349,4.3844,4.38445,4.384501,4.384551,4.384602,4.384653,4.384703,4.384754,4.384804,4.384855,4.384905,4.384956,4.385006,4.385057,4.385107,4.385158,4.385208,4.385259,4.385309,4.385360,4.38541,4.38546,4.385511,4.385561,4.385611,4.385662,4.385712,4.385762,4.385813,4.385863,4.385913,4.385964,4.386014,4.386064,4.386114,4.386165,4.386215,4.386265,4.386315,4.386365,4.386415,4.386466,4.386516,4.386566,4.386616,4.386666,4.386716,4.386766,4.386816,4.386866,4.386916,4.386966,4.387016,4.387066,4.387116,4.387166,4.387216,4.387266,4.387316,4.387366,4.387416,4.387466,4.387516,4.387566,4.387616,4.387666,4.387715,4.387765,4.387815,4.387865,4.387915,4.387964,4.388014,4.388064,4.388114,4.388163,4.388213,4.388263,4.388313,4.388362,4.388412,4.388462,4.388511,4.388561,4.388611,4.38866,4.38871,4.388759,4.388809,4.388859,4.388908,4.388958,4.389007,4.389057,4.389106,4.389156,4.389205,4.389255,4.389304,4.389354,4.389403,4.389453,4.389502,4.389551,4.389601,4.38965,4.389700,4.389749,4.389798,4.389848,4.389897,4.389946,4.389996,4.390045,4.390094,4.390143,4.390193,4.390242,4.390291,4.39034,4.390390,4.390439,4.390488,4.390537,4.390586,4.390635,4.390685,4.390734,4.390783,4.390832,4.390881,4.39093,4.390979,4.391028,4.391077,4.391126,4.391175,4.391224,4.391273,4.391322,4.391371,4.39142,4.391469,4.391518,4.391567,4.391616,4.391665,4.391714,4.391763,4.391812,4.391860,4.391909,4.391958,4.392007,4.392056,4.392105,4.392153,4.392202,4.392251,4.3923,4.392349,4.392397,4.392446,4.392495,4.392543,4.392592,4.392641,4.392689,4.392738,4.392787,4.392835,4.392884,4.392933,4.392981,4.39303,4.393078,4.393127,4.393175,4.393224,4.393273,4.393321,4.39337,4.393418,4.393467,4.393515,4.393564,4.393612,4.39366,4.393709,4.393757,4.393806,4.393854,4.393902,4.393951,4.393999,4.394048,4.394096,4.394144,4.394193,4.394241,4.394289,4.394337,4.394386,4.394434,4.394482,4.394530,4.394579,4.394627,4.394675,4.394723,4.394772,4.39482,4.394868,4.394916,4.394964,4.395012,4.39506,4.395108,4.395157,4.395205,4.395253,4.395301,4.395349,4.395397,4.395445,4.395493,4.395541,4.395589,4.395637,4.395685,4.395733,4.395781,4.395829,4.395877,4.395925,4.395972,4.39602,4.396068,4.396116,4.396164,4.396212,4.39626,4.396308,4.396355,4.396403,4.396451,4.396499,4.396547,4.396594,4.396642,4.39669,4.396737,4.396785,4.396833,4.396881,4.396928,4.396976,4.397024,4.397071,4.397119,4.397167,4.397214,4.397262,4.397309,4.397357,4.397405,4.397452,4.3975,4.397547,4.397595,4.397642,4.39769,4.397737,4.397785,4.397832,4.39788,4.397927,4.397975,4.398022,4.398070,4.398117,4.398164,4.398212,4.398259,4.398306,4.398354,4.398401,4.398449,4.398496,4.398543,4.398590,4.398638,4.398685,4.398732,4.39878,4.398827,4.398874,4.398921,4.398969,4.399016,4.399063,4.39911,4.399157,4.399204,4.399252,4.399299,4.399346,4.399393,4.39944,4.399487,4.399534,4.399581,4.399629,4.399676,4.399723,4.39977,4.399817,4.399864,4.399911,4.399958,4.400005,4.400052,4.400099,4.400146,4.400193,4.400239,4.400286,4.400333,4.40038,4.400427,4.400474,4.400521,4.400568,4.400615,4.400661,4.400708,4.400755,4.400802,4.400849,4.400895,4.400942,4.400989,4.401036,4.401082,4.401129,4.401176,4.401223,4.401269,4.401316,4.401363,4.401409,4.401456,4.401503,4.401549,4.401596,4.401643,4.401689,4.401736,4.401782,4.401829,4.401875,4.401922,4.401969,4.402015,4.402062,4.402108,4.402155,4.402201,4.402248,4.402294,4.402341,4.402387,4.402433,4.40248,4.402526,4.402573,4.402619,4.402665,4.402712,4.402758,4.402805,4.402851,4.402897,4.402944,4.40299,4.403036,4.403082,4.403129,4.403175,4.403221,4.403268,4.403314,4.40336,4.403406,4.403452,4.403499,4.403545,4.403591,4.403637,4.403683,4.403729,4.403776,4.403822,4.403868,4.403914,4.40396,4.404006,4.404052,4.404098,4.404144,4.40419,4.404236,4.404282,4.404328,4.404374,4.404420,4.404466,4.404512,4.404558,4.404604,4.40465,4.404696,4.404742,4.404788,4.404834,4.40488,4.404926,4.404972,4.405018,4.405063,4.405109,4.405155,4.405201,4.405247,4.405292,4.405338,4.405384,4.40543,4.405476,4.405521,4.405567,4.405613,4.405659,4.405704,4.40575,4.405796,4.405841,4.405887,4.405933,4.405978,4.406024,4.40607,4.406115,4.406161,4.406206,4.406252,4.406298,4.406343,4.406389,4.406434,4.40648,4.406525,4.406571,4.406616,4.406662,4.406707,4.406753,4.406798,4.406844,4.406889,4.406935,4.40698,4.407026,4.407071,4.407116,4.407162,4.407207,4.407253,4.407298,4.407343,4.407389,4.407434,4.407479,4.407525,4.40757,4.407615,4.40766,4.407706,4.407751,4.407796,4.407841,4.407887,4.407932,4.407977,4.408022,4.408068,4.408113,4.408158,4.408203,4.408248,4.408293,4.408338,4.408384,4.408429,4.408474,4.408519,4.408564,4.408609,4.408654,4.408699,4.408744,4.408789,4.408834,4.408879,4.408924,4.408969,4.409014,4.409059,4.409104,4.409149,4.409194,4.409239,4.409284,4.409329,4.409374,4.409419,4.409464,4.409509,4.409553,4.409598,4.409643,4.409688,4.409733,4.409778,4.409822,4.409867,4.409912,4.409957,4.410002,4.410046,4.410091,4.410136,4.410181,4.410225,4.41027,4.410315,4.410359,4.410404,4.410449,4.410493,4.410538,4.410583,4.410627,4.410672,4.410717,4.410761,4.410806,4.410850,4.410895,4.41094,4.410984,4.411029,4.411073,4.411118,4.411162,4.411207,4.411251,4.411296,4.41134,4.411385,4.411429,4.411474,4.411518,4.411563,4.411607,4.411651,4.411696,4.41174,4.411785,4.411829,4.411873,4.411918,4.411962,4.412006,4.412051,4.412095,4.412139,4.412184,4.412228,4.412272,4.412317,4.412361,4.412405,4.412449,4.412494,4.412538,4.412582,4.412626,4.412671,4.412715,4.412759,4.412803,4.412847,4.412891,4.412936,4.41298,4.413024,4.413068,4.413112,4.413156,4.4132,4.413244,4.413288,4.413332,4.413376,4.413420,4.413465,4.413509,4.413553,4.413597,4.413641,4.413685,4.413729,4.413772,4.413816,4.41386,4.413904,4.413948,4.413992,4.414036,4.41408,4.414124,4.414168,4.414212,4.414255,4.414299,4.414343,4.414387,4.414431,4.414475,4.414518,4.414562,4.414606,4.41465,4.414694,4.414737,4.414781,4.414825,4.414869,4.414912,4.414956,4.415,4.415043,4.415087,4.415131,4.415174,4.415218,4.415262,4.415305,4.415349,4.415393,4.415436,4.41548,4.415524,4.415567,4.415611,4.415654,4.415698,4.415741,4.415785,4.415828,4.415872,4.415915,4.415959,4.416002,4.416046,4.416089,4.416133,4.416176,4.41622,4.416263,4.416307,4.41635,4.416394,4.416437,4.41648,4.416524,4.416567,4.416610,4.416654,4.416697,4.416741,4.416784,4.416827,4.416870,4.416914,4.416957,4.417,4.417044,4.417087,4.41713,4.417173,4.417217,4.41726,4.417303,4.417346,4.417390,4.417433,4.417476,4.417519,4.417562,4.417605,4.417649,4.417692,4.417735,4.417778,4.417821,4.417864,4.417907,4.41795,4.417993,4.418037,4.41808,4.418123,4.418166,4.418209,4.418252,4.418295,4.418338,4.418381,4.418424,4.418467,4.41851,4.418553,4.418596,4.418639,4.418681,4.418724,4.418767,4.41881,4.418853,4.418896,4.418939,4.418982,4.419025,4.419068,4.41911,4.419153,4.419196,4.419239,4.419282,4.419324,4.419367,4.41941,4.419453,4.419496,4.419538,4.419581,4.419624,4.419667,4.419709,4.419752,4.419795,4.419837,4.41988,4.419923,4.419965,4.420008,4.420051,4.420093,4.420136,4.420179,4.420221,4.420264,4.420306,4.420349,4.420392,4.420434,4.420477,4.420519,4.420562,4.420604,4.420647,4.420689,4.420732,4.420775,4.420817,4.420859,4.420902,4.420944,4.420987,4.421029,4.421072,4.421114,4.421157,4.421199,4.421241,4.421284,4.421326,4.421369,4.421411,4.421453,4.421496,4.421538,4.42158,4.421623,4.421665,4.421707,4.42175,4.421792,4.421834,4.421877,4.421919,4.421961,4.422003,4.422046,4.422088,4.42213,4.422172,4.422214,4.422257,4.422299,4.422341,4.422383,4.422425,4.422468,4.42251,4.422552,4.422594,4.422636,4.422678,4.42272,4.422762,4.422804,4.422847,4.422889,4.422931,4.422973,4.423015,4.423057,4.423099,4.423141,4.423183,4.423225,4.423267,4.423309,4.423351,4.423393,4.423435,4.423477,4.423519,4.423561,4.423603,4.423644,4.423686,4.423728,4.42377,4.423812,4.423854,4.423896,4.423938,4.423979,4.424021,4.424063,4.424105,4.424147,4.424189,4.42423,4.424272,4.424314,4.424356,4.424398,4.424439,4.424481,4.424523,4.424564,4.424606,4.424648,4.42469,4.424731,4.424773,4.424815,4.424856,4.424898,4.42494,4.424981,4.425023,4.425065,4.425106,4.425148,4.425189,4.425231,4.425273,4.425314,4.425356,4.425397,4.425439,4.425480,4.425522,4.425564,4.425605,4.425647,4.425688,4.42573,4.425771,4.425813,4.425854,4.425895,4.425937,4.425978,4.42602,4.426061,4.426103,4.426144,4.426185,4.426227,4.426268,4.42631,4.426351,4.426392,4.426434,4.426475,4.426516,4.426558,4.426599,4.42664,4.426682,4.426723,4.426764,4.426806,4.426847,4.426888,4.426929,4.426971,4.427012,4.427053,4.427094,4.427136,4.427177,4.427218,4.427259,4.4273,4.427341,4.427383,4.427424,4.427465,4.427506,4.427547,4.427588,4.427629,4.427671,4.427712,4.427753,4.427794,4.427835,4.427876,4.427917,4.427958,4.427999,4.42804,4.428081,4.428122,4.428163,4.428204,4.428245,4.428286,4.428327,4.428368,4.428409,4.42845,4.428491,4.428532,4.428573,4.428614,4.428655,4.428696,4.428737,4.428777,4.428818,4.428859,4.4289,4.428941,4.428982,4.429023,4.429063,4.429104,4.429145,4.429186,4.429227,4.429267,4.429308,4.429349,4.42939,4.429431,4.429471,4.429512,4.429553,4.429593,4.429634,4.429675,4.429716,4.429756,4.429797,4.429838,4.429878,4.429919,4.42996,4.43,4.430041,4.430082,4.430122,4.430163,4.430203,4.430244,4.430285,4.430325,4.430366,4.430406,4.430447,4.430487,4.430528,4.430569,4.430609,4.43065,4.43069,4.430731,4.430771,4.430812,4.430852,4.430893,4.430933,4.430973,4.431014,4.431054,4.431095,4.431135,4.431176,4.431216,4.431256,4.431297,4.431337,4.431378,4.431418,4.431458,4.431499,4.431539,4.431579,4.43162,4.43166,4.4317,4.431741,4.431781,4.431821,4.431862,4.431902,4.431942,4.431982,4.432023,4.432063,4.432103,4.432143,4.432183,4.432224,4.432264,4.432304,4.432344,4.432384,4.432425,4.432465,4.432505,4.432545,4.432585,4.432625,4.432666,4.432706,4.432746,4.432786,4.432826,4.432866,4.432906,4.432946,4.432986,4.433026,4.433066,4.433106,4.433146,4.433186,4.433226,4.433266,4.433306,4.433346,4.433386,4.433426,4.433466,4.433506,4.433546,4.433586,4.433626,4.433666,4.433706,4.433746,4.433786,4.433826,4.433866,4.433906,4.433945,4.433985,4.434025,4.434065,4.434105,4.434145,4.434185,4.434224,4.434264,4.434304,4.434344,4.434384,4.434423,4.434463,4.434503,4.434543,4.434582,4.434622,4.434662,4.434702,4.434741,4.434781,4.434821,4.434860,4.4349,4.43494,4.434980,4.435019,4.435059,4.435099,4.435138,4.435178,4.435217,4.435257,4.435297,4.435336,4.435376,4.435416,4.435455,4.435495,4.435534,4.435574,4.435613,4.435653,4.435692,4.435732,4.435772,4.435811,4.435851,4.43589,4.435930,4.435969,4.436009,4.436048,4.436087,4.436127,4.436166,4.436206,4.436245,4.436285,4.436324,4.436363,4.436403,4.436442,4.436482,4.436521,4.43656,4.4366,4.436639,4.436679,4.436718,4.436757,4.436797,4.436836,4.436875,4.436914,4.436954,4.436993,4.437032,4.437072,4.437111,4.43715,4.437189,4.437229,4.437268,4.437307,4.437346,4.437386,4.437425,4.437464,4.437503,4.437542,4.437582,4.437621,4.43766,4.437699,4.437738,4.437777,4.437816,4.437856,4.437895,4.437934,4.437973,4.438012,4.438051,4.43809,4.438129,4.438168,4.438207,4.438246,4.438286,4.438325,4.438364,4.438403,4.438442,4.438481,4.43852,4.438559,4.438598,4.438637,4.438676,4.438715,4.438754,4.438792,4.438831,4.43887,4.438909,4.438948,4.438987,4.439026,4.439065,4.439104,4.439143,4.439182,4.439220,4.439259,4.439298,4.439337,4.439376,4.439415,4.439454,4.439492,4.439531,4.43957,4.439609,4.439648,4.439686,4.439725,4.439764,4.439803,4.439841,4.43988,4.439919,4.439958,4.439996,4.440035,4.440074,4.440112,4.440151,4.44019,4.440229,4.440267,4.440306,4.440345,4.440383,4.440422,4.44046,4.440499,4.440538,4.440576,4.440615,4.440654,4.440692,4.440731,4.440769,4.440808,4.440846,4.440885,4.440924,4.440962,4.441001,4.441039,4.441078,4.441116,4.441155,4.441193,4.441232,4.44127,4.441309,4.441347,4.441386,4.441424,4.441462,4.441501,4.441539,4.441578,4.441616,4.441655,4.441693,4.441731,4.44177,4.441808,4.441847,4.441885,4.441923,4.441962,4.442,4.442038,4.442077,4.442115,4.442153,4.442192,4.44223,4.442268,4.442307,4.442345,4.442383,4.442421,4.44246,4.442498,4.442536,4.442574,4.442613,4.442651,4.442689,4.442727,4.442765,4.442804,4.442842,4.44288,4.442918,4.442956,4.442995,4.443033,4.443071,4.443109,4.443147,4.443185,4.443223,4.443262,4.4433,4.443338,4.443376,4.443414,4.443452,4.44349,4.443528,4.443566,4.443604,4.443642,4.44368,4.443718,4.443756,4.443794,4.443832,4.44387,4.443908,4.443946,4.443984,4.444022,4.44406,4.444098,4.444136,4.444174,4.444212,4.44425,4.444288,4.444326,4.444364,4.444402,4.44444,4.444478,4.444515,4.444553,4.444591,4.444629,4.444667,4.444705,4.444743,4.44478,4.444818,4.444856,4.444894,4.444932,4.444969,4.445007,4.445045,4.445083,4.445121,4.445158,4.445196,4.445234,4.445272,4.445309,4.445347,4.445385,4.445423,4.44546,4.445498,4.445536,4.445573,4.445611,4.445649,4.445686,4.445724,4.445762,4.445799,4.445837,4.445875,4.445912,4.44595,4.445987,4.446025,4.446063,4.4461,4.446138,4.446175,4.446213,4.446251,4.446288,4.446326,4.446363,4.446401,4.446438,4.446476,4.446513,4.446551,4.446588,4.446626,4.446663,4.446701,4.446738,4.446776,4.446813,4.446851,4.446888,4.446926,4.446963,4.447,4.447038,4.447075,4.447113,4.44715,4.447187,4.447225,4.447262,4.4473,4.447337,4.447374,4.447412,4.447449,4.447486,4.447524,4.447561,4.447598,4.447636,4.447673,4.44771,4.447748,4.447785,4.447822,4.447859,4.447897,4.447934,4.447971,4.448008,4.448046,4.448083,4.44812,4.448157,4.448195,4.448232,4.448269,4.448306,4.448343,4.448381,4.448418,4.448455,4.448492,4.448529,4.448566,4.448603,4.448641,4.448678,4.448715,4.448752,4.448789,4.448826,4.448863,4.4489,4.448937,4.448974,4.449012,4.449049,4.449086,4.449123,4.44916,4.449197,4.449234,4.449271,4.449308,4.449345,4.449382,4.449419,4.449456,4.449493,4.44953,4.449567,4.449604,4.449641,4.449678,4.449714,4.449751,4.449788,4.449825,4.449862,4.449899,4.449936,4.449973,4.45001,4.450047,4.450083,4.45012,4.450157,4.450194,4.450231,4.450268,4.450305,4.450341,4.450378,4.450415,4.450452,4.450489,4.450525,4.450562,4.450599,4.450636,4.450673,4.450709,4.450746,4.450783,4.450820,4.450856,4.450893,4.45093,4.450966,4.451003,4.45104,4.451077,4.451113,4.45115,4.451187,4.451223,4.45126,4.451297,4.451333,4.45137,4.451407,4.451443,4.45148,4.451516,4.451553,4.45159,4.451626,4.451663,4.451699,4.451736,4.451773,4.451809,4.451846,4.451882,4.451919,4.451955,4.451992,4.452028,4.452065,4.452101,4.452138,4.452174,4.452211,4.452247,4.452284,4.45232,4.452357,4.452393,4.45243,4.452466,4.452503,4.452539,4.452575,4.452612,4.452648,4.452685,4.452721,4.452757,4.452794,4.45283,4.452867,4.452903,4.452939,4.452976,4.453012,4.453048,4.453085,4.453121,4.453157,4.453194,4.45323,4.453266,4.453303,4.453339,4.453375,4.453411,4.453448,4.453484,4.45352,4.453557,4.453593,4.453629,4.453665,4.453701,4.453738,4.453774,4.45381,4.453846,4.453883,4.453919,4.453955,4.453991,4.454027,4.454063,4.4541,4.454136,4.454172,4.454208,4.454244,4.45428,4.454316,4.454353,4.454389,4.454425,4.454461,4.454497,4.454533,4.454569,4.454605,4.454641,4.454677,4.454713,4.454749,4.454785,4.454821,4.454857,4.454893,4.454929,4.454965,4.455001,4.455037,4.455073,4.455109,4.455145,4.455181,4.455217,4.455253,4.455289,4.455325,4.455361,4.455397,4.455433,4.455469,4.455505,4.455541,4.455577,4.455613,4.455648,4.455684,4.45572,4.455756,4.455792,4.455828,4.455864,4.455899,4.455935,4.455971,4.456007,4.456043,4.456079,4.456114,4.45615,4.456186,4.456222,4.456258,4.456293,4.456329,4.456365,4.456401,4.456436,4.456472,4.456508,4.456544,4.456579,4.456615,4.456651,4.456686,4.456722,4.456758,4.456793,4.456829,4.456865,4.456901,4.456936,4.456972,4.457007,4.457043,4.457079,4.457114,4.45715,4.457186,4.457221,4.457257,4.457292,4.457328,4.457364,4.457399,4.457435,4.45747,4.457506,4.457541,4.457577,4.457613,4.457648,4.457684,4.457719,4.457755,4.45779,4.457826,4.457861,4.457897,4.457932,4.457968,4.458003,4.458039,4.458074,4.45811,4.458145,4.458180,4.458216,4.458251,4.458287,4.458322,4.458358,4.458393,4.458428,4.458464,4.458499,4.458535,4.45857,4.458605,4.458641,4.458676,4.458711,4.458747,4.458782,4.458817,4.458853,4.458888,4.458923,4.458959,4.458994,4.459029,4.459065,4.4591,4.459135,4.459171,4.459206,4.459241,4.459276,4.459312,4.459347,4.459382,4.459417,4.459453,4.459488,4.459523,4.459558,4.459593,4.459629,4.459664,4.459699,4.459734,4.459769,4.459804,4.45984,4.459875,4.45991,4.459945,4.45998,4.460015,4.460050,4.460086,4.460121,4.460156,4.460191,4.460226,4.460261,4.460296,4.460331,4.460366,4.460401,4.460436,4.460472,4.460507,4.460542,4.460577,4.460612,4.460647,4.460682,4.460717,4.460752,4.460787,4.460822,4.460857,4.460892,4.460927,4.460962,4.460997,4.461032,4.461067,4.461101,4.461136,4.461171,4.461206,4.461241,4.461276,4.461311,4.461346,4.461381,4.461416,4.461451,4.461485,4.46152,4.461555,4.46159,4.461625,4.46166,4.461695,4.461729,4.461764,4.461799,4.461834,4.461869,4.461904,4.461938,4.461973,4.462008,4.462043,4.462078,4.462112,4.462147,4.462182,4.462217,4.462251,4.462286,4.462321,4.462356,4.46239,4.462425,4.46246,4.462494,4.462529,4.462564,4.462599,4.462633,4.462668,4.462703,4.462737,4.462772,4.462807,4.462841,4.462876,4.462911,4.462945,4.46298,4.463014,4.463049,4.463084,4.463118,4.463153,4.463187,4.463222,4.463257,4.463291,4.463326,4.46336,4.463395,4.463429,4.463464,4.463499,4.463533,4.463568,4.463602,4.463637,4.463671,4.463706,4.46374,4.463775,4.463809,4.463844,4.463878,4.463913,4.463947,4.463981,4.464016,4.46405,4.464085,4.464119,4.464154,4.464188,4.464223,4.464257,4.464291,4.464326,4.46436,4.464395,4.464429,4.464463,4.464498,4.464532,4.464566,4.464601,4.464635,4.464669,4.464704,4.464738,4.464772,4.464807,4.464841,4.464875,4.46491,4.464944,4.464978,4.465013,4.465047,4.465081,4.465115,4.46515,4.465184,4.465218,4.465252,4.465287,4.465321,4.465355,4.465389,4.465424,4.465458,4.465492,4.465526,4.46556,4.465595,4.465629,4.465663,4.465697,4.465731,4.465765,4.4658,4.465834,4.465868,4.465902,4.465936,4.46597,4.466004,4.466039,4.466073,4.466107,4.466141,4.466175,4.466209,4.466243,4.466277,4.466311,4.466345,4.466379,4.466413,4.466447,4.466481,4.466516,4.46655,4.466584,4.466618,4.466652,4.466686,4.46672,4.466754,4.466788,4.466822,4.466856,4.466890,4.466924,4.466957,4.466991,4.467025,4.467059,4.467093,4.467127,4.467161,4.467195,4.467229,4.467263,4.467297,4.467331,4.467365,4.467398,4.467432,4.467466,4.4675,4.467534,4.467568,4.467602,4.467636,4.467669,4.467703,4.467737,4.467771,4.467805,4.467839,4.467872,4.467906,4.46794,4.467974,4.468008,4.468041,4.468075,4.468109,4.468143,4.468176,4.46821,4.468244,4.468278,4.468311,4.468345,4.468379,4.468413,4.468446,4.46848,4.468514,4.468547,4.468581,4.468615,4.468648,4.468682,4.468716,4.468749,4.468783,4.468817,4.468850,4.468884,4.468918,4.468951,4.468985,4.469019,4.469052,4.469086,4.469119,4.469153,4.469187,4.46922,4.469254,4.469287,4.469321,4.469355,4.469388,4.469422,4.469455,4.469489,4.469522,4.469556,4.469589,4.469623,4.469656,4.46969,4.469723,4.469757,4.46979,4.469824,4.469857,4.469891,4.469924,4.469958,4.469991,4.470025,4.470058,4.470092,4.470125,4.470159,4.470192,4.470225,4.470259,4.470292,4.470326,4.470359,4.470392,4.470426,4.470459,4.470493,4.470526,4.470559,4.470593,4.470626,4.470659,4.470693,4.470726,4.470759,4.470793,4.470826,4.470859,4.470893,4.470926,4.470959,4.470993,4.471026,4.471059,4.471093,4.471126,4.471159,4.471192,4.471226,4.471259,4.471292,4.471325,4.471359,4.471392,4.471425,4.471458,4.471492,4.471525,4.471558,4.471591,4.471624,4.471658,4.471691,4.471724,4.471757,4.47179,4.471823,4.471857,4.47189,4.471923,4.471956,4.471989,4.472022,4.472055,4.472089,4.472122,4.472155,4.472188,4.472221,4.472254,4.472287,4.47232,4.472353,4.472386,4.472419,4.472453,4.472486,4.472519,4.472552,4.472585,4.472618,4.472651,4.472684,4.472717,4.47275,4.472783,4.472816,4.472849,4.472882,4.472915,4.472948,4.472981,4.473014,4.473047,4.47308,4.473113,4.473146,4.473179,4.473212,4.473244,4.473277,4.47331,4.473343,4.473376,4.473409,4.473442,4.473475,4.473508,4.473541,4.473574,4.473606,4.473639,4.473672,4.473705,4.473738,4.473771,4.473804,4.473836,4.473869,4.473902,4.473935,4.473968,4.474001,4.474033,4.474066,4.474099,4.474132,4.474165,4.474197,4.47423,4.474263,4.474296,4.474328,4.474361,4.474394,4.474427,4.474459,4.474492,4.474525,4.474558,4.47459,4.474623,4.474656,4.474688,4.474721,4.474754,4.474787,4.474819,4.474852,4.474885,4.474917,4.47495,4.474983,4.475015,4.475048,4.475081,4.475113,4.475146,4.475178,4.475211,4.475244,4.475276,4.475309,4.475341,4.475374,4.475407,4.475439,4.475472,4.475504,4.475537,4.475570,4.475602,4.475635,4.475667,4.4757,4.475732,4.475765,4.475797,4.47583,4.475862,4.475895,4.475927,4.47596,4.475992,4.476025,4.476057,4.47609,4.476122,4.476155,4.476187,4.47622,4.476252,4.476285,4.476317,4.476350,4.476382,4.476414,4.476447,4.476479,4.476512,4.476544,4.476576,4.476609,4.476641,4.476674,4.476706,4.476738,4.476771,4.476803,4.476836,4.476868,4.4769,4.476933,4.476965,4.476997,4.47703,4.477062,4.477094,4.477127,4.477159,4.477191,4.477223,4.477256,4.477288,4.47732,4.477353,4.477385,4.477417,4.477449,4.477482,4.477514,4.477546,4.477578,4.477611,4.477643,4.477675,4.477707,4.47774,4.477772,4.477804,4.477836,4.477868,4.477901,4.477933,4.477965,4.477997,4.478029,4.478062,4.478094,4.478126,4.478158,4.47819,4.478222,4.478254,4.478287,4.478319,4.478351,4.478383,4.478415,4.478447,4.478479,4.478511,4.478543,4.478576,4.478608,4.47864,4.478672,4.478704,4.478736,4.478768,4.4788,4.478832,4.478864,4.478896,4.478928,4.47896,4.478992,4.479024,4.479056,4.479088,4.47912,4.479152,4.479184,4.479216,4.479248,4.47928,4.479312,4.479344,4.479376,4.479408,4.47944,4.479472,4.479504,4.479536,4.479568,4.4796,4.479632,4.479664,4.479696,4.479727,4.479759,4.479791,4.479823,4.479855,4.479887,4.479919,4.479951,4.479983,4.480014,4.480046,4.480078,4.48011,4.480142,4.480174,4.480205,4.480237,4.480269,4.480301,4.480333,4.480365,4.480396,4.480428,4.48046,4.480492,4.480524,4.480555,4.480587,4.480619,4.480651,4.480682,4.480714,4.480746,4.480778,4.480809,4.480841,4.480873,4.480905,4.480936,4.480968,4.481,4.481031,4.481063,4.481095,4.481127,4.481158,4.48119,4.481222,4.481253,4.481285,4.481317,4.481348,4.48138,4.481412,4.481443,4.481475,4.481506,4.481538,4.48157,4.481601,4.481633,4.481665,4.481696,4.481728,4.481759,4.481791,4.481822,4.481854,4.481886,4.481917,4.481949,4.48198,4.482012,4.482043,4.482075,4.482107,4.482138,4.48217,4.482201,4.482233,4.482264,4.482296,4.482327,4.482359,4.48239,4.482422,4.482453,4.482485,4.482516,4.482548,4.482579,4.482611,4.482642,4.482673,4.482705,4.482736,4.482768,4.482799,4.482831,4.482862,4.482893,4.482925,4.482956,4.482988,4.483019,4.483050,4.483082,4.483113,4.483145,4.483176,4.483207,4.483239,4.48327,4.483301,4.483333,4.483364,4.483395,4.483427,4.483458,4.483489,4.483521,4.483552,4.483583,4.483615,4.483646,4.483677,4.483709,4.48374,4.483771,4.483802,4.483834,4.483865,4.483896,4.483928,4.483959,4.48399,4.484021,4.484053,4.484084,4.484115,4.484146,4.484177,4.484209,4.48424,4.484271,4.484302,4.484334,4.484365,4.484396,4.484427,4.484458,4.484489,4.484521,4.484552,4.484583,4.484614,4.484645,4.484676,4.484708,4.484739,4.48477,4.484801,4.484832,4.484863,4.484894,4.484925,4.484956,4.484988,4.485019,4.48505,4.485081,4.485112,4.485143,4.485174,4.485205,4.485236,4.485267,4.485298,4.485329,4.48536,4.485391,4.485422,4.485453,4.485484,4.485516,4.485547,4.485578,4.485609,4.485640,4.485671,4.485702,4.485733,4.485763,4.485794,4.485825,4.485856,4.485887,4.485918,4.485949,4.48598,4.486011,4.486042,4.486073,4.486104,4.486135,4.486166,4.486197,4.486228,4.486259,4.486289,4.48632,4.486351,4.486382,4.486413,4.486444,4.486475,4.486506,4.486536,4.486567,4.486598,4.486629,4.48666,4.486691,4.486722,4.486752,4.486783,4.486814,4.486845,4.486876,4.486906,4.486937,4.486968,4.486999,4.48703,4.48706,4.487091,4.487122,4.487153,4.487184,4.487214,4.487245,4.487276,4.487307,4.487337,4.487368,4.487399,4.487429,4.48746,4.487491,4.487522,4.487552,4.487583,4.487614,4.487644,4.487675,4.487706,4.487737,4.487767,4.487798,4.487829,4.487859,4.48789,4.487921,4.487951,4.487982,4.488012,4.488043,4.488074,4.488104,4.488135,4.488166,4.488196,4.488227,4.488257,4.488288,4.488319,4.488349,4.48838,4.48841,4.488441,4.488472,4.488502,4.488533,4.488563,4.488594,4.488624,4.488655,4.488685,4.488716,4.488746,4.488777,4.488808,4.488838,4.488869,4.488899,4.48893,4.48896,4.488991,4.489021,4.489052,4.489082,4.489112,4.489143,4.489173,4.489204,4.489234,4.489265,4.489295,4.489326,4.489356,4.489387,4.489417,4.489447,4.489478,4.489508,4.489539,4.489569,4.489599,4.48963,4.48966,4.489691,4.489721,4.489751,4.489782,4.489812,4.489843,4.489873,4.489903,4.489934,4.489964,4.489994,4.490025,4.490055,4.490085,4.490116,4.490146,4.490176,4.490207,4.490237,4.490267,4.490298,4.490328,4.490358,4.490388,4.490419,4.490449,4.490479,4.490510,4.49054,4.49057,4.4906,4.490631,4.490661,4.490691,4.490721,4.490751,4.490782,4.490812,4.490842,4.490872,4.490903,4.490933,4.490963,4.490993,4.491023,4.491054,4.491084,4.491114,4.491144,4.491174,4.491204,4.491235,4.491265,4.491295,4.491325,4.491355,4.491385,4.491415,4.491446,4.491476,4.491506,4.491536,4.491566,4.491596,4.491626,4.491656,4.491686,4.491717,4.491747,4.491777,4.491807,4.491837,4.491867,4.491897,4.491927,4.491957,4.491987,4.492017,4.492047,4.492077,4.492107,4.492137,4.492167,4.492197,4.492227,4.492257,4.492287,4.492317,4.492347,4.492377,4.492407,4.492437,4.492467,4.492497,4.492527,4.492557,4.492587,4.492617,4.492647,4.492677,4.492707,4.492737,4.492767,4.492797,4.492827,4.492857,4.492887,4.492917,4.492946,4.492976,4.493006,4.493036,4.493066,4.493096,4.493126,4.493156,4.493186,4.493215,4.493245,4.493275,4.493305,4.493335,4.493365,4.493395,4.493424,4.493454,4.493484,4.493514,4.493544,4.493574,4.493603,4.493633,4.493663,4.493693,4.493723,4.493752,4.493782,4.493812,4.493842,4.493871,4.493901,4.493931,4.493961,4.493991,4.49402,4.49405,4.49408,4.494110,4.494139,4.494169,4.494199,4.494228,4.494258,4.494288,4.494318,4.494347,4.494377,4.494407,4.494436,4.494466,4.494496,4.494525,4.494555,4.494585,4.494614,4.494644,4.494674,4.494703,4.494733,4.494763,4.494792,4.494822,4.494852,4.494881,4.494911,4.49494,4.49497,4.495,4.495029,4.495059,4.495088,4.495118,4.495148,4.495177,4.495207,4.495236,4.495266,4.495296,4.495325,4.495355,4.495384,4.495414,4.495443,4.495473,4.495502,4.495532,4.495561,4.495591,4.495620,4.49565,4.495679,4.495709,4.495739,4.495768,4.495797,4.495827,4.495856,4.495886,4.495915,4.495945,4.495974,4.496004,4.496033,4.496063,4.496092,4.496122,4.496151,4.496181,4.49621,4.496239,4.496269,4.496298,4.496328,4.496357,4.496386,4.496416,4.496445,4.496475,4.496504,4.496533,4.496563,4.496592,4.496622,4.496651,4.49668,4.49671,4.496739,4.496768,4.496798,4.496827,4.496856,4.496886,4.496915,4.496944,4.496974,4.497003,4.497032,4.497062,4.497091,4.49712,4.49715,4.497179,4.497208,4.497237,4.497267,4.497296,4.497325,4.497355,4.497384,4.497413,4.497442,4.497472,4.497501,4.49753,4.497559,4.497589,4.497618,4.497647,4.497676,4.497706,4.497735,4.497764,4.497793,4.497822,4.497852,4.497881,4.49791,4.497939,4.497968,4.497997,4.498027,4.498056,4.498085,4.498114,4.498143,4.498172,4.498202,4.498231,4.49826,4.498289,4.498318,4.498347,4.498376,4.498406,4.498435,4.498464,4.498493,4.498522,4.498551,4.49858,4.498609,4.498638,4.498667,4.498696,4.498726,4.498755,4.498784,4.498813,4.498842,4.498871,4.4989,4.498929,4.498958,4.498987,4.499016,4.499045,4.499074,4.499103,4.499132,4.499161,4.49919,4.499219,4.499248,4.499277,4.499306,4.499335,4.499364,4.499393,4.499422,4.499451,4.49948,4.499509,4.499538,4.499567,4.499596,4.499625,4.499654,4.499683,4.499712,4.499740,4.499769,4.499798,4.499827,4.499856,4.499885,4.499914,4.499943,4.499972,4.500001,4.50003,4.500058,4.500087,4.500116,4.500145,4.500174,4.500203,4.500232,4.500261,4.500289,4.500318,4.500347,4.500376,4.500405,4.500434,4.500462,4.500491,4.50052,4.500549,4.500578,4.500606,4.500635,4.500664,4.500693,4.500722,4.50075,4.500779,4.500808,4.500837,4.500866,4.500894,4.500923,4.500952,4.500981,4.501009,4.501038,4.501067,4.501096,4.501124,4.501153,4.501182,4.50121,4.501239,4.501268,4.501297,4.501325,4.501354,4.501383,4.501411,4.50144,4.501469,4.501497,4.501526,4.501555,4.501583,4.501612,4.501641,4.501669,4.501698,4.501727,4.501755,4.501784,4.501813,4.501841,4.50187,4.501899,4.501927,4.501956,4.501984,4.502013,4.502042,4.50207,4.502099,4.502127,4.502156,4.502185,4.502213,4.502242,4.50227,4.502299,4.502327,4.502356,4.502385,4.502413,4.502442,4.50247,4.502499,4.502527,4.502556,4.502584,4.502613,4.502641,4.50267,4.502698,4.502727,4.502755,4.502784,4.502812,4.502841,4.502869,4.502898,4.502926,4.502955,4.502983,4.503012,4.50304,4.503069,4.503097,4.503126,4.503154,4.503182,4.503211,4.503239,4.503268,4.503296,4.503325,4.503353,4.503381,4.50341,4.503438,4.503467,4.503495,4.503523,4.503552,4.50358,4.503609,4.503637,4.503665,4.503694,4.503722,4.503750,4.503779,4.503807,4.503836,4.503864,4.503892,4.503921,4.503949,4.503977,4.504006,4.504034,4.504062,4.504091,4.504119,4.504147,4.504175,4.504204,4.504232,4.50426,4.504289,4.504317,4.504345,4.504374,4.504402,4.50443,4.504458,4.504487,4.504515,4.504543,4.504571,4.5046,4.504628,4.504656,4.504684,4.504713,4.504741,4.504769,4.504797,4.504825,4.504854,4.504882,4.50491,4.504938,4.504966,4.504995,4.505023,4.505051,4.505079,4.505107,4.505136,4.505164,4.505192,4.50522,4.505248,4.505276,4.505304,4.505333,4.505361,4.505389,4.505417,4.505445,4.505473,4.505501,4.505530,4.505558,4.505586,4.505614,4.505642,4.50567,4.505698,4.505726,4.505754,4.505782,4.505811,4.505839,4.505867,4.505895,4.505923,4.505951,4.505979,4.506007,4.506035,4.506063,4.506091,4.506119,4.506147,4.506175,4.506203,4.506231,4.506259,4.506287,4.506315,4.506343,4.506371,4.506399,4.506427,4.506455,4.506483,4.506511,4.506539,4.506567,4.506595,4.506623,4.506651,4.506679,4.506707,4.506735,4.506763,4.506791,4.506819,4.506847,4.506875,4.506903,4.506930,4.506958,4.506986,4.507014,4.507042,4.50707,4.507098,4.507126,4.507154,4.507182,4.507210,4.507237,4.507265,4.507293,4.507321,4.507349,4.507377,4.507405,4.507432,4.50746,4.507488,4.507516,4.507544,4.507572,4.507600,4.507627,4.507655,4.507683,4.507711,4.507739,4.507766,4.507794,4.507822,4.50785,4.507878,4.507905,4.507933,4.507961,4.507989,4.508017,4.508044,4.508072,4.5081,4.508128,4.508155,4.508183,4.508211,4.508239,4.508266,4.508294,4.508322,4.50835,4.508377,4.508405,4.508433,4.508460,4.508488,4.508516,4.508544,4.508571,4.508599,4.508627,4.508654,4.508682,4.50871,4.508737,4.508765,4.508793,4.50882,4.508848,4.508876,4.508903,4.508931,4.508959,4.508986,4.509014,4.509042,4.509069,4.509097,4.509125,4.509152,4.50918,4.509207,4.509235,4.509263,4.50929,4.509318,4.509345,4.509373,4.509401,4.509428,4.509456,4.509483,4.509511,4.509538,4.509566,4.509594,4.509621,4.509649,4.509676,4.509704,4.509731,4.509759,4.509786,4.509814,4.509841,4.509869,4.509897,4.509924,4.509952,4.509979,4.510007,4.510034,4.510062,4.510089,4.510117,4.510144,4.510172,4.510199,4.510226,4.510254,4.510281,4.510309,4.510336,4.510364,4.510391,4.510419,4.510446,4.510474,4.510501,4.510528,4.510556,4.510583,4.510611,4.510638,4.510666,4.510693,4.51072,4.510748,4.510775,4.510803,4.51083,4.510857,4.510885,4.510912,4.51094,4.510967,4.510994,4.511022,4.511049,4.511076,4.511104,4.511131,4.511158,4.511186,4.511213,4.511240,4.511268,4.511295,4.511322,4.51135,4.511377,4.511404,4.511432,4.511459,4.511486,4.511514,4.511541,4.511568,4.511596,4.511623,4.51165,4.511677,4.511705,4.511732,4.511759,4.511786,4.511814,4.511841,4.511868,4.511896,4.511923,4.51195,4.511977,4.512004,4.512032,4.512059,4.512086,4.512113,4.512141,4.512168,4.512195,4.512222,4.512249,4.512277,4.512304,4.512331,4.512358,4.512385,4.512413,4.51244,4.512467,4.512494,4.512521,4.512548,4.512576,4.512603,4.51263,4.512657,4.512684,4.512711,4.512739,4.512766,4.512793,4.51282,4.512847,4.512874,4.512901,4.512928,4.512955,4.512983,4.51301,4.513037,4.513064,4.513091,4.513118,4.513145,4.513172,4.513199,4.513226,4.513253,4.513281,4.513308,4.513335,4.513362,4.513389,4.513416,4.513443,4.51347,4.513497,4.513524,4.513551,4.513578,4.513605,4.513632,4.513659,4.513686,4.513713,4.51374,4.513767,4.513794,4.513821,4.513848,4.513875,4.513902,4.513929,4.513956,4.513983,4.51401,4.514037,4.514064,4.514091,4.514118,4.514145,4.514172,4.514199,4.514226,4.514253,4.514279,4.514306,4.514333,4.51436,4.514387,4.514414,4.514441,4.514468,4.514495,4.514522,4.514549,4.514575,4.514602,4.514629,4.514656,4.514683,4.51471,4.514737,4.514764,4.514790,4.514817,4.514844,4.514871,4.514898,4.514925,4.514952,4.514978,4.515005,4.515032,4.515059,4.515086,4.515113,4.515139,4.515166,4.515193,4.51522,4.515247,4.515273,4.5153,4.515327,4.515354,4.515381,4.515407,4.515434,4.515461,4.515488,4.515515,4.515541,4.515568,4.515595,4.515622,4.515648,4.515675,4.515702,4.515729,4.515755,4.515782,4.515809,4.515836,4.515862,4.515889,4.515916,4.515942,4.515969,4.515996,4.516022,4.516049,4.516076,4.516103,4.516129,4.516156,4.516183,4.516209,4.516236,4.516263,4.516289,4.516316,4.516343,4.516369,4.516396,4.516423,4.516449,4.516476,4.516503,4.516529,4.516556,4.516582,4.516609,4.516636,4.516662,4.516689,4.516716,4.516742,4.516769,4.516795,4.516822,4.516849,4.516875,4.516902,4.516928,4.516955,4.516981,4.517008,4.517035,4.517061,4.517088,4.517114,4.517141,4.517167,4.517194,4.517221,4.517247,4.517274,4.5173,4.517327,4.517353,4.51738,4.517406,4.517433,4.517459,4.517486,4.517512,4.517539,4.517565,4.517592,4.517618,4.517645,4.517671,4.517698,4.517724,4.517751,4.517777,4.517804,4.51783,4.517857,4.517883,4.517910,4.517936,4.517962,4.517989,4.518015,4.518042,4.518068,4.518095,4.518121,4.518147,4.518174,4.5182,4.518227,4.518253,4.518280,4.518306,4.518332,4.518359,4.518385,4.518412,4.518438,4.518464,4.518491,4.518517,4.518543,4.51857,4.518596,4.518623,4.518649,4.518675,4.518702,4.518728,4.518754,4.518781,4.518807,4.518833,4.51886,4.518886,4.518912,4.518939,4.518965,4.518991,4.519018,4.519044,4.51907,4.519096,4.519123,4.519149,4.519175,4.519202,4.519228,4.519254,4.519281,4.519307,4.519333,4.519359,4.519386,4.519412,4.519438,4.519464,4.519491,4.519517,4.519543,4.519569,4.519596,4.519622,4.519648,4.519674,4.519701,4.519727,4.519753,4.519779,4.519805,4.519832,4.519858,4.519884,4.51991,4.519936,4.519963,4.519989,4.520015,4.520041,4.520067,4.520093,4.52012,4.520146,4.520172,4.520198,4.520224,4.52025,4.520277,4.520303,4.520329,4.520355,4.520381,4.520407,4.520433,4.520460,4.520486,4.520512,4.520538,4.520564,4.52059,4.520616,4.520642,4.520668,4.520695,4.520721,4.520747,4.520773,4.520799,4.520825,4.520851,4.520877,4.520903,4.520929,4.520955,4.520981,4.521007,4.521033,4.521060,4.521086,4.521112,4.521138,4.521164,4.52119,4.521216,4.521242,4.521268,4.521294,4.52132,4.521346,4.521372,4.521398,4.521424,4.52145,4.521476,4.521502,4.521528,4.521554,4.52158,4.521606,4.521632,4.521658,4.521684,4.52171,4.521736,4.521762,4.521788,4.521813,4.521839,4.521865,4.521891,4.521917,4.521943,4.521969,4.521995,4.522021,4.522047,4.522073,4.522099,4.522125,4.522151,4.522176,4.522202,4.522228,4.522254,4.52228,4.522306,4.522332,4.522358,4.522384,4.522409,4.522435,4.522461,4.522487,4.522513,4.522539,4.522565,4.522590,4.522616,4.522642,4.522668,4.522694,4.52272,4.522746,4.522771,4.522797,4.522823,4.522849,4.522875,4.522900,4.522926,4.522952,4.522978,4.523004,4.523029,4.523055,4.523081,4.523107,4.523133,4.523158,4.523184,4.52321,4.523236,4.523262,4.523287,4.523313,4.523339,4.523365,4.52339,4.523416,4.523442,4.523468,4.523493,4.523519,4.523545,4.523570,4.523596,4.523622,4.523648,4.523673,4.523699,4.523725,4.523750,4.523776,4.523802,4.523828,4.523853,4.523879,4.523905,4.52393,4.523956,4.523982,4.524007,4.524033,4.524059,4.524084,4.52411,4.524136,4.524161,4.524187,4.524213,4.524238,4.524264,4.52429,4.524315,4.524341,4.524366,4.524392,4.524418,4.524443,4.524469,4.524495,4.52452,4.524546,4.524571,4.524597,4.524623,4.524648,4.524674,4.524699,4.524725,4.524750,4.524776,4.524802,4.524827,4.524853,4.524878,4.524904,4.524929,4.524955,4.524981,4.525006,4.525032,4.525057,4.525083,4.525108,4.525134,4.525159,4.525185,4.52521,4.525236,4.525261,4.525287,4.525312,4.525338,4.525363,4.525389,4.525414,4.52544,4.525465,4.525491,4.525516,4.525542,4.525567,4.525593,4.525618,4.525644,4.525669,4.525695,4.52572,4.525746,4.525771,4.525796,4.525822,4.525847,4.525873,4.525898,4.525924,4.525949,4.525974,4.526,4.526025,4.526051,4.526076,4.526102,4.526127,4.526152,4.526178,4.526203,4.526229,4.526254,4.526279,4.526305,4.52633,4.526355,4.526381,4.526406,4.526432,4.526457,4.526482,4.526508,4.526533,4.526558,4.526584,4.526609,4.526634,4.52666,4.526685,4.52671,4.526736,4.526761,4.526786,4.526812,4.526837,4.526862,4.526888,4.526913,4.526938,4.526964,4.526989,4.527014,4.527039,4.527065,4.52709,4.527115,4.527141,4.527166,4.527191,4.527216,4.527242,4.527267,4.527292,4.527317,4.527343,4.527368,4.527393,4.527418,4.527444,4.527469,4.527494,4.527519,4.527545,4.52757,4.527595,4.52762,4.527646,4.527671,4.527696,4.527721,4.527746,4.527772,4.527797,4.527822,4.527847,4.527872,4.527898,4.527923,4.527948,4.527973,4.527998,4.528023,4.528049,4.528074,4.528099,4.528124,4.528149,4.528174,4.528200,4.528225,4.52825,4.528275,4.5283,4.528325,4.52835,4.528375,4.528401,4.528426,4.528451,4.528476,4.528501,4.528526,4.528551,4.528576,4.528601,4.528627,4.528652,4.528677,4.528702,4.528727,4.528752,4.528777,4.528802,4.528827,4.528852,4.528877,4.528902,4.528927,4.528952,4.528978,4.529003,4.529028,4.529053,4.529078,4.529103,4.529128,4.529153,4.529178,4.529203,4.529228,4.529253,4.529278,4.529303,4.529328,4.529353,4.529378,4.529403,4.529428,4.529453,4.529478,4.529503,4.529528,4.529553,4.529578,4.529603,4.529628,4.529653,4.529678,4.529703,4.529728,4.529753,4.529778,4.529803,4.529827,4.529852,4.529877,4.529902,4.529927,4.529952,4.529977,4.530002,4.530027,4.530052,4.530077,4.530102,4.530127,4.530151,4.530176,4.530201,4.530226,4.530251,4.530276,4.530301,4.530326,4.530351,4.530375,4.5304,4.530425,4.53045,4.530475,4.5305,4.530525,4.53055,4.530574,4.530599,4.530624,4.530649,4.530674,4.530699,4.530723,4.530748,4.530773,4.530798,4.530823,4.530848,4.530872,4.530897,4.530922,4.530947,4.530972,4.530996,4.531021,4.531046,4.531071,4.531096,4.53112,4.531145,4.53117,4.531195,4.53122,4.531244,4.531269,4.531294,4.531319,4.531343,4.531368,4.531393,4.531418,4.531442,4.531467,4.531492,4.531517,4.531541,4.531566,4.531591,4.531616,4.53164,4.531665,4.53169,4.531714,4.531739,4.531764,4.531789,4.531813,4.531838,4.531863,4.531887,4.531912,4.531937,4.531961,4.531986,4.532011,4.532035,4.53206,4.532085,4.532109,4.532134,4.532159,4.532183,4.532208,4.532233,4.532257,4.532282,4.532307,4.532331,4.532356,4.532381,4.532405,4.53243,4.532454,4.532479,4.532504,4.532528,4.532553,4.532578,4.532602,4.532627,4.532651,4.532676,4.532701,4.532725,4.53275,4.532774,4.532799,4.532824,4.532848,4.532873,4.532897,4.532922,4.532946,4.532971,4.532995,4.53302,4.533045,4.533069,4.533094,4.533118,4.533143,4.533167,4.533192,4.533216,4.533241,4.533265,4.53329,4.533314,4.533339,4.533364,4.533388,4.533413,4.533437,4.533462,4.533486,4.533511,4.533535,4.533560,4.533584,4.533608,4.533633,4.533657,4.533682,4.533706,4.533731,4.533755,4.53378,4.533804,4.533829,4.533853,4.533878,4.533902,4.533927,4.533951,4.533975,4.534,4.534024,4.534049,4.534073,4.534098,4.534122,4.534146,4.534171,4.534195,4.53422,4.534244,4.534268,4.534293,4.534317,4.534342,4.534366,4.534390,4.534415,4.534439,4.534464,4.534488,4.534512,4.534537,4.534561,4.534585,4.53461,4.534634,4.534659,4.534683,4.534707,4.534732,4.534756,4.53478,4.534805,4.534829,4.534853,4.534878,4.534902,4.534926,4.534951,4.534975,4.534999,4.535024,4.535048,4.535072,4.535097,4.535121,4.535145,4.535169,4.535194,4.535218,4.535242,4.535267,4.535291,4.535315,4.535339,4.535364,4.535388,4.535412,4.535436,4.535461,4.535485,4.535509,4.535534,4.535558,4.535582,4.535606,4.535630,4.535655,4.535679,4.535703,4.535727,4.535752,4.535776,4.5358,4.535824,4.535849,4.535873,4.535897,4.535921,4.535945,4.53597,4.535994,4.536018,4.536042,4.536066,4.536091,4.536115,4.536139,4.536163,4.536187,4.536211,4.536236,4.53626,4.536284,4.536308,4.536332,4.536356,4.536381,4.536405,4.536429,4.536453,4.536477,4.536501,4.536525,4.536550,4.536574,4.536598,4.536622,4.536646,4.53667,4.536694,4.536718,4.536742,4.536767,4.536791,4.536815,4.536839,4.536863,4.536887,4.536911,4.536935,4.536959,4.536983,4.537007,4.537032,4.537056,4.53708,4.537104,4.537128,4.537152,4.537176,4.5372,4.537224,4.537248,4.537272,4.537296,4.53732,4.537344,4.537368,4.537392,4.537416,4.53744,4.537464,4.537488,4.537512,4.537536,4.537560,4.537584,4.537608,4.537632,4.537656,4.537680,4.537704,4.537728,4.537752,4.537776,4.5378,4.537824,4.537848,4.537872,4.537896,4.53792,4.537944,4.537968,4.537992,4.538016,4.53804,4.538064,4.538088,4.538112,4.538136,4.53816,4.538184,4.538208,4.538232,4.538256,4.538279,4.538303,4.538327,4.538351,4.538375,4.538399,4.538423,4.538447,4.538471,4.538495,4.538519,4.538542,4.538566,4.53859,4.538614,4.538638,4.538662,4.538686,4.53871,4.538734,4.538757,4.538781,4.538805,4.538829,4.538853,4.538877,4.538901,4.538924,4.538948,4.538972,4.538996,4.53902,4.539044,4.539067,4.539091,4.539115,4.539139,4.539163,4.539187,4.53921,4.539234,4.539258,4.539282,4.539306,4.539329,4.539353,4.539377,4.539401,4.539425,4.539448,4.539472,4.539496,4.53952,4.539544,4.539567,4.539591,4.539615,4.539639,4.539662,4.539686,4.53971,4.539734,4.539757,4.539781,4.539805,4.539829,4.539852,4.539876,4.5399,4.539924,4.539947,4.539971,4.539995,4.540018,4.540042,4.540066,4.54009,4.540113,4.540137,4.540161,4.540184,4.540208,4.540232,4.540256,4.540279,4.540303,4.540327,4.54035,4.540374,4.540398,4.540421,4.540445,4.540469,4.540492,4.540516,4.54054,4.540563,4.540587,4.540611,4.540634,4.540658,4.540682,4.540705,4.540729,4.540752,4.540776,4.5408,4.540823,4.540847,4.540871,4.540894,4.540918,4.540941,4.540965,4.540989,4.541012,4.541036,4.541059,4.541083,4.541107,4.54113,4.541154,4.541177,4.541201,4.541225,4.541248,4.541272,4.541295,4.541319,4.541342,4.541366,4.54139,4.541413,4.541437,4.54146,4.541484,4.541507,4.541531,4.541554,4.541578,4.541602,4.541625,4.541649,4.541672,4.541696,4.541719,4.541743,4.541766,4.54179,4.541813,4.541837,4.54186,4.541884,4.541907,4.541931,4.541954,4.541978,4.542001,4.542025,4.542048,4.542072,4.542095,4.542119,4.542142,4.542166,4.542189,4.542212,4.542236,4.542259,4.542283,4.542306,4.54233,4.542353,4.542377,4.5424,4.542424,4.542447,4.54247,4.542494,4.542517,4.542541,4.542564,4.542588,4.542611,4.542634,4.542658,4.542681,4.542705,4.542728,4.542751,4.542775,4.542798,4.542822,4.542845,4.542868,4.542892,4.542915,4.542939,4.542962,4.542985,4.543009,4.543032,4.543055,4.543079,4.543102,4.543126,4.543149,4.543172,4.543196,4.543219,4.543242,4.543266,4.543289,4.543312,4.543336,4.543359,4.543382,4.543406,4.543429,4.543452,4.543476,4.543499,4.543522,4.543546,4.543569,4.543592,4.543615,4.543639,4.543662,4.543685,4.543709,4.543732,4.543755,4.543778,4.543802,4.543825,4.543848,4.543872,4.543895,4.543918,4.543941,4.543965,4.543988,4.544011,4.544034,4.544058,4.544081,4.544104,4.544127,4.544151,4.544174,4.544197,4.54422,4.544244,4.544267,4.54429,4.544313,4.544336,4.54436,4.544383,4.544406,4.544429,4.544453,4.544476,4.544499,4.544522,4.544545,4.544569,4.544592,4.544615,4.544638,4.544661,4.544684,4.544708,4.544731,4.544754,4.544777,4.5448,4.544823,4.544847,4.54487,4.544893,4.544916,4.544939,4.544962,4.544986,4.545009,4.545032,4.545055,4.545078,4.545101,4.545124,4.545148,4.545171,4.545194,4.545217,4.54524,4.545263,4.545286,4.545309,4.545332,4.545356,4.545379,4.545402,4.545425,4.545448,4.545471,4.545494,4.545517,4.54554,4.545563,4.545586,4.545609,4.545633,4.545656,4.545679,4.545702,4.545725,4.545748,4.545771,4.545794,4.545817,4.54584,4.545863,4.545886,4.545909,4.545932,4.545955,4.545978,4.546001,4.546024,4.546047,4.54607,4.546093,4.546116,4.546139,4.546162,4.546185,4.546208,4.546231,4.546254,4.546277,4.546300,4.546323,4.546346,4.546369,4.546392,4.546415,4.546438,4.546461,4.546484,4.546507,4.54653,4.546553,4.546576,4.546599,4.546622,4.546645,4.546668,4.546691,4.546714,4.546737,4.54676,4.546783,4.546806,4.546829,4.546852,4.546875,4.546897,4.54692,4.546943,4.546966,4.546989,4.547012,4.547035,4.547058,4.547081,4.547104,4.547127,4.547149,4.547172,4.547195,4.547218,4.547241,4.547264,4.547287,4.54731,4.547333,4.547355,4.547378,4.547401,4.547424,4.547447,4.54747,4.547493,4.547516,4.547538,4.547561,4.547584,4.547607,4.54763,4.547653,4.547675,4.547698,4.547721,4.547744,4.547767,4.54779,4.547812,4.547835,4.547858,4.547881,4.547904,4.547926,4.547949,4.547972,4.547995,4.548018,4.548041,4.548063,4.548086,4.548109,4.548132,4.548154,4.548177,4.5482,4.548223,4.548246,4.548268,4.548291,4.548314,4.548337,4.548359,4.548382,4.548405,4.548428,4.54845,4.548473,4.548496,4.548519,4.548541,4.548564,4.548587,4.54861,4.548632,4.548655,4.548678,4.548701,4.548723,4.548746,4.548769,4.548791,4.548814,4.548837,4.548860,4.548882,4.548905,4.548928,4.54895,4.548973,4.548996,4.549018,4.549041,4.549064,4.549086,4.549109,4.549132,4.549154,4.549177,4.5492,4.549222,4.549245,4.549268,4.54929,4.549313,4.549336,4.549358,4.549381,4.549404,4.549426,4.549449,4.549472,4.549494,4.549517,4.549540,4.549562,4.549585,4.549607,4.54963,4.549653,4.549675,4.549698,4.54972,4.549743,4.549766,4.549788,4.549811,4.549833,4.549856,4.549879,4.549901,4.549924,4.549946,4.549969,4.549992,4.550014,4.550037,4.550059,4.550082,4.550104,4.550127,4.550150,4.550172,4.550195,4.550217,4.55024,4.550262,4.550285,4.550307,4.55033,4.550352,4.550375,4.550398,4.55042,4.550443,4.550465,4.550488,4.55051,4.550533,4.550555,4.550578,4.5506,4.550623,4.550645,4.550668,4.55069,4.550713,4.550735,4.550758,4.55078,4.550803,4.550825,4.550848,4.55087,4.550893,4.550915,4.550938,4.55096,4.550983,4.551005,4.551027,4.55105,4.551072,4.551095,4.551117,4.55114,4.551162,4.551185,4.551207,4.551230,4.551252,4.551274,4.551297,4.551319,4.551342,4.551364,4.551387,4.551409,4.551431,4.551454,4.551476,4.551499,4.551521,4.551543,4.551566,4.551588,4.551611,4.551633,4.551655,4.551678,4.5517,4.551723,4.551745,4.551767,4.55179,4.551812,4.551834,4.551857,4.551879,4.551902,4.551924,4.551946,4.551969,4.551991,4.552013,4.552036,4.552058,4.55208,4.552103,4.552125,4.552147,4.55217,4.552192,4.552214,4.552237,4.552259,4.552281,4.552304,4.552326,4.552348,4.552371,4.552393,4.552415,4.552438,4.55246,4.552482,4.552505,4.552527,4.552549,4.552571,4.552594,4.552616,4.552638,4.552661,4.552683,4.552705,4.552727,4.55275,4.552772,4.552794,4.552816,4.552839,4.552861,4.552883,4.552905,4.552928,4.55295,4.552972,4.552994,4.553017,4.553039,4.553061,4.553083,4.553106,4.553128,4.55315,4.553172,4.553195,4.553217,4.553239,4.553261,4.553283,4.553306,4.553328,4.55335,4.553372,4.553394,4.553417,4.553439,4.553461,4.553483,4.553505,4.553528,4.55355,4.553572,4.553594,4.553616,4.553638,4.553661,4.553683,4.553705,4.553727,4.553749,4.553771,4.553794,4.553816,4.553838,4.55386,4.553882,4.553904,4.553927,4.553949,4.553971,4.553993,4.554015,4.554037,4.554059,4.554081,4.554104,4.554126,4.554148,4.55417,4.554192,4.554214,4.554236,4.554258,4.554280,4.554303,4.554325,4.554347,4.554369,4.554391,4.554413,4.554435,4.554457,4.554479,4.554501,4.554523,4.554546,4.554568,4.55459,4.554612,4.554634,4.554656,4.554678,4.5547,4.554722,4.554744,4.554766,4.554788,4.55481,4.554832,4.554854,4.554876,4.554898,4.55492,4.554942,4.554965,4.554987,4.555009,4.555031,4.555053,4.555075,4.555097,4.555119,4.555141,4.555163,4.555185,4.555207,4.555229,4.555251,4.555273,4.555295,4.555317,4.555339,4.555361,4.555383,4.555405,4.555427,4.555449,4.555471,4.555492,4.555514,4.555536,4.555558,4.55558,4.555602,4.555624,4.555646,4.555668,4.55569,4.555712,4.555734,4.555756,4.555778,4.5558,4.555822,4.555844,4.555866,4.555888,4.555909,4.555931,4.555953,4.555975,4.555997,4.556019,4.556041,4.556063,4.556085,4.556107,4.556129,4.556150,4.556172,4.556194,4.556216,4.556238,4.55626,4.556282,4.556304,4.556326,4.556347,4.556369,4.556391,4.556413,4.556435,4.556457,4.556479,4.556501,4.556522,4.556544,4.556566,4.556588,4.55661,4.556632,4.556654,4.556675,4.556697,4.556719,4.556741,4.556763,4.556785,4.556806,4.556828,4.55685,4.556872,4.556894,4.556915,4.556937,4.556959,4.556981,4.557003,4.557025,4.557046,4.557068,4.55709,4.557112,4.557134,4.557155,4.557177,4.557199,4.557221,4.557242,4.557264,4.557286,4.557308,4.55733,4.557351,4.557373,4.557395,4.557417,4.557438,4.55746,4.557482,4.557504,4.557525,4.557547,4.557569,4.557591,4.557612,4.557634,4.557656,4.557678,4.557699,4.557721,4.557743,4.557764,4.557786,4.557808,4.55783,4.557851,4.557873,4.557895,4.557917,4.557938,4.55796,4.557982,4.558003,4.558025,4.558047,4.558068,4.55809,4.558112,4.558133,4.558155,4.558177,4.558199,4.55822,4.558242,4.558264,4.558285,4.558307,4.558329,4.55835,4.558372,4.558394,4.558415,4.558437,4.558458,4.55848,4.558502,4.558523,4.558545,4.558567,4.558588,4.55861,4.558632,4.558653,4.558675,4.558696,4.558718,4.55874,4.558761,4.558783,4.558805,4.558826,4.558848,4.558869,4.558891,4.558913,4.558934,4.558956,4.558977,4.558999,4.559021,4.559042,4.559064,4.559085,4.559107,4.559128,4.55915,4.559172,4.559193,4.559215,4.559236,4.559258,4.559279,4.559301,4.559323,4.559344,4.559366,4.559387,4.559409,4.55943,4.559452,4.559473,4.559495,4.559516,4.559538,4.55956,4.559581,4.559603,4.559624,4.559646,4.559667,4.559689,4.55971,4.559732,4.559753,4.559775,4.559796,4.559818,4.559839,4.559861,4.559882,4.559904,4.559925,4.559947,4.559968,4.55999,4.560011,4.560033,4.560054,4.560076,4.560097,4.560119,4.56014,4.560162,4.560183,4.560204,4.560226,4.560247,4.560269,4.56029,4.560312,4.560333,4.560355,4.560376,4.560398,4.560419,4.56044,4.560462,4.560483,4.560505,4.560526,4.560548,4.560569,4.56059,4.560612,4.560633,4.560655,4.560676,4.560697,4.560719,4.56074,4.560762,4.560783,4.560804,4.560826,4.560847,4.560869,4.56089,4.560911,4.560933,4.560954,4.560976,4.560997,4.561018,4.56104,4.561061,4.561082,4.561104,4.561125,4.561147,4.561168,4.561189,4.561211,4.561232,4.561253,4.561275,4.561296,4.561317,4.561339,4.56136,4.561381,4.561403,4.561424,4.561445,4.561467,4.561488,4.561509,4.561531,4.561552,4.561573,4.561595,4.561616,4.561637,4.561659,4.56168,4.561701,4.561723,4.561744,4.561765,4.561786,4.561808,4.561829,4.56185,4.561872,4.561893,4.561914,4.561935,4.561957,4.561978,4.561999,4.562021,4.562042,4.562063,4.562084,4.562106,4.562127,4.562148,4.562169,4.562191,4.562212,4.562233,4.562254,4.562276,4.562297,4.562318,4.562339,4.562361,4.562382,4.562403,4.562424,4.562445,4.562467,4.562488,4.562509,4.56253,4.562552,4.562573,4.562594,4.562615,4.562636,4.562658,4.562679,4.5627,4.562721,4.562742,4.562764,4.562785,4.562806,4.562827,4.562848,4.562870,4.562891,4.562912,4.562933,4.562954,4.562975,4.562997,4.563018,4.563039,4.56306,4.563081,4.563102,4.563124,4.563145,4.563166,4.563187,4.563208,4.563229,4.56325,4.563272,4.563293,4.563314,4.563335,4.563356,4.563377,4.563398,4.563419,4.563441,4.563462,4.563483,4.563504,4.563525,4.563546,4.563567,4.563588,4.563609,4.563631,4.563652,4.563673,4.563694,4.563715,4.563736,4.563757,4.563778,4.563799,4.56382,4.563841,4.563863,4.563884,4.563905,4.563926,4.563947,4.563968,4.563989,4.56401,4.564031,4.564052,4.564073,4.564094,4.564115,4.564136,4.564157,4.564178,4.564199,4.564220,4.564242,4.564263,4.564284,4.564305,4.564326,4.564347,4.564368,4.564389,4.56441,4.564431,4.564452,4.564473,4.564494,4.564515,4.564536,4.564557,4.564578,4.564599,4.56462,4.564641,4.564662,4.564683,4.564704,4.564725,4.564746,4.564767,4.564788};

#endif

